(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    185225,       3091]*)
(*NotebookOutlinePosition[    186025,       3119]*)
(*  CellTagsIndexPosition[    185981,       3115]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["  ReactionDiffusionLab.m", "Subtitle",
  CellMargins->{{0, 0}, {Inherited, 0}},
  CellFrameMargins->{{8, 0}, {18, 18}},
  Background->RGBColor[0.74902, 0.694118, 0.552941]],

Cell["Version 2.0, July 2004", "Text"],

Cell[TextData[{
  "Selwyn Hollis\n",
  ButtonBox["shollis@appliedsymbols.com",
    ButtonData:>{
      URL[ "mailto:shollis@appliedsymbols.com"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontFamily->"Helvetica",
    FontSize->10],
  ButtonBox["http://www.appliedsymbols.com",
    ButtonData:>{
      URL[ "http://www.appliedsymbols.com"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell["Description", "SubsectionIcon"],

Cell[TextData[{
  "R",
  StyleBox["eactionDiffusionLab",
    FontFamily->"Courier"],
  " is a package that provides two functions, ",
  StyleBox["RDDensityPlots",
    FontFamily->"Courier"],
  " and ",
  StyleBox["RDSurfacePlots",
    FontFamily->"Courier"],
  ", for animating solutions of autonomous reaction-diffusion systems with \
two components,"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(u\_t - \(d\_1\) \[CapitalDelta]\[VeryThinSpace]u\), 
              "=", \(\(f(u, v)\)\(,\)\)},
            {\(v\_t - \(d\_2\) \[CapitalDelta]\[VeryThinSpace]v\), 
              "=", \(\(g(u, v)\)\(,\)\)}
            },
          ColumnSpacings->0.25,
          ColumnAlignments->{Right, Center, Left}], TraditionalForm]]],
  "    ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(u(0, x, y)\), "=", \(\(u\_0\)(x, y)\)},
            {\(v(0, x, y)\), "=", \(\(v\_0\)(x, y)\)}
            },
          ColumnSpacings->0.25,
          ColumnAlignments->{Right, Center, Left}], TraditionalForm]]]
}], "Text",
  TextAlignment->Left,
  TextJustification->0,
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 6}],

Cell["or three components,", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(u\_t - \(\(d\_1\) \(\[CapitalDelta]\)\(\[VeryThinSpace]\)\(u\)\
\(\ \)\)\), "=", \(\(f(u, v, w)\)\(,\)\)},
            {\(v\_t - \(\(d\_2\) \(\[CapitalDelta]\)\(\[VeryThinSpace]\)\(v\)\
\(\ \)\)\), "=", \(\(g(u, v, w)\)\(,\)\)},
            {\(w\_t - \(d\_3\) \[CapitalDelta]\[VeryThinSpace]w\), 
              "=", \(\(h(u, v, w)\)\(,\)\)}
            },
          ColumnSpacings->0.3,
          ColumnAlignments->{Right, Center, Left}], TraditionalForm]]],
  "    ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(u(0, x, y)\), "=", \(\(u\_0\)(x, y)\)},
            {\(v(0, x, y)\), "=", \(\(v\_0\)(x, y)\)},
            {\(w(0, x, y)\), "=", \(\(v\_0\)(x, y)\)}
            },
          ColumnSpacings->0.3,
          ColumnAlignments->{Right, Center, Left}], TraditionalForm]]]
}], "Text",
  TextAlignment->Left,
  TextJustification->0,
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 6}],

Cell["\<\
Boundary conditions may be periodic or any combination of \
homogeneous Neumann type and (possibly nonhomogeneous) Dirichlet type. \
\>", \
"Text"],

Cell[TextData[{
  "The  domain is a rectangle ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, b)\)\[Times]\((c, d)\)\)]],
  ", and solution values are stored in an ",
  Cell[BoxData[
      \(TraditionalForm\`m\[Times]n\)]],
  " matrix corresponding to a rectangular grid with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[VeryThinSpace]x = \((b - 
              a)\)/\((n - 1)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[VeryThinSpace]y = \((d - 
              c)\)/\((m - 1)\)\)]],
  ". Regardless of the boundary conditions, the first/last rows correspond to \
the top/bottom edges of the region, and the first/last entries in all rows \
correspond to the left/right edges of the region. "
}], "Text"],

Cell["The default domain is", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\((0, \(n - 1\)\/\(m - 1\))\)\[Times]\((0, 1)\)\)]],
  ","
}], "Text",
  ScriptSizeMultipliers->0.87],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " are the number of rows and columns in the arrays containing the initial \
data."
}], "Text"],

Cell["\<\
Time stepping is done via an alternating direction implicit (ADI) \
method. Although the method is unconditionally stable for linear problems, a \
reasonably small time step is required for nonlinear problems.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Two-component Systems", "SubsectionIcon"],

Cell[TextData[{
  " ",
  StyleBox["RDDensityPlots",
    FontFamily->"Courier"],
  " and ",
  StyleBox["RDSurfacePlots",
    FontFamily->"Courier"],
  " are used as follows in the two-component case:"
}], "Text"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"RDDensityPlots", "[", 
            RowBox[{
              RowBox[{
                StyleBox["{",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Times"], 
                    StyleBox[\(u, \ v\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Times"]}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Times"], 
                    StyleBox[\(u, \ v\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Times"]}]}], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["}",
                  FontFamily->"Times"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["{",
                  FontFamily->"Times"], 
                StyleBox[\(u, \ v\),
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox["}",
                  FontFamily->"Times"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["u",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["v",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"]}], "}"}],
                FontFamily->"Times"], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "1"], ",", " ", 
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "2"]}], "}"}],
                FontFamily->"Times"], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["\[CapitalDelta]",
                  FontFamily->"Times",
                  FontSlant->"Plain"], 
                StyleBox["\[VeryThinSpace]",
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox["t",
                  FontFamily->"Times",
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox["nframes",
                FontFamily->"Times",
                FontSlant->"Italic"]}], "]"}]},
        {
          RowBox[{"RDSurfacePlots", "[", 
            RowBox[{
              RowBox[{
                StyleBox["{",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Times"], 
                    StyleBox[\(u, \ v\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Times"]}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Times"], 
                    StyleBox[\(u, \ v\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Times"]}]}], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["}",
                  FontFamily->"Times"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["{",
                  FontFamily->"Times"], 
                StyleBox[\(u, \ v\),
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox["}",
                  FontFamily->"Times"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["u",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["v",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"]}], "}"}],
                FontFamily->"Times"], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "1"], ",", " ", 
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "2"]}], "}"}],
                FontFamily->"Times"], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{
                  StyleBox["\[CapitalDelta]",
                    FontFamily->"Times",
                    FontSlant->"Plain"], 
                  StyleBox["t",
                    FontFamily->"Times",
                    FontSlant->"Italic"]}]], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              StyleBox["nframes",
                FontFamily->"Times",
                FontSlant->"Italic"]}], "]"}]}
        },
      ColumnSpacings->0]], "FramedBox"],

Cell[TextData[{
  "\[FilledSmallSquare] In each of these, ",
  Cell[BoxData[
      \(TraditionalForm\`v\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\_0\)]],
  " are ",
  Cell[BoxData[
      \(TraditionalForm\`m\[Times]n\)]],
  " matrices containing initial values."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] The first thing each of these functions does is build \
a ",
  ButtonBox["LinearSolveFunction",
    ButtonStyle->"RefGuideLink"],
  " for each of two ",
  Cell[BoxData[
      \(TraditionalForm\`m\[ThinSpace]n\[Times]m\[ThinSpace]n\)]],
  " sparse matrices. Consequently, there may be an initial delay of several \
seconds if ",
  Cell[BoxData[
      \(TraditionalForm\`m\[ThinSpace]n\)]],
  " is large (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", on the order of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  " or greater)."
}], "Notes"],

Cell[TextData[{
  StyleBox["RDDensityPlots",
    FontFamily->"Courier"],
  " takes the options of ",
  ButtonBox["ListDensityPlot",
    ButtonStyle->"RefGuideLink"],
  ", and ",
  StyleBox["RDSurfacePlots",
    FontFamily->"Courier"],
  " takes the options of ",
  ButtonBox["ListPlot3D",
    ButtonStyle->"RefGuideLink"],
  ". In addition, each has the following options:"
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox["option",
            FontFamily->"Times",
            FontSize->10,
            FontSlant->"Italic"], 
          StyleBox[\(default\ value\),
            FontFamily->"Times",
            FontSize->10,
            FontSlant->"Italic"], " "},
        {"PlotEvery", "1", 
          
          StyleBox[\(The\ number\ of\ time\ steps\ to\ take\ between\ each\ \
\(\(plot\)\(.\)\)\),
            FontFamily->"Times"]},
        {"ReturnLast", "False", 
          
          StyleBox[\(Whether\ to\ return\ the\ numerical\ values\ from\ the\ \
last\ \(\(step\)\(.\)\)\),
            FontFamily->"Times"]},
        {"Domain", \({{0, \[ThinSpace]Automatic}, {0, 1}}\), 
          RowBox[{
            StyleBox["Describes",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["the",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["rectangular",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["domain",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            RowBox[{
              StyleBox["(",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["a",
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontFamily->"Times"], 
                StyleBox["\[NonBreakingSpace]",
                  FontFamily->"Times"], 
                StyleBox["b",
                  FontFamily->"Times",
                  FontSlant->"Italic"]}], 
              StyleBox[")",
                FontFamily->"Times"]}], 
            StyleBox["\[Times]",
              FontFamily->"Times"], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontFamily->"Times"], 
                RowBox[{
                  StyleBox["c",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox["\[NonBreakingSpace]",
                    FontFamily->"Times"], 
                  StyleBox["d",
                    FontFamily->"Times",
                    FontSlant->"Italic"]}], 
                StyleBox[")",
                  FontFamily->"Times"]}], 
              StyleBox[".",
                FontFamily->"Times"], 
              StyleBox[Cell[""],
                FontFamily->"Times"]}]}]},
        {"BoundaryConditions", "Neumann", 
          RowBox[{"Neumann", 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], "Dirichlet", 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], \({Neumann, Dirichlet}\), 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox["\[IndentingNewLine]",
              FontFamily->"Times"], \({Dirichlet, Neumann}\), 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            RowBox[{
              StyleBox["or",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], "Periodic"}]}]},
        {"BoundaryFunctions", \({0 &, 0 &}\), 
          
          StyleBox[\(A\ pair\ of\ functions\ of\[NonBreakingSpace]two\ \
variables\ describing\ Dirichlet\ \[IndentingNewLine]
            boundary\ \(\(data\)\(.\)\(\ \)\)\),
            FontFamily->"Times"]}
        },
      ColumnSpacings->0.5]]]], "DefinitionBox3Col",
  GridBoxOptions->{ColumnWidths->{0.27, 0.3, 0.43},
  RowLines->{True, False}}],

Cell["\<\
\[FilledSmallSquare] The first frame is displayed after one time \
step.\
\>", "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] Setting ",
  StyleBox["ReturnLast\[Rule]\[ThinSpace]True",
    FontFamily->"Courier"],
  " allows you to resume a computation without starting over at time zero. \
(If you do this, be sure to end the command with a semicolon, so as not to \
display the large arrays of numbers.)"
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] The ",
  StyleBox["PlotRange",
    FontFamily->"Courier"],
  " option works in a nonstandard way: ",
  StyleBox["PlotRange\[VeryThinSpace]\[RightArrow]\[VeryThinSpace]",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`{{a, b}, {c, d}}\)]],
  " provides separate vertical plot ranges for the two components. With ",
  StyleBox["PlotRange\[VeryThinSpace]\[RightArrow]\[VeryThinSpace]",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " the same vertical plot range is used for both components. If no plot \
range if specified, or if ",
  StyleBox["PlotRange\[VeryThinSpace]\[RightArrow]\[VeryThinSpace]Automatic",
    FontFamily->"Courier"],
  ", then plot ranges are calculated from the minimum and maximum of the \
initial data. (With a nonnegative minimum these are ",
  StyleBox["{",
    FontFamily->"Courier"],
  StyleBox["0,1.25\[ThinSpace]",
    FontFamily->"Courier",
    FontSize->10],
  StyleBox["max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier"],
  ".) This will rarely give an ideal choice, but it ensures that plot \
sequences always \[OpenCurlyDoubleQuote]stay still.\[CloseCurlyDoubleQuote] A \
related matter: The default for the ",
  StyleBox["ClipFill",
    FontFamily->"Courier"],
  " option in ",
  StyleBox["RDSurfacePlots",
    FontFamily->"Courier"],
  " is ",
  StyleBox["None",
    FontFamily->"Courier"],
  "."
}], "Notes"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< RDL`ReactionDiffusionLab`\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Example 1: Activator-Substrate", "SubsubsectionIcon",
  CellDingbat->None],

Cell["\tThe (nondimensionalised) reaction-diffusion system", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t\t\t", GridBox[{
            {\(u\^\[Prime]\), 
              "=", \(\(d\_1\) \[CapitalDelta]\[VeryThinSpace]u + \(u\^2\) 
                  v - \[Beta]\ u\)},
            {\(v\^\[Prime]\), 
              "=", \(\(d\_2\) \[CapitalDelta]\[VeryThinSpace]v - \(u\^2\) v + 
                1\)}
            },
          ColumnSpacings->0.25,
          ColumnAlignments->{Right, Center, Left}]}], 
      TraditionalForm]], "Text"],

Cell[TextData[{
  "\tarises from the hypothetical autocatalytic ",
  StyleBox["activator-substrate",
    FontSlant->"Italic"],
  " reaction"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(2  A + S\), "\[RightArrow]", \(3  A\)},
            {"B", "\[RightArrow]", "S"},
            {"A", "\[RightArrow]", "P"}
            },
          RowSpacings->0.5,
          ColumnSpacings->0.3,
          ColumnAlignments->{Right, Center, Left},
          ColumnsEqual->False], TraditionalForm]]],
  "\t"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "\tunder the assumption that the concentration of ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is constant. (",
  Cell[BoxData[
      \(TraditionalForm\`u \[Proportional] \([A]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Proportional] \([S]\)\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  "This is the reaction vector field (with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 1\)]],
  "):"
}], "MathCaption"],

Cell[BoxData[
    \(actisubstr := {\(u\^2\) v - u, \(-u\^2\) v + 1}\)], "Input"],

Cell["A judicious choice of diffusion coefficients:", "MathCaption"],

Cell[BoxData[
    \(d1 =  .00025; d2 =  .01;\)], "Input"],

Cell[TextData[{
  "A matrix of initial values for each component. Here our domain is ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 1)\)\[Times]\((0, 1)\)\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[{
    \(\(h = 1/50;\)\), "\n", 
    \(\(u0 = Table[ .5 + Random[], {y, 0, 1, h}, {x, 0, 1, h}];\)\), "\n", 
    \(\(v0 = Table[ .5 + Random[], {y, 0, 1, h}, {x, 0, 1, h}];\)\)}], "Input"],

Cell[TextData[{
  "A ",
  StyleBox["likely",
    FontSlant->"Italic"],
  " safe time-step:"
}], "MathCaption"],

Cell[BoxData[
    \(dt =  .5*h\^2/Max[{d1, d2}]\)], "Input"],

Cell["This animates the solution with Neumann boundary conditions:", \
"MathCaption"],

Cell[BoxData[
    \(\(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 5, 
        PlotEvery \[Rule] 30, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
        ImageSize \[Rule] 400, ReturnLast \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "Since we used ",
  StyleBox["ReturnLast\[Rule]True",
    FontFamily->"Courier"],
  ", we can resume the computation as follows:"
}], "MathCaption"],

Cell[BoxData[
    \(RDDensityPlots[actisubstr, {u, v}, %, {d1, d2}, dt, 10, 
      PlotEvery \[Rule] 30, PlotRange \[Rule] {{0, 5}, {0, 2}}, 
      ImageSize \[Rule] 400]\)], "Input"],

Cell[TextData[{
  "Here the domain is ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 1)\)\[Times]\((0, 2)\)\)]],
  ". Since the height is not 1, we need to use the ",
  StyleBox["Domain",
    FontFamily->"Courier"],
  " option."
}], "MathCaption"],

Cell[BoxData[{
    \(\(h = 1/40;\)\), "\n", 
    \(u0 = Table[ .5 + Random[], {y, 0, 2, h}, {x, 0, 1, h}]; \), "\n", 
    \(\(v0 = 
        Table[ .5 + Random[], {y, 0, 2, h}, {x, 0, 1, 
            h}];\)\n\), "\[IndentingNewLine]", 
    \(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 20, 
      PlotEvery \[Rule] 30, Domain \[Rule] {{0, 1}, {0, 2}}, 
      PlotRange \[Rule] {{0, 5}, {0, 2}}]\)}], "Input"],

Cell[TextData[{
  "We can change the size of the domain without recomputing initial values. \
This uses ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 1/2)\)\[Times]\((0, 1)\)\)]],
  ", which would also be the default."
}], "MathCaption"],

Cell[BoxData[
    \(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 20, 
      PlotEvery \[Rule] 30, Domain \[Rule] {{0,  .5}, {0, 1}}, 
      PlotRange \[Rule] {{0, 5}, {0, 2}}]\)], "Input"],

Cell["\<\
With a square domain, the same intial-value arrays result in a \
non-square grid.\
\>", "MathCaption"],

Cell[BoxData[
    \(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 20, 
      PlotEvery \[Rule] 30, Domain \[Rule] {{0, 1}, {0, 1}}, 
      PlotRange \[Rule] {{0, 5}, {0, 2}}, ImageSize \[Rule] 400]\)], "Input"],

Cell[TextData[{
  "If the aspect ratio of each plot is less than 0.6, then the plots are \
arranged vertically. Here, we\[CloseCurlyQuote]ll also use the ",
  StyleBox["ColorFunction",
    FontFamily->"Courier"],
  " option."
}], "MathCaption"],

Cell[BoxData[{
    \(\(h = 1/30;\)\), "\n", 
    \(u0 = Table[1 + x\ y\^2, {y, 0, 1, h}, {x, 0, 3, h}]; \), "\n", 
    \(\(v0 = 
        Table[y\ Random[], {y, 0, 1, h}, {x, 0, 3, 
            h}];\)\n\), "\[IndentingNewLine]", 
    \(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 20, 
      PlotEvery \[Rule] 30, Domain \[Rule] {{0, 3/2}, {0, 1/2}}, 
      PlotRange \[Rule] {{0, 4}, {0, 2}}, 
      ColorFunction \[Rule] \((RGBColor[#, 0, 0] &)\)]\)}], "Input"],

Cell["\<\
Here\[CloseCurlyQuote]s an example where we use a zero Dirichlet \
boundary condition on the first component.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(h = 1/30;\)\), "\n", 
    \(\(u0 = 
        Table[\((1.5 +  .5  Random[])\) 
            UnitStep[1/9 - \((x\^2 + y\^2)\)], {y, \(-1\), 1, h}, {x, \(-1\), 
            1, h}];\)\), "\n", 
    \(\(v0 = 
        Table[1\ , {y, \(-1\), 1, h}, {x, \(-1\), 1, 
            h}];\)\[IndentingNewLine]\), "\n", 
    \(d1 =  .0005; d2 =  .01; 
    dt =  .175*h\^2/Max[{d1, d2}]\[IndentingNewLine]\), "\n", 
    \(RDDensityPlots[actisubstr, {u, v}, {u0, v0}, {d1, d2}, dt, 30, 
      PlotEvery \[Rule] 40, Domain \[Rule] {{\(-1\), 1}, {\(-1\), 1}}, 
      BoundaryConditions \[Rule] {Dirichlet, Neumann}, 
      BoundaryFunctions \[Rule] {0 &, {}}, 
      PlotRange \[Rule] {{0, 4}, {0, 4}}, 
      ColorFunction \[Rule] \((RGBColor[#, 0, 0] &)\)]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Activator-Inhibitor", "SubsubsectionIcon",
  CellDingbat->None],

Cell["\tThe (nondimensionalised) reaction-diffusion system", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\t\t\t", GridBox[{
            {\(u\^\[Prime]\), 
              "=", \(\(d\_1\) \[CapitalDelta]\[VeryThinSpace]u + 
                u\^2/v - \[Beta]\ u\)},
            {\(v\^\[Prime]\), 
              "=", \(\(d\_2\) \[CapitalDelta]\[VeryThinSpace]v + u\^2 - v\)}
            },
          ColumnSpacings->0.25,
          ColumnAlignments->{Right, Center, Left}]}], 
      TraditionalForm]], "Text"],

Cell[TextData[{
  "\tarises from the hypothetical ",
  StyleBox["activator-inhibitor",
    FontSlant->"Italic"],
  " reaction"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(2  A + C\), "\[RightArrow]", \(3  A + C\)},
            {\(2  A + D\), "\[RightArrow]", \(2  A + B\)},
            {\(B + C\), "\[RightArrowLeftArrow]", "E"},
            {"A", "\[RightArrow]", "0"},
            {"B", "\[RightArrow]", "0"}
            },
          ColumnSpacings->0.25,
          ColumnAlignments->{Right, Center, Left}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "\tunder the assumption that the concentrations of ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " are constant. (",
  Cell[BoxData[
      \(TraditionalForm\`u \[Proportional] \([A]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Proportional] \([B]\) \[Proportional] 
        1/\([C]\)\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  "This is the vector field for the ",
  StyleBox["activator-inhibitor",
    FontSlant->"Italic"],
  " system with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 1\)]],
  "."
}], "MathCaption"],

Cell[BoxData[
    \(actinhib := {u\^2\/v - u, u\^2 - v}\)], "Input"],

Cell["Next define a matrix of initial values for each component.", \
"MathCaption"],

Cell[BoxData[{
    \(\(h = 1/50;\)\), "\n", 
    \(\(u0 = Table[Random[], {y, 0, 1, h}, {x, 0, 3/2, h}];\)\), "\n", 
    \(\(v0 = 
        Table[ .1 + Random[], {y, 0, 1, h}, {x, 0, 3/2, h}];\)\)}], "Input"],

Cell["\<\
These are good values for the diffusion coefficients and time step:\
\
\>", "MathCaption"],

Cell[BoxData[
    \(d1 =  .0005; d2 =  .01; dt =  .5*h\^2/Max[{d1, d2}]\)], "Input"],

Cell["\<\
Let\[CloseCurlyQuote]s set an option for convenience:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(SetOptions[RDDensityPlots, 
        ColorFunction \[Rule] \((Hue[ .1,  .2 +  .8 \@ #\%4, 
                1 -  .95  #] &)\)];\)\)], "Input"],

Cell["\<\
The following animates the solution of the activator-inhibitor \
system with periodic boundary conditions. (The color is supposed to suggest a \
cheetah\[CloseCurlyQuote]s coat.)\
\>", "MathCaption"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000340000S2000`400?l00000o`00003o00WoB6IL
odYSFom<HESoBEmEodQSEOm;IUSoCFMJodiXFomAJeh00_mBK5l0^?mEK63oE6]OoeE/H?mAJ5coCfIJ
odaPE?m9GE7oB5a@odIJC_m3Ed_oAEI:odEGBOm6F4[oAEM9odMIBom4GU7oB5m;odQPC?m8HUCoHVUA
ohN0G_n:QVGo_jn:ok:JM?nHQF?oGTd^ofiE>OnDNFOoGdi;ocd/9_nNOfSoXh]RojN9K?nbTfgocZim
okNDJOn_S6_oXX5PojN4H_niUG7o]Xm[oj>1Foo3XGWo^iY_ojj<I?nkVGCoYhEPokNAJ_n^QEoo`iU`
ok^EJ?noWFgo`j5bol>NLOo4WG7oaIa/olJNJ_o:Y77oc:IcolNQK_o>Z7Oob:9aomV`P?o>YGGobj5f
okbCI?o9XFcodZQcom^^OOoI/7[ofk=nom6ZNonjU6Wo]iUbokNFKOnfTf_o^iE/ol>JL?o:XgGobZ=d
olbXMoo:Yg_oa:=jolNQN?nnVW;ob:Emojb<IOnoWWSo^9AaoimnGOnOPF?o[Hm/okjIK?o4VfOobZ9/
olVPK_o=XWSoaiefol2ELOn_Qf7odZ]_om>ZLoo6X7[o_YagokZHK?niUV[o^iIZoljXOOo4W7;o`Y]h
oj5lF_naSVcoXh=RoiYnFonWRFWo]Y9[om6YN?o4WVgo[hmYoj67K_n0JE3oTgULokNIM_nlVW?o`iig
ol6RPoneUW7o/8mZok6=K?n_Rfgo_9ioohE^EOn?PVkoSX5]oiZ8L_naVgcoZYIhoif:LonOSgkoQgY^
og=[H?n0NfcoPgUToh1aD_nKQf3oT7U@ojJ=J_nHP6CoW8M`oij7LonMQG7oSWeWoi>5LOnERG[oR7me
ogmhL?m[K6?oNgabofM/HOm?Ed[oGFQJofMfIomNKV3oEfMKoeQXG_mWMVgoGFaRoe9PEomCHUWoD61F
odiLE?m=G5?oC5Y@odaGCom<ETkoCEI?odeDCOm<D4goC51<odU=B_m8C4[oAd]8odI:Aom3AdD1odA8
A00000goB6ILodURF_m;H5OoC65HodaWFOm=Je_oCVYLoe1/G_mCKf7oE71Roe5]GomHLVGoEFmR00;o
DVaO03?oC6IIoe9XFom<HUGoBV1CodUOD_m2F4_oAe]>odEJBom2EdSoAea=odYOD?m6GE3oC69=od]R
COm8I5GoM85_ohN8KomlOfSoRHIXol:dS_ndVF_oZHUHogeWAom1<AcoIEM8ocLZ5olo<akoXHYXohU`
Con=Ke3ocjj=olNVNon^RfCo]i=^okZHLon`SVWo/i5/ok2@JOn`TfWo]iI]okZGKonfT6WobjEkolRQ
Lon^REgo^IAXokRBH_o1VfOobjIfoljXMonmU6800_oBZ7D0OooI/G_oeJeiolZQKoo<XgGodjUlolJM
KOnkTFCocZAiom^bP_oF[WSodZYbomFYMoo9WVco_9=Tom:ZO?o;YGSo`ImdolBPMongTFSo^95Yol>K
LonfTfOo[heQolNUO?nlW7Go^iefojb:I?noWGSo^YQcokZGLOncSf[o/8UUoknJM_n`SfWo_iadolNN
LongSEco`iYWol:IJ_nnUF[o]8YTolBIMOo:X77ocjEYolVNKoo:X83o`Z1kolJPM?njUf_oaJ9iokVF
K_nNNUGoZHERokNELOn^SFSoa:Amon33VOnnWgco^YMcolf[Ooo7Y7Oo`9igojj?KonRQfWoXhEWokbK
NoncT6go^YIcok6=LOnlVgWo_9afolFSO_nfUG?oZHe]ojV@MonNS7GoUhIaoiJ3K_nRSG;oYI5hoh]k
IOmLD43oCdHkoeE?AomQFE3oJf1@oi22JOnAPEoo_j^9oi=mH?nCOFCoTgiWoi5oJ_nHQWGoRWa/ohn3
Lon9P7;oM6mTofYWG?mlPWSoDe]@of1ZGomMIUcoMX9foee/HOmGIecoFVUPoeETGOmDHecoE69Loe=R
FomAH5WoD5mHodmNEom>GEKoCUYDodiHD_m<EU7oCEIAodeCCom>DTooC51>oda@C?m:CT_oB4a9odQ<
B?m5BDH00Om5BDL0002`od=TFOm6I5[oBVEJodUTFOm7IUSoB6aJodU/F_m=L5koBfmLodeaG_mBMF;o
Dg=Roe5bGomALF3oC6eJodQXF?m:Ie7oC6YEodUWDOm4HDcoA69<odAPBOlnFTCo@Ee7odEQBom8I4go
BfIDodmRC?mDIdooCFUJoeM[G?mLIeCoFFYHoeeZD?mjLdco`9aRom>LFOo5Vf[oNUlkojj@K?nGOEOo
ShI_ofQF?_n@OEgoFD0[ocdP4_naUFkoajAfokZFJ?n`SF7oWgmDoj61F?nbUV[o[8mUojV8H_nROeOo
_9EYolfWMOo1V6Oo/HmRokbIKOo3WfcodjabolnYNOo3VfKo_iINomN^M_o4V6GodZUaom>YM_o<XW3o
cZ=foljSN?o>YG?odZUiokjDJOo4VfgocjMdolbRKOo?Xg;oaIU^olNNLoo>YWWocjQgol2LKoo6XGCo
aJ1dokRBJOniU6go_IabojR8H_nFMeGoYXMUojb?JOn/S6_o]IAaojn<JOn[Qf;o`9UfokbFKongT6So
^91WokR=Hoo9WWCoaieaokR>I?nkTFKo_iE[ok>9H?o6W7;oe:YiomR]M_oBYG_o/hUVolFQM_o8XgGo
^YM[oknMM?n[RFGo]iIdojR7I?n_SV[oYhIRoi5`BonoWGSo]9Aeoj>4IOnXQfKo[Xa[okVELOnlVWSo
YXIWokNGN?n[RF_o_YYlokfJNonnVG[o_IYeokNFL?o0XGoo[Hibok:EN?nSRFgoXX]aoi9mI_nWUH3o
VHUgoiZ:NOmWFd[oNVmPohf4M_mIDTKoN75Vohf4M_n9O6[oUXI^ohYjHOnGQFooWXUaoiR4KOn<NfOo
S85`ohj4MOn4O6goOWU[og5`HomdM6OoG6ULogb8OOmTL6CoGFUMoeaXGOmKJ5koEfMMoeUXGomDI5h3
oe=RG@0=oe5PG?m@Ge[oCeiIodiMF?m>FUKoCUQDodeFE?m>EUCoCUABodmCD?m>DTooC51>od]?C002
odQ<BP7oATY70Om7BdL00006od9ZGOm4J5coAVIIodMWF_m>Lf;oFhA]0_mIPfT0^?mIQ6WoFXAZoeV3
JOmNQVcoFhEZodmfGOmFPFGoDWUPoef1I_m@M5SoDWIJoeEhGOmKOf?oDgAIoeIgFomGNEcoFGYNoeAf
FOm;IeCoEFMBoeIXD?m<J5[oE6YNoeU[G?mBK5goF6eFohb:HOo8WEooi9]@omB5B_o:TFCohJIfojYe
B?mTC3GoE4Hgog1QAOnEPGCoG4@ooh]dD_o9YgCocjaiolNUM?noWfooZHaLojfBHonjWW?o/8mYoj^8
H?o1V6[o^91IoljVL_o9Yg[o_9]]ol^VKoo=YFOocjIeolVPJOoE[G3oejebomR[N?oDZg;oejiholRN
K?o?Y7WoaiacoljVL?o2VVGobj9dol2FJ_naR5Woe:YholRLJoo=XgSo_YA[olFNLOo<YGGoc:9colVP
LOnaRUooZ89Iol2JL_ndUF[o/I=`ojV;K_nENU_o/YQcok2ALOnZRF[o/8i[ok>=JOn`R6?oaj1goknH
KOnoUFWoaIQ]ol2EJoo1Ug7o]he/ol2FL?niSfCo`YU[olNOKoo7VfgobI]Yol:BK_o0UG;ob:AcolVT
M_njUf_o^YQbojf=JOndUGCo/iIaojV:I_n]S6_oYXATokNDM_nKNf3oYHI_ojR9L_n]RW;o_iUkokVD
LOndU6oo]YAbokREM_ndT7Co^IIiol6LN?noW7Go`Z5kojf>KonURG3o[iAgok2ENOnlXhOoX8]doiR7
L_mjL6?oQGa`ohMnL?n<PW7oMFUHogE/Fon4OFkoUHanoiB7N_n@PW?oS7i_oi>3LOnCOfOoSGUQoiN8
M?n;PW?oQ7]^ogigJOmhMFSoM7AWogIiJomVMV_oDf9GofUhK_mPKF?oFfQNoe]XGomHIekoE6=LoeAS
GOmBH5koDV5Moe=RGOmAH5coD5mJodmNFOm>GESoCUYFodiHE?m=EUCoCeMEodmEDom@E57oCU=@odiB
C_m<D4d2odY>BP7oAd]80Om7BdT00008od5WE_m6I5SoB69NociSF_mAKf?oL8Akof^2NomZPWX2off4
O@0AogB:POmfRWkoE71Qoe5aHOm@LV7oCFaLode[FOm:J5KoAF=AodESD_m5He7oAf5>odaTD_m:HU3o
CVIDodmWEOmAJ5D00_mDJeL0V_mFKEWoF6mKoeM_GOmJKekoGG1LofMfHon2ME7o_Y1FokYf>_nhJ3So
_6a6ojY/B_n4EcOoJT//ohUYBon<KTooZ8m`ofaM>om>AC?oFD`hokJQP_o8ZGooe[1kokRFH_nhU6Oo
_II]ojZ=GOnnWFCodJ=Vomf^Noo4VG[o`9aVoljVG?oFYfOodJI^om:WL?oG[GOofK5jokN?FooBZgSo
dZQfoknIIoo5W6go^I5UolJOL_oCZGOoeJMcol6CHOnoUVGo_HmVokjIN?n=N5OoVgeDojF2F?nmVg_o
cZN2omBTLooBZWSodZiiol^OHOo9XG7oa:5dojj>IOnbV7;o/9YgojV3L?ncTg?oZi9Sok:CHonoVFko
b9UhoknJL_ncTVgoXGQYoiAjJ?mfJDkoQVaKojb8LonnU6coc:5eokjDKonkT6So/hQXokJ@J_neUg?o
WXI`ojj:L?n_RV_o_9AkokF?M?nhUVGo^IMeoj^:IOnmVWOo]I5jojj=M?n`SW3o[Hi_ok>EN?o5Xh;o
bImgomZ/P?oB[7oo`YicoknMMonjVGKo`Z62okZEN_njV7co/95eokJKOon_UW[oY8Uhoh]iKomECTco
Cde@od0l?_l/9bGo@3`goeaHDOmLF4koGea@ogUgHomkMV?oP7E/ohUjMOmcHeWoTh=doiF1LOnAPFSo
SX=WohZ2Kon;PgSoQ7UXofURD_meMFSoJg5UofA/HomSKF7oHV]Tof1XI_mOJ6?oGVQMoeaYGomKIeoo
F6EMoeITFomEHEWoDUmIoe=QGomBH5koD5iLodiLF_m?GEX2odiKD`0:odmKDom;F53oBUM>odaED?m=
EU7oCUA@odiBC_m;CdcoBDm;odQ>BP7oAde900005ollJEKo@fMJodMVH?m4J63o/<FnooKjmoolo?go
oOgmooclo?ohn?Woo?gloo[on_oRl^WoEgEWoe5aH_m?LF7oDfeOodmYFom>J5[oBfEGodYTE_m>IUKo
Bf=C00;oD6QH09WoDf]Koe=[FOmGKUcoFG1NoeYaGomLLf7oFg9QoeecH?mNMF3oGWITogAdFOn>KdKo
[8ARoiYS=oo;RUKoSTlPoj5Y@Oo1Q3ko_HM9oiM`?_oFaIgoXZB2oi2GSolV:RGo1P80obLJ3_nOS7So
]Yn4okbPP?n/Qf?od:Mhol^MHOoHZV?ocjITolRMKOo=X6_of:M]omBNK_o<WF?obY]QoljPI_oAXfWo
dZA[omjbN_oBY6oofJaion:cPoo?XW7ohkJ5om>TKooAWfKof:I^oljPK?noVG;oHd/eoeY3<onbU7oo
SgMSocH^8om6?bkoMedooj24Hoo2Y83oeJaoomB[Ooo>Y7[obZ=hom2XO_nlU6co^i][ojn=GoncS6?o
^YAeofQ5;OmG<R3oXfMAoi]LA_lo9ako6aTNoc/_9om[D3[oSg9Roj^>L?nZR6So/8adojB:MonPR7ko
Wh]loiR6L_n=N7;oUg]]oiQnH?nHNekoY8E`ojb<KonKNEkoYXAYojj<L?ndTG?o[8QVokfJN_ngUGOo
/8e`ok^HM_neRVGod:Ekol6JL?noVG7o`imjokJDLOnhUGGoY8=VoiYnIOnJQ77oPg5TogMXG_mGCdOo
@cllob<S8ol<3@oo7AdLocdg<?mGCdKoETm4ogE_HOmWHE7oKfECogmfIOn0Og7oNgM/ofaPF?nHQggo
R7e]ogQ^Hon2Ng7oRXEioh9oKoln?cSoJ6eVofA_JomRLVooH79aof9`IomJIV7oG6QVoeaXI?mLJ67o
FfMQoeUUGomHI5goEV9LoeMSGOmEHUh00omBH5h01Om@GUcoD5mKoe1LE_m>FUCoCe]E00;oCEUC00Ko
CEMCodiHDom>EU7oCUA@odiBCom<DDd2odY@C00001So>VYHod5YG_m6JV?oB6aVom;PgOonnocoLFe_
oi^IV_mWHfGoPWioofMQI?ooo?colOWeoeabJ?mDM6OoCW9ToeI^HOmBJUgoDf]Noe5YG?m@J5_oCFQI
odiZFOm?JeX2oe9]G@04oeA]GOmHLEooFW=QoeYcHP;oG7IT08[oGgIRoeaiHomKNfcoIg9Roh5^DOm_
BB[o[X5@om2NIOo>WVkoVFi<ogQ48onTMUcoT6mNojZLTonOXIgoJWibof]oLomWMF[oAdm7ob@W8Olo
?CSo7QdBod0b7?o0VGOodZEcom^fOoo9X6kodjA^om^XK?oGY6WobYYOoljPI_oM[WCofZU^omf[K_oN
ZfkofZU^omVWKooDXV_odImZolZHI?o6Uf7ofjM`omjWKOoU[gKociaUolbWL?mlGS3oVGA=ok>2F_nU
PEgoUhIZoienF_naQecoLDl_of9;>OmjI53oSWIKoj:7K?nJO5ooZhYZojb:JOnWRV;o[h]XokF9JOn`
PV;oVG18ohU[DOnXG4?ofGaHoiQaB?maF3WoVg9Boh=TAOn5LVOoV8Yhoh1YE?m<;B7o:A`Goa0:5?l=
2`ko3`T5ocTZ:omYE5;oSWmWohenHonKPgCoVgeaoi=kJon:MFooKeiFohAcGOnORWGo[iAmokFIOone
UWgo/I5eojj=L?o0WgooajJ6okVHN?ndU7Go/Y5doj61IonUSgOoYI:1ogeaIom<AD;o@Ca1ob0X:_l1
1@Ko1``<o``@3olk?CcoI6=HoeYFB?mXI5KoLViQogMcI_n0LfSoNFaModA2;Ol`;QWo:AlCog=SF?mo
N6GoFe9?odm9BomOGUKoHfMCode?Aom^LV_oHf]Uof1ZIOmOK6OoG6YToeaZIOmIIf82oeYXH`;oFfMS
00CoFFEQoeQTH?mGHeooE65N0omBH5h2oe5OG@0<oe9NF_m@G5SoCe]GodmKEom@G5SoCe]Eoe1KEOm?
F5?oCeIAodmEDOm=DdooC59>0Om;DDd0000CocUWF?m0IegoAVeXodI]IooAgmgoo_gnohf@Sona];?o
S92?ojNZZOm/KFgol^oaooOnoOmJL6WoDW=XodmcIomCLFGoDFiRodm^H@02odi/H006oe1/G_mBKV3o
DViPoe=_HOmELF?oF7=S0_mJMF@0L_mKMVGoGGQWoeeiJ?mNNFGoFgaSoeYnK?m[NF[oWHU`oh=F:_o2
Tf?oVf`ioj1gAonQOE?oRg5<ogYQ?on@OF3oFU<hogj1Iom_Q6[oKXE]ofn4K_m`PW3oKgm`ofUcLOm<
GUKoCE4loiQbFOmiCbgoV7eIokN=KOoM[7;oeJ9Von2fO?o@/77odJQcomR]MOoDYFcoeJ=Won6]L?oI
Z6kofjUbom:PJOoAWf[ofjUfolfNJ?oMZW?ogZQ^omfXK_o7UEkohK5_on^nMoo`_gSolkEZonBSHona
NDCogY5:oln0>?n]N4SoHD/ioclg;om>AS[oJV1BofeQD?n1LV3oQWERoiQlK_mlHe;oIDH^oi5Q=oo]
ZV_o[W50olUe@_ohVE_ogiIComfICooUXUoo[8ERocLY8_l/:B3oMfIEoiYkJOmC?bko3`T@o`lC5OlK
60koGde7ofeLGOn6OG3oL6MKodPf;_mhFdOoN69:oad>5?lT82So@48fodM6@omREU;oBc/_odLc:?m4
<2CoH513oeE6>OmNCSkoRGEVojNCP_nYU8CoSGQZofaOE_l_9AkoCdM4oaTD5Ol610Ko1P/?o`/=40;o
8B4O02;o51HFocDg<Om>CdSo=CD_ob@T8?lm?C_oOW]foifDQonKRg3oVhQZoeU7<?mbH4coUGiUofED
A?m?AcgoLG5Wof1UFOmjO7;oN7Y`og5eJomZL6GoJG9WoeiWH?mPJF;oG6ILof5ZHOmLIEkoG6MSoeUU
HomGHf7oF6ARoeMSH?mDHEooE69P0omCHEl00omAGegoDUiLoe5MF`03oe5MF`07odmNF?m@GEKoCe]E
odmHDom>Ee;oCUE@odiDD001odaBCP0001Oo@6EJod=UG_m4K6OoA6iXoloOg_oooOoonOSioo_jnom7
ATKo^;Nhom?BdookoOgolOgkoeQbJ_mEMF[oDWAYoe9eIom@LVGoCW5Sode_H_m>L6?oDW5Soe=aH`02
oeEcI@04oeMeIomKMfSoFWIWoeahJ@;oGWY[09GoGGY[oeilIomNOf?oGh9]ofafI?mUCcKo[XmVoiie
D_nLIcoofZ1VolV>@_nUMdooUFa:oc4E1?mNDd;o:BhSogB2K_mcPVooM89aogF3LomcPGCoOX=eogJ3
Ion;RVGoW6U:oiIQ?on9L4WoOEHYomn`IooW]GooJdPYog=O??o;Z7OoeZmkomN]M_oN[gKoeZEYom6R
JooFZ7?ocj5/olbMK?o=WVgodjEcolbLI_o:UUoodImXom:TKooEX6OooM>CooO>Q?oh`gCofXY;olil
BoodX5?ojYA5omFIGon9KdooKf9?ofmSD?mdIeGoLVECog1TDOmTF4GoHD/iogEZF?miK5?oVFQ0ooB>
EOoWMCSokY1<on>CE_oMR5[omJU/onf[I_nBHCkoF4U5o`d?1omHBcGoWW]MojV8H_m2=R[oW9nDodY6
<OmgI4oo;R0Lob<J6?lF31;oBcPdoj64H?nZQeKoDcHaoa452omKFd_o0`44o`X94_lh=cGoEDm:oc8_
:_l61`Wo?D13oc8`;Ol>2@So;BHSobHM6_ld:RWo30H<oa4;3Om1>cWoB48loblV8?lF4aCo@c`iodTn
>old;B_o8b8Uoa<H6_l83@oo2@hCo`dA6OlK82[oOXR9ojbYVonJNE_o[H9Noj^?K?nIQ6Go[8=TojZ>
K?nKSG7oNGM[og9eM_mULg?oI7=cof1_K_mMKV_oG6eZofM/IOn3Qg_oUib:ogb0L_mOHe_oGVMUoe]W
I_mII6CoFFEToeIRHOmGHf;oEFAQoeAQH002oeARH003oe9PG_mBGUgoDemN00;oE5mO00SoE5mNoe1P
FOm@GUSoD5aFodmIE?m?F5?oD5IBodmED@7oCUA@00004?loIf7o@6MSod1[JOm1L6Sod>3Kooklo?lg
=cOoDe=Co`820_o5aLGo0`<3ooGhm?ogoogoDWM]odaiK_mDLVl3oe1dJ00:odmcIomAMFWoDGAYoe9e
J_mCMV_oE7M]oeEhK_mENVkoEW]^oeMlK`;oF7e`0:CoGGa^oeb1J?mSPF_oGh1bofJ5JomWARSoZ7QH
oh=XAOnHNE[oVflfonFaL_maD4WoVg]AohYZC?mYDe?o>3@Tofj:N?mePgKoOH=cogJ5L?mgQW?oN8Ad
ojBHN?ndPTko_7a2okin@OnoQCoobYEFolf6DooGVF7oWh1Koe57@omQCccoG40^oeU1>_m5<RkoSG5T
ojR8IOo3WWSo_i=[olNLK_o:XFgoe:IdolnQLOo=Wfkod9m]omFQKOoCX6Wol;QkonRLD_oXUDKoii]D
omREDOoUVT_odXe2om:BDOmoDRgoMV=MogmbG_mbIU7oI5U6of9IAOmRFdKoG54logESD?mRGeKoVVM0
om]e?oo8HC_obVHcomQg@?oAMD[ohiEOomnUM?mkD2coXX1Joei3>_mXAc[oXg10om:CDonoVGOoM4h_
oj5lE?mWECKoF5Hloi9iDom<>ROo8APEoj=jH_oKSdko]geCog=L@om`K5co4Pl@o`L;3_lh>C7oI5Q8
ogm^H?m1<C3oLVY[oclo=_m:B4?oEDe5oh1cH_n0LU[o:2DEofi/G?n>RWgoDTe2ocXc:Om5A33oFUa=
oe=KD_mOLFgoLhb;ofQoOOlQ;2ko82P`obH_=omACdGoPg1FoiYlGOnWOUWo]8ALok>2G?nePESo`XeK
ojj?L?nDS8?oKG1dofecO?mSMg_oH7=eoei`LOmNKfooGfi]oemYI_mNJ6?oGVMRoeiXHomfP7coH6YY
oeaVIOmJI6CoFfEToeUTH_mHHV?oEV1QoeMPH_mHHF;oEEiPoeEOHOmDGV3oDeaNoeAMGomEGf7oEEiP
oeAMFomDG5[oDU]Hoe5IEom>EUCoCeUCodiHDP7oCEMB00007OlmJF?o?VQToce]JOm0L6Sod>3Mookl
oOl@413o0`<3ob8R8_n6QXKo3Ph=onCUh_ogookoD7E]odUjKomCM77oCgE/oe1eK?m?M6coCWA[odme
K?mAMVcoDWM]oe=hK_mENW3oEW]aoeQmLOmIOW;oFWmc00;oFh1d0:CoGH1coeZ5L?mQPg7oHhEhofV6
JOnLM57oPdl^oi=dD_n?M5SoYh5@omFSJOlm6Q7oR6Lloc0C0?lN2PcoATHjofb=M_mbQgCoNHMfog:8
MOmfQgOoQXE/okfMK?o7R4Coei=;omZHC_oPXdook;QQonJZE_oJYToo/IAGofMI@om??BWoV89LoeeE
=_l:30Go1`87oc/[9?ln:1goGSlaohESCOnAL5CoSVi<oin1G_nVR6So[Y5eolBXSOnoWgoo_YE^omNS
Moof_XSojJYYoje]:_o7QU?ocY5Foo^jN?nlRU;oSWEDofI;<?mlHTSoSGEKohYcF_n6L5SoPWIRoh]d
H?mNFE3oT5hcomEb>OnoIcKo^V95ohdi7_oARE;oaHYEohA@;onXN4Go]H54ok^:HOnUK3kodhU5omb7
DOo:RdOocYA6ol>BGOmN@cSo^HiYomVLJOniSVOoITlcoiU^@?oST53ofI5Ioj5eCOmbH4Oo6QPCog]_
Jon<Ng?o=BXLogihI_lK60_oG5U:oc@_8_m:AC_o:b<JogI^H?nRVHSoCd51ogIXI_n>OW_oCSdioe50
>onDQh;oVhQnoeQ1=OmZFe?oSXZ<oiZRX?la<Bko8QhRoaLE6On>PG3o[HaYoi5S??nTLDGoYFm3ok5l
D_ngPU[o_Xm]ojbFPombN7?oHg]loe]iN_mQMGSoH79doei`LOmNKVgoGVa/oem[J?mNJVKoGFQUoeiY
I_mNJFGoGVUWoeeXI_mKIVCoFVIToeUTH_mHHf?oEf5RoeMRHomGHF;oE5mPoeEOHOmDGf3oE5iOoeEO
H?mFH6;oEEmPoeENGOmCG5[oDE]Hoe5JF?m@FEOoCUUDodeID`7oC5QD00007OlhJfCo>VYVocY^J_lo
LF[ocn3Noo;`l?o0`<3o:BTYohb<S?o_knooXJ6Qom?Ed_odo_coCGE]odIkLOm@MWCoCGQ_odigKom>
N6ooCgUaoe1jL_m@NG3oDGYaoe9kL_mDO7CoEGieoeV1M_mJPWOoFh=h00;oG8Ai0:3oGHAjoeN8NOmM
QGWoHXEkofR2Hoo2TV_o_8MOofi59?m/DcgoOf91om6PJOnZPFOoYh9Koh1SB?m8>3?o7b0Iofb?Lom_
RWKoLHYlofj:N?mlQW?oY8]OolN?B?o^Y53ool=^onFSD?od/5col:eVooZmKOojb7codJ=eohaSC?o<
ZGCobJAeof9A>?lC4`co3Pd4ocT^8ommJUgoL5A4ohYXDOn@Ke;oS75DogMM@OnJPV_oGddmoaH;1?ld
91coB3H]obdO6?l_5`go`iMToo6gMOoKYgWoPdhLonn_L_oFWfSo]YE^oknTSOn]U7ooT7QVoib7M_n:
MFKoLFAGog=LBOm/IE[o/Gm@ooBIGOn6>1co^GE@oiiS?_nOJeWoU6]>ohIP<oncNdOobhE3okab=_o?
OSkoeg/^omf4=_oVSD[olZ5Xoi]R<onDM4_ocX]@on^LEooVWUoob8UAol^1@OoGOD3oghe<ol61BonT
PVKoK6MHodi2<omgJ5[oDddlohf7L_n0L5OoP6Y>oiZ2J_mlI4_oUWmYoiB1K_n8Mf;oYhUTojj>IOn_
SUooZhQDolZTK_naReOocZ1Uom6RIOoC/X?oO75Eoc</9Om4<bcoDShjodXj=_nENVKo/hm[ojj5H?nZ
O5WoZGeKojj<K_nORG7oS89gog1fL?mSMGOoGGUjoeakN_mOM7OoGg9doembL_mQLG3oHG1_of1/J_mO
JfWoGVYXoem[J_mOJfSoGf]YoeeYIomLJ6GoFVIToeQTH_mII6?oF69ToeQSI?mFHV;oE5mPoeEOHOmD
Gf3oEF1QoeIQH_mGHF?oEV5RoeIPGOmBG5WoD5YG0_mAFeP1odiJE07oCEUD0Om<F5H0000:ocA/Iolh
KFWo>71/oceaK?o?h=kooO_molo?comKFe_o]KFeoo_kn`;om_Kf00GomoooodmgLOm6OGCoCGUgodYk
M002odYiL`0:odelM_m>OGOoCW]bodmlLom@OGCoDWmfoeB1N?mIPWWoFX=ioe^4NP;oGXMm08SoGhEm
oeR:NomKQgkoG8Enof^6Ion@H3SoTf<bokR;J_mJBSWoG4hmokbCG_mA8@7oY7YDoh9QA_lb7Q7o6Q09
ogFAN_maSWgoKXanog:8L?nOU73oa9EGomfKAOoo^5[oijUEooo4MOobZUWojZA>onbgF_o_`g?obYMC
omVQF?oKY4ook;1nohIJCOn[Th?ob;B6ogQQ>?nMOUGoZHEJoj9lD?nXPUCoWh9Koj22G?nWQfSoM5a6
od@e;?mLDE3o;2D[o`D43_lf:BKoW7YGol^IH?nPLc;ok[b4omJII?ngPU_oHdDdob@K3olK4`[o5Q0<
oaD@3olc;c7oFUA@ochZ7Olg=2Wo_I=SonJEFonkLdWo]GMGogi<=?nDKeGoKe0coi5bE?n_N5Gob7]?
ol=h@_nWFbSocGU=ok=S;oo3LBgoaX=5ojEbAOnaOEWodYA=onBKCooQRd7ojHQ4on^2@OoLODCoeHDn
olB9DonYQ77o<BLCoeQIA?lU8AWoU8E/oh]_D?nRMUWoXgEJoi=^ConaR6;oHCTHoi5bE_mdFTCo/Xab
okbBM?n@I47oe:9iolVEJOoGXGCociibolbYPomoJeWo?CLjodlo?_mF?3;oD3L[ofQEBOnNP6SoQFM9
oiZ3JOli7@_oIeI8ogenM_mYOGSoGgn0of1lOomRNGooIWImofIeO?mOLgKoGg9dof1bLomQLG3oHG1_
0_mOKfd03_mOKVgoGVi/oei^K?mMKF[oG6aYoea[J?mIJ6GoF6QToeMWI_mGIVGoE6AToeATHomEIFCo
EVEU0omDI6<02OmDI6;oDf9QoeAPGOmBGU[oDEeIoe1LF?m?FeOoCUeHod]KF001odUIF00001go<6iW
ocA_JoleLFgo?79/oloOgoono?kogMgMomGEeOn<S8con_[jodi>C_oNg]oolO_loe5jM?m5PGOoCWaj
odUkMom:O7SoBgeiodeoNom>P7coD81ioe:1NOmCPW[oE8=koeJ5OOmJQGcoG8Eloef6O@02oeb5O028
oen5N_mLRWWoFhV1oej:Q_m]S73o/8=MokRAE_nMLDko=2dNofe`I_oN_H[oc9]XogA78olg4`;oPVE9
oem5=?m6FDcoKhV1og:=POn7TFko_iQOomjREOob/EKoiJA;oo_=P_nWK2cofIEBonRbK_oH_7[o^ZEh
ookPYOoca6Woo]69oo:iJoncQdGo^IUYokZBIoneV6So]9=VokNDJonCLD_oZheXoj2;I_n/U6koXhIS
ohYbFOmCAC_o9AdKoaD>4olI4AWo=2<Poe`m9ooP]8_oolbAok9nBon^M4?oZh1Goei>=_lb<RGoPhAk
oc<e<Ol>4ACo2@/Bo`T;4?m4=BkoC4a5okB@HOoMVF3oY5dYom:@J?nTKeGoP5XfohEU@?mfEc[oXWIF
ogln6_o2R5So/hEMoi9PC?nTJdoo`HYJoheW?_n@J4Ko]W18omJ=C?oPUUKokYMAoo6CB_o_UEGogXA9
on6ME_oO]HcoH4=4ohikJ?mGCd7oSGa]ojV2GOn[NTco^Xe[ofA5;_mXCcko/I9doknMOOnHOVWo`k6W
ofACDOm>?3KoBc<[of53>?mkEdgoIe98oh>0N_mcOGkoDUEKod0b>om>>c_oG4<ioe@m;OmgIeOoUWeS
ohI^D?mA?ROoU7m_oi^BSOmYNgcoGgn6of5lROmQNXCoHgZ0of9iP?mPNWkoHGEioembM?mQLgCoHW9a
of9`L0CoHG5`00GoH71^oem_K?mMKF[oGFeZoe][J002oeYZI`04oeUYJ?mFIVGoF6QWoeMWIPCoEVIU
00WoEFEToeATH_mDHeooDf9Moe5PFom@H5[oD5iJod]KF?m;FeT00Om;FeX0000BobmaKOl`LVko<W=]
od5dK_o9gmgon_clookmo?ojn?Oo_K^jooonoOomno_ooocoon_koOm?Ng[oB81kodV2NOm9P7[oBX5k
0_m;PW`0WOm=PggoD89loe:4O_mEQh7oE8F0oeF8POmEQX3oF8MooeV7P_mJRH7oFXR3oen6P?mLR8Go
Fh^3oeV9OomNOFSoa9URokbAH?o3VWkoEThloe5QD?nEWX3oTfa0omVNL_n[MTkoXgeFoi9T@?lI3PCo
LHn<off>Q?n`Vg?ohImDon2LD?og[4goh[1EoogLSOoj^VoodIMKoiMnD?n2RW_oP8V6oh>7MOnGWgko
l]2QooWDWoo?Z7OoVGM;ok2=I_naTV;o[iIjoin;N_n?PgCoK7IZogB<S?mjThGoMHU]ohVAOOm8A4Oo
1P<>obDO;OlE30[o;R8ModT[6On_Pd;oM3`Nok9mF_o[/XKo`Y5]okZNO_n1JdWoG54lod]:@ol520So
3`lBoaLE7Om3>SGoNFY/ok>=IOo@Te_od7aHolZ<Kon]MEGoCbL>ohUbDOnLNdKoVgeLoj5jH_nYL4Ko
P4dNogeO@?mYABGoCCH[odm1?on>JeGo_7a;oj=[BOo3PU[o]VXfojYP9oo7S53ogjj@ojf<M?lY7A?o
40T>ogI/IOm^F4coIdXiok>AMOo4X87o`jB7ok^TSOmBAcOoXif<odDo=Om3>CSo91HJoc<S7omIACSo
KEU5odHd8omTETWoJV1HogB5OomUPh;o>TA3oa<91?lX5@coE4HlofYRFOn1MFSoTgYOoj:2I?n]PV[o
Qem<ofQTG_mXO7ooIGb3of=nQ_mQO8?oH7b0oeilOOmMNWgoHGQmof1eN?mQLgKoHG=cof1bL_mQLg?o
HWAdof1bL_mOLG7oH79bof1aLOmPLW7oGW1_oem`L?mKK6`00_mIJf/4oeQZJP0:oeIXJ_mEIfWoEVQZ
oeIWJOmDIVSoEFISoeATHOmCHV3oDV1Ooe1KF`?oC5YJ00001_l^LW?o;GEbobmeL_lfLF_oNj>Qongo
o`;ol_oo0_oaool02?odoooomOoooifn_om<OWgoAh9nodZ3O?m:PWgoBh=n0_m<Q7l02Om=QH3oDhJ2
oe>5P_mBQ87oE8J3oeF7Q?mFQh?oEhR2oeR9P`02oeV:Q02Doef8PomGRH_oFXb4oeb=Pom_SGoo`iQM
ohiQ=?n@KE7oI5e=oe=XFOmRPW;oiLb9okJ0@onFID3oNFILodhd?OmIA43oMHEkohRBMoo9VV?oj9i=
oo6[DOoS[FGoiK9ionJjRooE[7KonL1jojjSP?m[TXOoK9B:ohB>P?mcJEgoME`coiQhEOn_R6WoMe<_
ok6AJ?ncUW;oW8]iohQkLom6A3WoO9J>ofNFTOm[U9;oKhZ=og5iNol=20Ko6A@9oc@/;?l^9aco<R/Y
odL/;onoSUkooL9conRbE?n;BAOo_XMCom:dM?nmXhKoGDm0oc<c<Ol52Pco1PP<o`P84?lO71WoED=:
ok>AJ_neO4Oo]FDfohmG>Om?6PKoY89[obXK5?n0FcgoNe0eoedm:_lU40[oU6mGoja_@?nWMdWoGD8^
ob4C4?mGACcoGSlZoe/l9on6FCko`He[okN8IOnFM5?o90`1obPL5ol?3Q3o3@dAoaHA4?lZ5`goKEI7
oij4LolK0P3oLeQ1oeM0:_nZXI7oN7I/oaHC4OlP4QGo?2LZoe8o<omWD3goQ6QCoh]_G_n1JF;oOGii
of^6POm_S8_o=c/nocT^:OmVDTCoGe57oc`e;?mmKF3oYhU]ohA[COn6IT[oQFIAogR4OOmNPhKoHXB9
of20QOmPP8;oHGj1of5mOomPO7goHWUnof=jOOmTNG[oHgMfof9dM?mQMGCoHWIeof5eM?mPM7?oHGEd
of1dM?mQMGCoGW9aoeeaL?mLL6ooG71^oe]_KP;oFFe/0_mHK6`02_mHJ6koEfQ]oeQXK_mFIfcoEFI[
oeEWI_mBI6?oDf9Roe9PH?mAG5d3od]KFP0001;o:gAjobUgNOlYNGSo:WIbod:2POleKF_o@79^od5d
L?m3MW;oA7Mcod]mNOm;OGSoC8N1odN5P?m9QH7oCXB0odV5POm:QX82od^7P`09odb8Q?m?QH?oDHN5
oe>9QomBR8KoDhV7oeF9Q?mFRXGoEh^600;oF8b708ooFH^6oe6<RomHS8CoEHIoofF8P?oJ]XGo`8mT
ojV@L_lH50[oAeYFof:=Q?n5QgCoZXEXoe0Y2om1=R7o9Ah?ofA=@_mfHdWo[XYBomZGAOoVXdgom;AL
ojMl?omi@QGoOT<JogAC:?o>[g_oN8UjoffFSOm^S8;oDdhoofU:>_n5KD[oYHMXoj>0HOnWQ6?o/8mZ
oj:BOom@Ad;o1@41oce1>?m[T8OoHI>?ofnCUolh@dko<2P/odlo=?mPDCWo9aT>obdV6?lU92Go;1DO
ohAF9OoTW5gob8ETomfOI?o?Vgko^j6<ohmoMOl^9bGo10H:o`H=4_l52Pko20hGo`P>2ol>1Q;oT7QE
ol2=F_oSWF[o]8IToj]iF_m28ACo3@@3ohm`G_nMLUOoPfM:ofmXFomTC3ko`8QVoiE/AOm_EdCo4P`:
oda>DOmYJfWoIT/^ojV7J?nELUOo>1h=od/n=om@BT3o71`IoeEHF?lG61co3PT:oh1cK?nMS87o=28E
okVVU?o8]9koI54moinDR?n>QWoo:QlMod8_;_m@=C7oID`gofaD?On:MEooJe]<ohMiM?mZQhOoHXb8
og29ROlm=SCoHDe4ofmHAomdHE?oTX5eoi^6LOnXQVKoPV]=ofeD?Om4;agoK85noeN2R?mGOXKoGH:8
oej1QOmOPHCoHH23of5oPOmQO87oGg]nof9kOOmSNg_oI7Ujof1gN?mRNW[oH7Qhof5iNOmNMWKoGgMg
of1hN002oeifMP03oe]cLomJLW;oFg=c00;oFW9b00goF71`oeM]K_mIJfooFVa`oeMZK_mFJFgoEFQ/
oeEYIomBIVCoDfASoe=SHOm@GUkoBU]K00;oBE]K00004?lXMG[o:GQlobYkO?lZNgco;genocAoOOlh
Ogco>X5noc^3OolnQH;o@8J3od65Pom1R8;oAHN1odV7P_m<QXD5od^9Q006odb8Q?m>RHGoChZ6odn:
Q_mAS8SoDXZ70_mESHP3oeB<Q`29odj>S_mGRhCoFHb8oe^9R?meH3Oo^h]QofMG>?m8@c_o@DY;of>?
R?mNS8_o/J2<ojQlFOnDMe;oTgMEog1=<On]O57odi53onVP?oof^V[omL:8oog2O?o__WKofZIHon:d
N?mmTHGoK9F9oeiJE?mH@C_oGT`koiB6IOnJPEgoVWeKojZ;K?nCN5_o[9AioiR@R_le<SSo3PT;oa0F
3omLQGkoIY6WodaUJ_maLEWoBSLNodX`:Om=<booAB`_odTm<olM6A?o9Q06oljQE_n6AAgoTE/eojUi
COn>Kd_oEde?oda4@_l_:b_o6a/NoaXN8OlO8BGo82H]oaDO7?l<2aSo/9aioh9?6onbKTSo@aP8ojAd
F?n:JeGo4Q45ohefF_moI4[o;a<1okb<D?n7H3So60`5oc<U5OlK6AOo00<7o`P70_m=@Bgo^HEColnL
Jon;HS[oTGQSodLm=om6B43oFU]Fod]=BOlo?cgo6QHCod0h<olQ5PkoDD@gogESD_lo:aGoS7aUoj^Q
TomhKVKo<2<PodDe<_m9=C7oH4@kofYPE?m_Mf[oKhElofZ;Q?mLS8koHi6?of]lNom3<c7oIDm2ogAO
Com[EdSoOFYJoiEmI_nPOEkoWX=Xoh5PCOnLOFooNHF5of:7T_mPPXcoG8::oeb3R?mOPXKoGh:4of21
Q?mQP8CoHGj2of=oP_mTO7ooHg]lof=lO_mRNgd00omQNW`01_mRNggoHGYlof1iNomNMgWoGGMioe]e
M`;oG7Eg00goG7AfoeYbM?mHL7;oG6iboeU/L?mHK73oEVU]oeEYKOmDJVOoDVMToe=VI?mBHf;oCUmM
00?oBUaN00004?lYNGSo:g]jobmlO?l_O7co=7j2ocN0POljPGoo?H>1ocf4POloQXCo@HJ7odB3ROm5
QHCoAhR2odR9Pom9RHT5odR:QP08od^9Q_m<RXOoCH^8odf;R?m?SH[oD8b8oe:>R_m@S8P2oe6=R@2;
oe>=ROm>SXooFHZ4oe^?SOm>RXco/K2:ogi@:?n`YhWoHUI=ofURH_m=LFCoCiN3ok:^RonCId?oUWQS
oah60on8GC7obhUAon6FA_o/[4kok[Qdomn^PonJKdOoX7M;om6PIonQV7?oJIVJogR:OOm_Cc[oM4`l
ofaD?on9M4goWWeGojZ9HonWS6coVXQ`oiR=Oolc<Bgo<2dcoc0W:?lO8QgoJi:AofJ;U?lP;BWo?2`G
oh9TBOl^5PcoHdPhog]LEOlN3`KoG5=;odPU5onfNcGok[9ZooS9N?oIZWGofl21ofUSComWIE_oEU=:
od8n>?mBDDkoAdI7od95A?lZ<bgo8R</ojJBK?oR[WCodY1NogaB<OnGIT;oK4/co``:0on1JE3oU75D
ojZ0HOndOeKoaiM`ohUVA?nUQ6Co7A@>o`l?3_mD@2Ko`91Lon:HF?oJVUcoRU/ZoiElHOmABD7oGE]D
odQ6?Om`K6?oM79Xoclo=?lO6Q;oMVeToiZ=O_lo;Q[o[iQnojVDN_lL4@SoUXYoodLn>Om2?3SoFeYF
oeibLom[RXgoHXb>oej?U?mNSiGoGXfAo`h[;?m4B4OoB3<`oe50=Om/FdkoKea?ohikJon1JE?oX85T
obhH2?moHT_oQVUIoeESH_mOQHgoHHJ>oe^6SOmLQXcoGhN;of67R_mQQX[oHH>7of:3R?mTPhKoI824
of>1POmROh;oHGj1of1mP002of9oPP04of5nPOmPO83oGgaooemlO`;oGGYm00KoG7UloeYhN_mJMW[o
F7AhoeMcM_mLL7@2oeU^L@;oEfa_00KoDf]Yoe9XIOmBIfCoDF=RodeOGOm8Feh2odQKG`0000Oo:Wai
obemNolbOWgo<gemocN0P?ljPH3o?H:000;o?hB200So@HJ4odB7Qom8QHWoBHN6odZ8Q?m9RHKoBH^9
odJ;QP;oB8Z600CoB8V6odV:Q_m;RHOoC8Z80_m=RhT0Z_m?SH_oDHf<oe6>R_m?Rh[oDHf:oe6=RomA
SH[oD8f>oeJ;R?mFShgoDI6CohJMPonkU6_o<bD=oaD91?mKDU7o<T8fodbDT_maN6WoPEm:oe95;?lc
9A3o^hA>okec<OoaY5[ojZaSokn;BOnkQDWoGD<PohmRAonPP6KoKIJ<offBS?mLD4;oNei2ofmF>Ome
FT7oVGADojN3GOn[SFWoIE4eoi27Mom0?3WoB4I3od50@olV7Qoo?40log:HUOmcThOoT91lodlb;ome
FUGoA3@LohMcEomZCd;oIeM4oe12>?mQ=BOodI55ook:R?n@DBoo`iE;om^kU?mjJ5ooNgESoeQ?@omC
BD;oFEE>og5`JOmFEe?oA4Q1oda;D?nRTgKom/N@oieT;OnfRU[oV6<ooh9NAolJ3aOoJUE4ofTn9OnC
JeKo9P/6ojYlEooAQDgoaHMGod`e9Olg:b?o/X]UomZDC_o7P4?o_817olVNLomKB33o71HAoeM?A_m>
AC_oPW]]oc`g:_mdLVGo5Q8:ofiVFon>P7;oYiF0ohA]E?njY8Wo^JB>ok2LR_mUEd[o7a/CoeeZI?mF
TYSoE9:JoeF?VomLSigoHXjNof:<TolkEeGo>38aoe8i=omGCdKoI5A<of1=@_n8N6OoMVIBohMaG?nE
QFkoXX9Yod<a6_mmPh7oGXfAof2;T_mLR8ooG8V>oeb8S?mNQh[oGXN9of26R_mQQh[oI8N9of:5QomT
PhKoHh>5of>1PomQP8?oHh64of>2Q?mQOh;oH7j1oemmPOmPOh;oGWb0oemnPOmMOGooFgYnoe]kO_mL
N7coFGIjoeYcMOmHL7?oF71boeM^L?mGKVooE6a[oe=YJ?mBJ6OoD6ETodaPH?m:Gf7oBUmR0Om9Gf80
0009obamO_l]OWoo<H60ocB1OolgPgoo>XF1ocf5POlnQX;o@8R400;o@HV500coA8^5odB9Q?m7RHGo
B8Z6odZ:Qom5S8KoAX^6odN;Q_m7RHGoBXZ7odb9ROm=RXX2odj;R`04oe2=SOm?S8coChb<odn<S0Go
D8f=0_mASXh0O_mOT8Soc[>0oij6KolB3P[oIFYRoe56>omMVi;oH8j1ohf0OOmVESco]HA@olR;@OoJ
WU3ogJAGol>AEOnGL53oZ7];onJ_JOoHZW7oQin0ofbMTOl]:ROoIdm1ogiUC_n8JdkoUWIHojB2IOnZ
R6[o[9AioibDPOmJFE?o<c<eoc@_<ol_;c;o3`d@oaPO7om_UH[oFfERok>RO_l]40WoI5ABoa070omC
@CCo:QPHocL[8?lf:bGoJT<jonF^KOoY/gkol;Ulom6]P_mLBSGoUXEhogASCOmIAS[o?bdXoeYAB_ma
LVKoJFYUod4n>_lk>3OoDT]1ohYXA?n`Q6SocYAMol]iB?o0Od?o=ATEodm6=?m3:AgoUGQNok:8I?o9
TUGo/F/lok1iDolj9QgoETDmok^<H_oNTdco`HE<on2ZN_nUOU_oT7QXodm4@On3N6coMV]MogU_HolK
4`koJ65Gof1KDol`:AooD4@hof=C@_ngY8oo>28@ojbBPonRQW;oXhmmoh1lM?mNK6_oHXfGof:?VOmO
SiSoGXnIoef@W?mHRY7oIhJ5odE1>omE?cWoH5YBof1:AOm/ETcoQGMWofUPC_lI3@Oo:Q/<oi][D?m<
>AgoZIREoej>S_mHR8koF8Z?oeV:SomJRHkoG8V<oeb9RP;oGHV:00KoH8R:of27R_mPQHWoHXF7of64
Q_mPQ8D2of23Q@0Gof23Q_mOPXKoGh:6oej1QOmMP8CoG824oeZ0Q?mKOh?oFGb0oeUiO_mHMg_oF7Eh
oeQdMOmGLG;oF71`oeI^K?mDJfkoDVY/oe5XJom@If[oCFEWodeRIOm:Gf800Om5G5l0000GobioP?l`
PH;o<h>2ocF3POliQH7o?8N3ocn7Pom0R8Co@HV5od::Q_m3RhOoAHb6odB;QOm7S8OoBHb7od^<R?m6
SXSoAhj8odR=R?m8S8OoBX^7odZ:ROm;RhX00_m<S8/01?m>SXgoCHf<odf=S?m=SH`6odj>S@29odn?
SomISXKoTG]<okBNQomHEDSoOXEdof=KAOmTNgWoA9J8ogJ9P?maCRko`XE3omF9=_oJTDWom[aWonFi
G?nYP5Koe;F9ombTN?n[YXSoGiV6ofE_K?m;;bWoOfA?oh5TB?nALDooYX9PoimkG?nGNeooXi5moh=k
Kol61@;o2`X=o`l:3_l20`Go1P@7o`T;3OmTQWgo<1lHojb>JOmM@C3oOVaGofmH=on@N6;oMVAJob`Q
4olK51OoECU3okR;H?mQ;PSoVVPnokBGNonKSh?oKF1DogaYCOm[ET3oK5M;ofUJD_mLEDcoGeiIodQ3
??m=B4OoDda5omFgV?mkCbooYGU7ogY:<On[QEoo90T8ofQFA_nAN5[oM4HgojMc?_o4SFKobY=ZolVC
Jon2HTkoB3<Uok65HOoESdkoeiUNojed@On2EBgoOV==ob`O6_mUFD_oAST[ogaaIOmmLfWoJV9God<l
<_n:PWOoUXYkojJEQ?mXE3koUH5[oiB2L?m6=2Ko?S0Tocdj=_mDFUgoEfEVofAgNom/QhkoIhbFof:>
V_mHTI[oHY2@ocQ3?Om<>cKoFdm6oe=2??lf9AgoO71Qof5EA?nMS7goYHedokF8I?nOQF7oRXn4oeJ@
SomCS93oF8fCoeV<T_mIRhooFXZ=oeZ:S?mKRH_oFhV:oef9RomOR8_oHHV<of67ROmRQHWoH8J8of66
R?mPQXP00omPQHP05?mOQ8OoGH>6oeb3Q_mLPXGoFX24oeYnP_mJNX3oF7UmoeUgNOmHMWKoFGAeoeUb
L_mFKVcoE6]^oe9ZK?mBJ6coDFQ[odmVJOm>I6OoBf9T0Om8H6<00007oc>4QOldQHKo=XJ5ocN5Polj
QX;o?HN3od69Q@02od::QP05od>;Qom4S8So@Xf6odJ>R?m8ShT00_m9SXT00om5T8WoAhn9odR?R@02
odV>R@?oBhf;0_m<SX`00om;SXkoBXj?odZ>S`03od^?T0CoC92A08?oEHf:ok^[Som?>S7oBDA1ofme
KOmSGeCo:RT[odNLS_mkSgco^85@oln6>oo/TDWohI5:omJEH_n]MU?o/814ohiT:_mcGD;oI9F6od]Y
I_m69BCoIE<nogQL@_n9Jd_oWgiJojZ6HonVPF?oOF]Boib@P?m:A43o9B<TocDa<ol/:Rgo4Q<EoaHA
5Ol;2PgoM9::ojJ:OomkGC[oVH1]odP]4_nVQeooTGQVoblL5OmQEd7o@Sh]of9A@_oYb8GomlZJon_1
TonoZhcoT8Yeoi26K?n?OfCoOFUAofYF@omPD4CoEDY1od<o>Om=@ScoAShkod0i=OnnYhgoeZZ8oiem
D?mHAd;o>c<RodHa=OmZDC_oRFXooc/@2On=JTCoFdDnoal=0On[MTgoZg]Iodd_6onMN5_of9INomBC
Eoo0P4So`XaNohYXComDA3coOFiPog5SDomkKUkoT8Eioe98??lk<bSoM6]Ooj6CPomJB3GoKeU3ok6H
OonjXHGo_:>8ojNANOnQT7koBSdaodHl=?m=BdOoD5UJoeiaM_m^R97oII>Ooen?TOm9H5go<b`Yode0
>_mTF5CoED]4oh9fK?m^GDko9Pd2oif1Jon`R73oGcXWofJ1OOmBSIWoChbLoeB<U?mCRY3oEh^@oeR<
T?mIS8ooFHb=oeZ;SOmKRhgoG8Z=oef:S@05of29R`0Aof28R_mOR8[oGhR:oef6R?mLQHSoFhB6oeb4
Q_mKPXGoFWj2oeQlP?mJO83oFWYloeQhN?mGMGCoEW9`oeE`K?mEK6l00_mBJF`01?mAJ6_oCVIXodiU
J?m:HVD1odYUIP0000Oo=8F6ocF6QolgQhKo>XR5ocf9QOloRHGo@XZ600;o@h^700GoA8b8odF=ROm3
ShOoA8n8odN?R@02odR?R@05odFAROm5T8WoAhn9odV@R_m:T8X01Om<Shd00om:Si3oBI2AodV@T@03
odV@T@CoBY6B08?oDXj;okbcV?l]6a;o5a4Aoa@J5olR81go0080of:@QonLQVGobhXnomF9@?oQXE;o
ZW/god@T4_lO0`coN5U;okNCM?n6V8CoHY6<ochb;_meDD7oJUa1ohA[ConNQ6?oXXARojJ5I_nOOV?o
DTL`ohb5O?mHEESo@3e3ocLa=?m4@TGo<30cob@M8_l]:BcoL8N2ohamKonCPfGoJ4m6ojMoH?n_SfOo
6`X3ogETH?moL5[oE4/ioea8=?oN^gCoXW@iohiU=omJAbgoPWaZoj>FOOn8Nf[oNfaIofYJAOmaI5;o
IUi@od8l=_lW6A7oAc`hoc`f<ombHDooK4XYojek?_o=RUco^hIBod<Y9omFB33oQFY8ohmcIomI@S?o
IE=2ob<=0On^NTgo/WA6ohEOA_mnGdSocI9QomRGFOoXXVKod9=PogiE>?mLBT7oHU52ohAdHomREDGo
S7m`obLL3_ld:QooThUkoe];>onhYI3oVH1Yog5G?_niWhOoA2`GoiN0IOmYDcSoTGaRoh=eIOm2>Bco
Ddm8oe]JF?mNHVGoIg^7ofN;T?mSOh3o0`<6ocH_;olV8QooF5=?ofiTG?mG@SCoQfUBog]MB_lP1P3o
]8Qooen=QomBSI[oE96PoeB?UomCSYCoEXjCoeN>T_mHSY7oF8j@oeV=T?mJSI3oFhb@oeb<T005oej:
S@0Goef9RomMRH[oGHV:oe^7ROmKR8SoFXJ7oe^5Q_mJPhGoFX24oeQnP_mJOH3oFWaloeQiN?mGMWGo
EWAaoeAbK_mFKG3oDfY]oe9ZK?mBJ6coDFQ[odiWJOm=IVP00Om:IfL00007ocF6Q_lfQhOo>8R7oc^9
QolnRXKo@8Z7od::QP02odB<R00<odF=ROm5SX[o@i28odF@ROm7ShWoAi28odR?ROm4THWoAI29odJ@
R_m9TH_oBY6;0om9SH/2odb@SP03odZATOm8TY?oB9:C00?oAi6B08;oB9:BodRBTom8TICoB96Dodn@
Ronm_9KoUXI`od]4=om2B3go81hFo`H?1OmnQ7OoaH]LolEo9_oFS4CofXm@oj=W??nKLTOodK1^ok21
B?mlI47oNiN7ocHk?OmWCT7oNV]<ogUIAOn7LeOoWXU[oiYoG_nWR6_oXhQaoiZEP_miMW3o=CDjoaXH
7_lM5A[o9RDVoaLH6_lL5A[o:B@Yof9eLOn7RGWoG5Diof93?_nOLE[oWX1OofIJB_mZFE7o>bTKoe93
@?m[CE;oTfDiooc=V_oicZCo/if>ofQMEOmcHECoEdm5ogQ]G_n3MV?oNg9NofmXEom0>C?oA3@/oeE8
A?mBBdWoQGMVol^ZQOnWPU;oQ65<oheiH?lT6bKoE4hcogm/F_mA?b_o9@H0okN8Eoo4S6?o^hUNolR6
E_naQfKoCc4Qol:<GooHUUWodXa=okQg@?n=HT3o>RDJogi]F_n1L5koNVYJogiaHom/H5?oMfePoeM;
?OnCPg?oZ9J0ogeTCOnbVhSoBCP[ojFFP_mMCcOo]JJ=ok:RR?n7OfgoED`nofAJD_m;@3go?C4`od93
COmUO83oM8b@oaHL8olT7bGo2`/;oa<A3_mHCDOo>B<FojB4KOnQQVooRGELojZ2L_mMUXCoFiFFoeJB
UomETIWoEI2GoeF@U_mFSi?oEY2B0_mISY82oe^=TP03oeb=T_mLRhgoG8^=00?oG8^=01?oFhZ;oe^:
R_mLRH[oFhV:oeb8ROmJQXOoFHF6oeZ4QOmJPXCoFGj2oeUoP_mJO7koF7YioeQhM_mFM7;oE79^oeM_
L?mDJfgoDf]]00;oDVU[0Om>JFT1odiZJ`7oBVQW00002?lfQX7o>HV4ocZ9Q?lnRXKo@8Z7od6:Qom4
S8SoAHf90_m6SXX00om8T8_oAi26odN@QP03odRAQ`GoAY6<00?oBHn=odZ@S_m;THl00_m;THl0R?m:
TI7oB9:AodRBTOm7TI3oB9:AodRBSom7ThkoAi:EodRAV?m7TiWoC9>DodmB@OnIPg;oJU4mof1OD_mJ
CCkoFDljokJ@Joo6QDWoaGTbomB<A?oAUEWoOeDgofA4:OoJ[G;ojK5XojbEJ?m/IUKoCT4iog5PCOmj
He3oK550ogQTC_l/7aKoOUi2ojZ8K_m2>2koQI:<o`lG4ol?5ACo0PD6oa0?5?l;3`[o:RP[oaH?6?lM
6R3o?TA3oeADB_nMPE[o`iYdod0S5omH>bKoS75Goee7=OmGAS_oIF1Noi^2J?o]]GooU5/dooG=Soo<
[Hco[9Amoj6<N_mgKeWoO7ASog]bIom/I5?oJF5<ofEHD?ld;B;o;2LSod]0?_nKR6oo_j1godXT5omB
=1;oUXA[o`l:4_mOFdkoOG1PohA/E_miAR_obXUOolF=EOm=;QKoQfQFol:FFomI@3Oo/HeRolfEH?o7
PdOoa7m4okb6FomjG4?oLETnog5LA_n<O6goDdPmog1ZGOn=QgSoJF1@ohf1KomIB3;o`:bCofA?>oo6
[9Oo/I1UoknYPOo0/9_o;aXBohUnLOlk<BgoFU9Aoc`f<_mIEDooGemIof]aKomjPX?o<blbocTV:?m:
BDSoEE17od/f9?n=Lf7o<A/CoiJ4M_lc60ooDDPnofZCTomCU9_oF96HoeRCVOmHTYOoEY6CoeNBTomI
Ti<2oef?T`03oeb?T_mMSi?oGY2C00CoFHn?01SoF8j>oeN<RomHRh[oFH^:oe^;RomLRH[oFhR:oeZ7
R_mIQ8SoFX>7oeZ2Q_mJP8CoFWenoeQlN_mFN7OoEgMdoeEdL?mGLFkoE6i[oeA^J_mBK6WoDF]Xodi/
J?m=KFP1od]ZIP0000So=hN2ocZ:QOlkRXGo?h^7od6;R?m3S8WoAHf9odJ>RP;oAhn;00?oBI6<odVB
ROm9TXT00om8THP2odJAS005odNBSOm8ThkoB9>>odV?SOm:T8h00om;THl0R?m9TY7oB9:AodRBTOm8
TY7oBI>BodZDT_m9UI7oAYFGod>CV?m2UYOoAiJBokNnZomjJ5coGTa0ob<T7_mB@SOoCCDIolBAI?o0
Lc;oaGPdom2DDooMVecoFDDjoaD;2OoIY6WolkA/olVYOom;=RGoHDa2of]I@_mMBc?oMfAAogaYFOm8
=bWoQfaHoh1VE_l@20CoMY>5oeiUHOm1=CSo91LNobPT9olO8Ako<c0eob8L9?lG51[o=CDdoi1fJ_mh
Gd[oV7MHok>4GOnjUFWoTgiMogIPC?m8=bKoOWEPoknTLooO[6Wo_HaConO2VonAN63o/j2GoiZ=L_m/
IUGoEe55ofiWG?mSG53oIEm>of=GB_mGD43oEe=>oahC5?noZIOof[20omn]P?nlT5CoZX]Zob/J:Ol8
10[oMgA]odHh:?n3ES[ob8MLokj6DOlU60coDd8fokVBI?mkIE[o]95[om2KJ_oNXFWoc8iFokR9GomN
@b_oHDhhohMeH_mdHU?o<B4FofYMC?m^HU7oQgQWofmNBomA>bCo]If4ogeWD?mmI4kob:N=ohMaG_o7
]ZKoGdXfof5A>OnBQG;oHUI9ogQaH_m`K5[o7aXDofAWHOln@cko>CXfobPP6om6=RWoJ5Q9oiB3M_mI
Ac_o;Q`CoiR2LOmF=b?oJei@oej7QomEVJ7oFYJNoeZGV_mHUISoFIJGoeREUOmGUI82oe^CU@;oG9>E
01OoFi:Doe^ATOmKTI7oFi6AoeZ@T?mIShooF8j<oeZ=S?mKSHcoFhb<oe^;RomLRH_oFhR;oe^6R_mL
Q8SoG8:8oe^2Q_mKOWooF7ajoeMiMomHN7CoEgIboeIcK`02oe=`K004oe5_JomAKFWoD71[odm_JP7o
Bf]W00002?liRHCo>XZ5ocb;Q_lnRHKo@H^8od><ROm5SHWoAhn;0om8T8`5odNBR`GoAi:=1Om9THh0
0om8TY7oBI>BodZDT`02odVCTP23odZCT_m8U9CoA9FHodBJVolmUI;oBIJAoh^BPOlO50go5`d9oeQK
F_mF@CGo_XUFomB9C_o>LbkogX]2omFECOoEUe;oZgYCoah90?mND3KobjQnolVSOOmYBcKoGd8hofA>
>?mXF3ooPGAPohelHOn7LUKoQ79IoiV9M_n2O6_oL960of]/Iom<<cWo=1hTobPQ9OlK6ago6APMoaPG
7Ol90`Wo4@/;ol:JM_m4;17oOfA0okZ2E_o:WWco<1X5oj>>L?mRDT;o^:BBokVDM?o7Uf_onm>@oe4_
5?n9MFGo]jVYogA]DOm9@cOoF597ogA^H_mQFe3oIEmCogEYF_mTGD_o>cLbocL/;_n[UHKoa:5eokB8
G?n6F4?oT75VobTT6_lA5a;oCe=Boe1;?omE;Q[o_G]AokUg?_n`QEko[HIOoh]F:_n4MV?oVhQdolJH
K?oRZgWo^85=okN;HOm_DS?oQ71Log1NC_lQ3PKoNVQJogETDomiIe?oA34OohA^F_nORG;oUh1YojjI
P_n[UGoo]YV9ob@A3?mGACSo_JB7okNRSOnbX9;oHE=<ogecK_n2OWKoMg9[og9aJ_m_LVSoKG9XoeEF
C_m3?SWoGeMCod<d:_mZDT3oZXAWof]=<?nBLU[oWHanog>GU_mKWZKoEYFKoe^HVOmJV9SoFYNGoeVG
U?mHUY800_mJUY@06OmKUiGoFYJDoeVETomMUICoG9BDoebDTomKTi;oFI6@oeZBSomJTHooFhn>oe^>
SOmKS8coG8Z;oeb9R_mLR8WoGHN9oef4QomKPXCoGH21oeYnO?mHNWSoF7QeoeEdL?mFM7000_mDLVh2
oe=aK@7oDG9]0OmAM6h1oe1bK00000So>XZ5oc^;Q_lmS8Oo?XZ6od6;R?m4SH[oAXj:odN?R`;oB92<
00?oAi6<odJBSOm6TXd00om5TH`5odNBS@GoAi6>00?oB9:AodVCT_m:U9<00om:U9<0P_m7UIOo@YNI
od2GV?m;VYOoDi>@ofU/GolS61Wo4``;odU9@_mC=Q_odHQ9olAjA?o8OTcohiePooFbI?o^]fkog9=>
olnNLOlI6Q3o7A<3oi5`C_mK>RSoAb/Roea9=_mcIU?oQg]/oi:1I?nSRfSoJf19ogIcI?n>QWCoHF]Q
odM0?Om1;2oo>BL[ob/Q9?lD4AOo0@08oa0?5OlH4AGo>bl]ol6ON?oC]H3o`jAeojb2I?noUh;oZXYY
oib6J?mmKUkoajNAogA8:_mI;Pkofk9kokfMM?n^W8WoE4I3oe16>Olm<RWoN6iOogE[F_mkLF;oMFUP
ogIYG_mVGe3o7QXEoc``<OmVDSko?R0Roi5aEOneTFgoMUhlo`/;0_l;31_oDE1?og9^GonWP6Go_GY@
ol=h@?o>QdSobHQ<olV7FOmEAb_oTXQookZCK_ngQe[o_hUFolZHI_nhSf3oF3hUoc/V5_mOBckoIe=9
oeM7>OmcHE;oQWASohejJOnSTGooTh1_oiB1L_le8QKoZ99lojNGR?mfI5?oZXabofaFAom_G5Go9ATJ
oh1jO_mYJ6_oSXj<od11??mFFDkoH6EKoeaQG?le>d;oBD=1oh9ZEonKMUSo[XERoj>:K_nTRWCoZ9>7
ofV7QOmPW9goHIbLof:JWOmPVI[oHI^Jof6JUomPVIH3oefIU@0FoebHU?mKUi?oGINFoebFUOmKUICo
FIBBoeRBTOmKTi3oFY:@oeZ@S_mLSXgoG8f<oe^<RomMRhWoGHV8oen8R?mNQ8KoG8>4oej1P_mKOggo
FWajoeYjM`;oF7Ib1?mFM701oeAgL@7oDgMa0OmAMFl00007oc^;Q_llS8Oo?Xf8ocn;Qom2S8WoAHj;
odN?R`03odR@S003odNAS?m4ThkoA9>>00?o@Y6<1Om7TXd5odJBSP03odRBTOm9Ti;oBYBC00;oBiFD
08?oBiFEodNFV_m3V9_oA9FHodjATOmWVi_oEeA>obHI8?lS6a_o3P`2ojN2FOnlN3goZ7ADod<M3_nK
L4_oZg8Zoo32Moo5TECo`i5Nom6`P?n4LeKoTgeRofM=>omC>SGoFDLhogQZGOlk<2[oNFMKoj63K_mD
BDOo10D;oaP:2?mA?cgo@CDbob/R8?l]9B?o;2<Toa/G7_lA41So61PNobLO9?lE1`KoaZjSohaS=ooi
eJ7oO6]BodDZ3?o3VW3oIDljoi:3LonUP5Cof:eZolBQH_md@akoi<N:oeQ2;?mJBT7oFD]=odhm<on0
LF3oSGiYogi^GOmoKfCoIUQCog1YGolZ9b7o>Bl/okVTRom^F3go_j=]odTL1onUOfkoDD@aobDK9old
;BOoR89_oiUbE?nnO57oagi;olJ?FOo4SU;obhMOogYW@_m]FU3o[X]]ok^AIoo>V6Coijmbom6JGOnS
PV?oJ4`hohaeJ?m;>S7oMfUQob8B1?n;NfcoFDTlocT[7_m`HUKo>2TQojjLSOnYUgKoPWQJofiNB?o1
XH_oQ75IoeY<??mSGECoTY:>o`dD3OnAV9[oKG9_ogAfL?mmOW[o<30bodM1@ombF4WoXgMFojMnGOmX
EdKo7QT=ogUSD_le8Q_oPifIofRNVom/X9coJYfPofVLWOmYVi_oJ9^IofJKU`02ofFMV00Kof>KUomQ
VICoH9RCoefIUomLV9KoFiNEoeVEU?mHU9;oFIB@oeVCT?mITHkoFY2>oeb?SOmLSHcoGXb9oej:R?mP
RXSoGXJ6oef5Q?mOPX?oGX:0oej0O_mMOG[oFgUeoeUiM?mGMg;oF7Qd00;oFWYe0_mFNW@1oeAhLP00
00So@HZ2odB<ROm3RXooA8ZAodJ<S_m7SX[oAhn;odVAS@;oBY:>00?oBI>>odFASOm5THd00om6TXh2
odB@S02[odFASOm6TXkoAY:>odJBS_m4T8coAY:>odFASOm7ThooAi6@odRBTOm9Ti;oBYBCod^EU?m8
V9GoC9FGodbAWollW9koDY68ohn8PomB>cWo=bPVoc<[;Ol/5R3ob9QAolYo@onUL4?o<1<0oi=]C?o9
QDgok[=GoiQNGongREOogJY[omV/Moo7Y8WoH3lfofQ;:?mZCTWoNV]Fo`/12Ol<1`GoSH5Xoh9aG?l/
81Ko<bdTodHm>?le;2Oo<BLUod4g=_lW7Aco3@`?oa@?4Olj=3;oCTE0ob@I4onHPFSog;jQon;1V?oc
ci?o/XUBolVTM_n=KU_oNEdholb^Mon2FcKomLQmoo_8PooRaYkoY8]aojbFP?lg:acoB3P_og9ODOn3
KU[oOFYBogi^FOmiKUOoMFaSoa892olf9R3o]IYoolV[Q?o@XW;oN5@eoi1YC?mkHdooD4a;oc/^9?mm
O7KoACX[oiQ^C?nlPUOoE2lQokR6Com26Q[oXYI_ohM^E_n2JeGo]IIkolZIL?oIY7OoUg9Aoj5mDon1
GdWoRG9VocLV6?mgK6GoKUiAoiB0K_m^FdOoRgUUofiLBOn4M67oLF5AochZ7OnLQG?oXI1kohIhHOn8
LV?o`[6JofaQB?nTX9;oU92AoiJATOn0Oh3oEUYIogEjM?mQI5SoCTU7oh9ZF_nPP6;oRG9IoeQ5<omD
>BOoXhQeoiB2L_n@UhSoOj6JogBTX?mcX9_oLYnJog6OV_m`XI_oKInHoffPVOmYWYOoIIjGof6NUomM
W9KoGIZCoebHU?mJU9?oFiFFoebBU?mHTiOoEi>DoeNAT_mJT97oGHj@oeb=SomNRhkoH8Z;of:9R_mS
R8SoHhJ7of:6Q?mQQH?oHX:2of5oOomNO7coFgaj00;oFgej00CoG7ikoeYlN_mMOGSoG7eg0OmKOWL0
0007odYaJOmERH;oAHb6ocj>SOm1SXkoAHj=odN?R`03odVAS@03odRBSOm5THgoAI6=00KoAI6=0_m6
TXh00om7ThooAI6=odNCS`02odJBSP2TodRBTOm9Ti;oBYBCodZDTom;UICoBYNEodNHV_m7UicoE9BF
odiVHOlT6@koAb/Xob8=3OlU6a_o=B4^oi=[>?o4Q5;o[H1Noi9O>?nfNT_oPEPgom6QJ?nmUFGo]YEI
ojUoDon>KToo/j5eodX`;?mIA37o;1HRobhW5?lX8b?o91dCoi:1I?nJPFWoVhAdoiV:Mom4?3[o9A`L
oadD5Olk<SGo;B@Yob0O8_l=20[o2P@2oe58@omFBdGoKEa9ohihJ?n=Le[oYXUNol6ONOnDMUGoRFmN
olZaSon/SUgoSV@koooGToo/`XgoTWQOok>NROmoJeKoC3l_obTJ7?mSCTcoH4U2ofIAB?m[Ee7oJEI4
oei?B?l_92So@c@cojbGQ?oG[h;o<R89ojZ3H?nKMESo8AdMobHN6oli=33oQHV4od=3??mREd_o=RHL
o`P41_nFNU?o8`00ojZKN_lR4`_o?2dTojB<N_o6Wh;oL4<Toi1VAonbR5?oQ5hkoei3;?n:NegoPWEK
og9SDOmfIE?oDT4`oem>?OmXEdKoNf]Joi61LOmnJU[oJEA1okFSSom9?BGoVHUfocX]7_mTFU7oWi^E
ogQgL?miM73oU9>Aoh63P_mbMFkoMgQ]ocD_;On1JEWoDS4PofU?=_nLPV[oXhE`oh]`GOnVUHCoTYF7
oh>QV?mhY9ooOJBOogZRWOmjY9koNJJOogJTW?maXY[oKJ6HofVPVOmUX9SoHYfGoenJU?mMV9CoFiFD
oe^EU_mIU9CoF9>GoeJCU?mGTI;oFY2Aoef>T?mMSHooGhb=of:<RomSRX[oIhV9ofR:ROmVR8KoIhN4
ofJ5PomVPX3oI81oof>1O_mSPGd2of:0O003of1nN_mSPWcoHX9l007oHX9l00002?lS:AooFW9VoeR>
P_m2SHCo@hj=odF>Som5ShgoAi6>0om6T8d2odFAS@?oA92<1Om6TXh0Yom7ThooAY:>odRDT?m7Thoo
AI6=odVCTOm:U9?oBiFDodZDTom;UICoCIJFodNHV?m?VIGoFg9doc8U8OmUETGoHT@mod<U9olh:R7o
>RPcoeLh6On3DbkoDRX>olAoD?o=QE7o<Ql@ogeDAomA;AOo@1lJokbHP_lI01;oQ7]Oob<D4Om??CWo
408Fo`P50?mcL6OoP79QoiN3HonKPFWoXhE`ojB<L_lX7b7o7QDHoblV:olX7RKo:b8ZobDT9olI51Ko
>S@bobPO6_la9R7oETa0ocL[9_lc91coX8mhok^WTomJACSoEd@eoi9mIOo;[XKoi;j8omf_LooA[8Ko
>bTGoi>3M?naWhWoGE50oc@W9_lj:B?oKEI=ofQ@A_li91[oHDLgocLS7_lO4AKo9Q/LogMWGOniUFko
`j>2oj^4HonkTg;oQG9PobDL5Om7?SOoQGicoe5:?omIE4oo5`l:oiQlG?o8Uf;oZFaAoh=R>_mDAD3o
<RXWoiN2N?mNA3Go[8ahoj1_COo>VFSoY7UKof97=?nPTGGo@38GoeA4<_mYFDSoGDdkoi61KomgIeKo
CCd]ogm]GondXY;oSGYWohEeGon;NfGoXYJ0ohQoN?n=QHWoW9REogioL_moN73oTXj:odi@COm>D4[o
Jf]Soc@[:?mMASGoZ8U/oj:8K_m[CC?o[I1iobD?1_mnKEgoNWa^ohnXWon3ZJ;oQZJQohBVX?n0Y9ko
OjFNogbSW?miY9_oMJ:Jog2PV_m/Wi[oIYfHof:JUOmPV9GoG9JEoeZFU_mHU9CoF9>GoeJCU?mGTI;o
FY2Aoef>T?mOSHkoHHf<of><S?mURh[oJHb:off=ROm/RXSoJhV7of^7Q_m/QXKoK8F500;oJHF100?o
JXJ2of^8Q?mZQX800_mWQ7l1ofJ5O`0000Ko<BXOogaoL_mWOW7oGH^0od^:QOm5SHd5odB@SPWoAI6=
1?m7Thl2odRDT00XodVCT_m:U9?oBiFDodbFUOm=UiKoDINGoenFUomYQX?o<S0Yoee<@OmdHU;o@RTN
od8R8omB@2WoCclnoe]2;OmhG3coZgeJok=eB_nmQeooJU8goj9nEonQP4goPEXiolfWHOn;KU3o?2hH
obHC4_mD@3Go;1LUoc@/5OmgKV?oPW=JohYiG_mG@CCoPfaRoi5mIol=20Oo>cDeobPQ90;o9b0U07?o
5A@Go``72Olj=3;o7aHAoaP=2?mACD3o<R/[o`X31?lb:B3o9adFocP/;olN5@SoIUE5okVLOoo]ahGo
o=ZPombgR?n1KeSoQWIWokNUT_mKDT;o>c@Yod8c9_maG4[oIdlmofeFA_mfFDgoFTDoobdQ8Olf:bOo
DT@gof138ooDWVooUgEKoh1H>?nJL4WoNFiSog5PE?mmL63oV8QeogeTCOmjDC?oiYeBomV=DOoSU63o
diYOohIYD_mBACooLe]<ob0@2?maGU?obI5/olbAH?mS>27o>24KogEYG?nDQW[oQgM[ohQjJommKf3o
A3HWof]NComgIeSoTGi_obTI3OnZVhKoM6==oh=`G?n3NVWoRX1goi::Q_m8@C[oViJ9ojJNT_n=RH;o
KViYog]kM_mcLV[oDdQ1ohE]FomI?RGoHe4mok2JQ?meGDWoO6QJohemK_nOWY7oVjjUohbYXOn?Z:7o
SJRPohRWW_n8YYgoQ:BJognUWOmlXicoN:>Kog2OVOm/WISoJ9bHof6IU_mMUiKoFIJFoeNFUOmGUIOo
EY>DoeZCUOmLTI?oGXnAof6?SomVShkoJ8n=ofZ>Rom_Sh_oKXb800;oL8Z700CoLHR6og:7Q_mcQhKo
L8V41?m`RH<1og68Q@7oL8R50Om_RHD00008oijQTonFTXKoLFUPof1[HomJRH;oAXf9odB?T?m4T942
odFATP03odFBT?m5THgoAI6=00OoAI6=1?m7Thl2odRDT0;oBiFD0:3oC9JEodfGU_m>V9OoDIJCofn7
R?mlJ6WoIEe?oadN3olk:AgoFd/mofQ6A_m[F3?oPW1PohabH?mWESKo^hADoe`a4_mE@c7o/8=>oi=Q
A?oL]fkofZaPom2FGOo8We?oajf@odL]:omK@bGoGd<nog5OAOmfHe_oOFmBoh=hH_l=10;o;R@Uoa@=
1_lZ9R;oAT8nodM3@?lG4a;o6aHEoa4@4olU82;o9AlMoe17@_m0=Boo5A<4odM3?_l[92Wo@SdfobPP
7?mDCEWo=C4Wod8c:OnKPFWon=>;oo_=TooX^WgoQg5?oj:@NonLRg[o?3D[oadF5_lk:bSo@R`UoeLl
=?mC=c;oA2/Sod8_:Olc:B7oD4@gojnLR?n4HCooY8YaofI;=OmR@bOoS7YSoeY>?om1>cOo9BHSoibA
P_nZP5coc8QKom:HFOnYNU_oeYU^omRGE_o2TF?oLUa:ohYZCom2=b_o6Q8<ok=mCooFWEgo]HeZodhm
<?m=ASWo=BdPogIYG?meJEWoPG=SofEGB?n8NV_oBcX[ohQcIOmFAcKoSH1[ocLW4On]UhGoU8MlohQk
JomjL5[oWYB4oiR;QOnGSX3oT8Z0oi6@R_m9B4?oKf]TodTi<On@MfGoJEE1oi27N_mgJeco6PT4oiR6
N?mhJ5WoJFAHoin^YOnAZJ7oUJZSoiBYX_nAZ:3oSZRPohZVW?n5Z:3oPJJNogfUWOmgXI_oLZ2KofbM
V_mVViWoH9VHoeZGUomGUiKoEiFGoeJCU?mJTiGoG96Cof2ATomSTI7oJI6@ofbASom]ShgoLI2<og6>
R_meSH[oMXf:ogN<R_mhRhWoN8Z91OmgS8L1ogN<R@7oMXb90OmeS8T0000;ojZ/W?nPVIGo@S<cob0K
4?mhRGcoH8Mnoe:>R?m8SY3o@i6DodJARom9T8H00_m7THh3od>BS@03odB@S?m5THgoAY:>00;oAY:>
09OoA9BBodFETom6UYCoAYBDodZEUOm8VI;oAYZ>oeJBTom>VYooB9fGog^HSomMDDGoKeY;oeU;=omA
AcKoKEaAofmVEOmbIecoFe92oalC1OmOC3_oNfi5omVVNOm_?AWo?A/:ol6FF_mZACWobjA/okf9G_oM
[gkoe:mTokjOM_mP?bkoES/jobDN8_mLCdKoDSH]ohAcHOn1LeOo5PL2oeQ;Aon?QFko<2PUochg=Ola
:bWo>3@aob4M6_lU8Ako>3<]oa091Om5?3Ko@3HfocL]:omYH63o@CLno`d51_mBBT7o40P5ob`V8?lU
8Q[oKEaFoiIeD_oL[GKokkj4ojb7I?nORFooH5A2ob8J5_lZ6a_oKeY>ofE:=omeF4[oBbd[of58?Omj
FdWoBSL^ochg=?nYSh3oVWIJoiiiE_n_PEKo_YUfod]0>?lm>SWoGEa@oca2>onDQhcoZG]Wok9_?OnE
L4oo20T7ocHL5ooDVeko`hMLohY^E?nBMe[oRgMIoem59onjSf[oejU]oiU_Gon@NVCoHEA0of5CD?m6
>S7o?38WobdR6?mPEd_oM6YOoe]>@_nCQ7KoHUA9oge_I?m]GU7oR7QYoc/_9On/X8ooNfmMojJJR_n6
NVgoPgI]ohIkLonBRh;oOWYaoeeMDOmQETSoTW]QohU_DolW60goF4Pdok:JO_n/TWGoJE<kod4d9OnP
XIgoWZNVoif/XOnJZIooVZZRoiJXX_nCYj7oSJNNohZUWon3XicoOJ6JogVOV?mcWIcoKIbIofRJV?mP
V9OoFYJD00;oFYFG017oGIBFoenDU?mRU9CoJI>DofjAT_maTi;oMI>BogJBTOmiTXkoNi6;ogbARoml
T8_oOHn:ogj?R_mlShgoNXb;og^=S002ogb>S@7oNXj80OmjShP1ogZ?R00000_oXYnDodU4B_lN62?o
4Q07og]mJOmiPW7oM9:7oe6<Qom3TY3o@i6>odN@R`02odNASP;o@i:=00?o@Y:=odB@S?m5THd00om6
TXh0ZOm4U9;oAIFCodJFU?m8UIGoBYJFodfGUOm8Vi3oEIBCod^IWOm@VI3oRH]noiZ0JOnYU7[oQG=L
oh]lK?ll;b?oFE90ogefJ?nARG_oP79SojNDPOm3;R7oYWI:olFACOn^OTkoaHaGom>CEOoHZ5goLU<b
odT/3?oDXV_oaIieoj5nIomJ>c[o2@L;o`T=4ol:0PGoH5=5oh5cFOn0L6;oTH1`oj2AM?m>A4?oCdM5
oe==Bom=BDKo>SHcodQ3A?l_:ROoFUE;ocdf;_li;bgo50/9odTo?_lH3A7o;b@VodDk>?m2>C?oB4<k
ocln>Olf:ROoZH]coo?;T_o_aX?o^YQbog1J@om8>cSo6@hRodln>onBOfkoUGaSoh]_G?mQASooIDlo
ogEH@omF@SGo?C@_oij4KomWDDGoGd@aoiE/BonoUg[oOF=Job/M6OmECSooAdDkoeE8B?mcCSWo_XMC
ojEkF?l930Oo5@dFohigE_lj9QcoO5djojN:K?nQQ6Wo/Hm_ok^DK?oDYVWoDb<FohATAOn8M67o=bL[
ogU_IomQETcoSXAjofILD_m[HEOoJEmAof9EA?mEAc[oOFiToj6CQ?nBQWCoZ9Z;odTl;OnZW8goF4Xj
oj6BQ?nMT8;oBChbog]cJ?n9Pg_oJfQQoda3=_nFOVKoXXQ/oj2@O?nVUh;oPFQ>og]QAOn/UGgoSgm`
ohn:QOn]/JooXjjSoj6/X_nOZj?oW:ZToiVXXonCZ:7oT:RPohVUW_n4Y9goOj6LogVOWomdWYcoKibJ
ofNJUomRVIOoGYRIoenGVOmQUYOoI9JFofNFU_m]UIGoLIBEogFEUOmiUICoO9BBogbDTOmnU8goOi>=
oh6CS_n3ThkoQ9>>oh:ASon0T8d00on1T8h3ogjAR`0000_oBT=3ob`Z>Ol83Ago5aX>oi:7JOnPRg;o
S8QgofN=OOm9T8Oo@Y6BodF@U002odNASP;o@i:=00?o@Y:=odB@S?m5THd00om6TXh0YOm4U97oAYBB
odNETom:UYCoC9JEoeBDVOm;VYCoDINDodfLVOmVVXkoXHQhoh1M?OnOPf?oYI=hohj2Lon6OG?oSXEc
oda4=Om;?c3oRWQVoif6KonING;oH3HDol^JG_nlPTGobHA8omBKFooEX5SojJm_olbDF_o;Y7koC3`/
ohMgJOmI?SGo5PD2obDU:Ol210WoIemAodLl9on;NVGoSWUQoin;K_lo=CCo?SHcoeA=B_lA3@[oAd<o
ob`Y;olF4ACo3@T6ofIQFOmBBd7oGEE;oc8Y8_m;@Cko>c4aoc<X:_lo<c;oDTa4ocdl=_ld:R[oVh1[
ojZ5Fon2FdooS6YNojVBM?nRUG?o?3DQoee?@on7M5ooMem3oh5VD?mMA3KoTGUSohM_Eom6<QgoLEi:
ogiQB?lK203oLEe;ogePAom/CcWoGda1oe];@on2M6GoJ61Dob4F3On<LeOo]HaRolF@HOmYCS3o<AP@
oij4HOlP3POoSFXnojZ5IOnHLeko[XQ]okbJKoo9WVCo_Xe^oiM^@?nEMV;o<24Xog1XGom2>2oo;R<J
of9HComnLf[o:Ql@ohn2KOmlKUkoD48dofaOCOmQE3ooVHUiog9RD_nOSgooG4`loi20L?nSUX3oUHQg
of5HBomlM6coGEQEoe=<@_nCOfWo;QL4ohEiJ?n4MVGoYY1iodT`6On?N6;oKUa<oeE=A?na/:[oZk6W
ojR^YonU[:CoXJ^RoijYXOnIZZ;oUJVPoi2WXOn;YZ3oR:BOoh:RX?mmX9coMijLofnLVOmZViSoIIZJ
ofJIVomXV9WoJYNHofjGUomcUiSoMiJFog^GU_moUiKoPINDoh:FU?n2Ui3oPiJ@ohBDT002ohFDS`03
ohVETOn7ThooQi>?00;oQi>?0On4TXh1ohBCSP7oPi>>00002ol>3Q?o0@<?o`hC5omOH4[o]:F7om>f
X?nXTh7oO8QbofNCPomATHgoCIBI00;oAY2=0_m3TXd01_m2TXgoAY:>odJBS_m6TXkoAi>?odRDT0;o
AYF@0:GoB9B@odbFT_m>Ui?oEiFIodfLUOmEVYCoE9jHofVEQOncUH7o`Ymkojf@KomdHdSoP7IVof9K
DOn3NVSoOgIUoif>O?nBNfCoJd``oh9N>OmaDD7oLTU1ok1kE?noRDgo`hmPoeT`5_o2V5gol;AZolRF
F_lY6`Oo10@1oeM9>omH>B_oKE=5od<f9om1=bco3`80oe50:_n>O5ooW8Mbob4H5?m?Ad;oCDM2od=0
>OmHEDko5aHHocLf>Ol@30koHeiKo`/60om9@3SoD4Lnoe=:@_lI4@go:b4PoaH<2_mGD4So1`L4ocL_
<?n0J5GogknHodHY6_m]CCKoYhURofEA;?mNCd3oFdTfoi=lI?n;Ke;oVGaQoiQmIonPP6GoS79MofE9
<_n^RF[o[8MXojf=I_ndUFkoYhi_ofAE@omBCdKo8QdBoge/HOlf9acoKEm9oi^;Kom[CcOo]We9olN:
C_oJU6SogYaFol>6F?njTVWo[XEToiI_DonVPfSo/YIgokZLMoo4V7Soa9AJofU2:omTEEGoK6AGog=Y
Gon5Ng7oF4m4of9HC_m]HeCoD4<_ofePD?n1LVCoRWe[og]_F_nBPW3oXY5oocPW5OnTTh7oASHTogQX
Don=OfgoUhanohElLolj=2ooFeI?oeQ8=on?NVKoBT0dogM/GonTT8;o]Yn>oj:;MomQBSWoR7QZoiR@
Q_nd/Zgo[jnZoj^^Y?nX[J;oYJ^PoinZX_nJZJ7oUZRQoi:WXOn>YJ3oR:6MohFPW?moX9_oN9jJog:M
V?m^W9goKIVKofnIV_mbVI[oMIVJogVIV?mmV9OoP9RGoh6FU?n4UYGoQINDohFGTOn6UY7oR9NBoh^H
Ton;UY800_n>Ui@01On=Ui?oS9FBohbET_n9U97oR9B@007oQi:>00002ol741;o1PX9oc<]6oo1^ICo
^ZfFojVLT?n:O6_oTHA`ohZBOomTSHCoC8f:00;oB9:?00?oAI>?odFDSom4U8l00om6TXh0Z_m8U93o
BIFAodZFTOm:UY7oBiJAodfFT_mAVIGoDYNCodbNS_mNVY?oFYbFofRIR?miHe7oLE<eoj6;JommL5Go
WIF5oeI@AOn3MfGoMf]Jog9QCOnPQF_oZhQYojanHOm=>c7o70X=ofm@=om_DdGoGT4RoaT>4omhJ3[o
jk1UonVTHOo9WG;o@B/JobDI1OmSA3CoLDlmoeA2:OmFAcgo4000oe]<>On4MEgoCcdgocdd;OmLEDgo
@3/cochk<_mFDd[oCU1;odi>COlF51So81/NocLd<?l[8R;o6Q4=oeiEBomHD4KoCdHooe96@om4?C?o
<C4/od@o@_lc7`koX8AKokfVO?oN_Y3obJEaojb<J_mcEeGoL5LooieoIOnMNEko[XY_oj1mHonYP67o
R6aHoj=oI?nkQ5_o]8MToiMfEOnKP6GoLea?ob0@2Om4=RgoJemCofUKEOmA?SWoUXE[oiV:LolL20Go
YGE7omJ>B_oWV67oeYA=olb?H?n[Pf[o^I5/oiIbB_nKOf?oFTDjoc@W7_nZRG;ofJQ[oiM/D_l]7QGo
B48`og5WGOmoMF_o@CL]ohf4NOm5>RgoIUQ8ohAfJ_m_H5OoIeQ;oga^GOm9>2CoR7MSoi>2K_mGAS;o
VXUeoi5nKom_Ge3oRWe^ogmgJ_m^J5_oCd]6ohYlKon0KUkoBT8koeA<@_m:>BooAS8WodTc8on?N6Co
NFIEof5DB?nXXIoo^;B`ok6`Yon^[j;oZjjPoj>/XonPZJ;oVjRQoiNXXonDYZ3oT:BMohbRWOn6XYgo
P:6Kog^PV_mfX9ooM9fNogJLWOmgVY_oNiZJogjIVOn2VYSoQIZHohJIV?n:VIKoRiZGoh^KU_n<ViKo
SIZFohnKUon?VIKoTYVE0_nCVID00onBV9CoT9JBohjFU002ohfET`000;[o=SHfoci08?nYX73o`Z^E
ogmbKOm7Bc_o7al=oiJ<M_nETGSoN8UfofJ<Q?m7THgoA9J@odFDSom:U93oAiB=od^CS_m;ThooBY>>
odbDT?m>UY;oCIJBodfFT?m@Ui7oDYRAoeJIU?mEW9?oEYn>of:NU?mTWYWoN9Z8ojjOQ_ngWH3oWha_
ohAfGon@R7SoPgmboiJ;N_mjK5coMfACogeSBonBM5KoMD`iohYhJ_m;?BkoJ5M6o`X65Ol02`?o5`X:
olRGF?oc[f3olkIdon6ULoo:WFgoXX=Poh5PCOm^CT7oFD<dof]FAOmbFToo;bHMoalK5_le:R[o1@<5
ogY_Iol^9AcoAT<lob8N5Om<BSgo@T0mobXX;?lQ71go<RXToe=:B?mLDe3o6A8;of5KD_lO6A?o;RTQ
oa<;1Olb;2GoD4Y3oeQ5:oo5Y7_oId<YomfjQoo3XGCo/Y9Hojn5HOn5ITcoWgeRoi=_D_nXPFGoTVeB
ojakG_n]SFkoNeE;ok20G_nCJTWoARPNohU_Hon1J5WoCSLWohM`G_mZFD_o6`X3ogYYG_n3NfWoN6aM
obd@2ooAU67odI]GojafH?nhSFCoSVM6ob4=5?nBNV?oXX5@oi]lF?l]6aCo5P`Eoei7?OnTOeco/hah
og5I@_n5NfOoF4i5ohQnM_lZ7QGoL6IOofeRFOm8?C3oIeY@oei@B?mnKfOoLV=EoiR5K_miIDkoNFE?
ohIcG?nNRWCoEdDfogaZG?n2LVGoU8Qkohn4Mom7@SKoJF1Cod4d:OmZHU_o<BLPoh5dIon6M6OoOVUG
og9LBonDPG;oWXn2ofAJDonh/;7o][:Yok>bX_n_[ZOoZZfVojJ[YOnPZJGoW:RSoiNVXonDYZ7oT:BQ
oh^SXOn7XZ3oPj6OogjPX?mlWZ3oOIfOogjMWOmoWIgoPY^LohVKW?n:VY[oRiVIohnKV?n@VYSoSi^H
oi6LV?nAW9T2oi:KV@?oUYbG00CoU9ZEoi>HTon>V9GoSYVF0On<V9@0000@of:4Ooo5b9_oi/bGoiF3
P?lB3AGo40h;oaTG4OnRWH_oP7YZog5_G_mnRgSoE9><odVKTOm:UI3oDIB@odfER`?oD9F>09_oDIJ?
oe>HTOmCV9?oE9NAoeRIT_mKVi;oGYfDoejNTOmRWi3oI:2FofVNVOn<X8koRWUJohAXB?nQRVgoQGEN
ogidHom9@S?oKV=Bodi0<on2Kf3oBcHPogIM@omnHdkoKEU:oeHo;OmfGDgo3`L4o`8:3?mYC3KoeJ9T
ojn0H?o=WeoogjQ`ojeh@_o2T6;o^8m_of=5>?m:=c7oMV=BohAYE?lG3`_o10<5ocd_:Ol71PGoP6iO
odXk;OmFDT_o>S@ZofIPD_m=BT?o?cdnoeUCD?mEBd7o8QPBofYQG?lI4`ooHUeGod]8@OmJEU7oEDa8
of1CD_lW7QWoV89Uoo;=V?o@ZV3oeK5eod8P7onROf;o`XmYojb5JOnHLUCoVgAEoiQ_DOnWOV3o_8eZ
ojn@I?lh6a;oY7mKojj=Hon`TgcoSG5Doib1HOmfH4OoNVYNoalA3?n3LF?oNFYGobPR5_n<OG3oKD@^
omNCF_o0UEGo9@/CobHB2OnFMeOo=A/<of@o9OnjRVGoXgQJofQG??lD2`GoJei=ocTT6ol`5A3oYHem
ohEjK?m8@3KoQGYbofEKDomDBDCoAc`fohEmL?m7?S;oOW5Voe11>Om]GE?oD3hYoib:M?mNBSKoUX=]
odll9omkIeSoJUQ:of]JC_m2<bSoNVaRoeaDB?m6?SGoA3/eocld;Olj;B?o=RPJoh5`H?m8<b;oPfiL
ohAbIOmcIEKoGE15oj^OYOnj]:_o];>Qok2`Zon][JWoZZbWojFZYonPZ:KoWJNVoiJXY_nCYJGoT:FT
ohfSY?n9X:?oQJ2Qoh>OX003oh:NW`08ohRNWon=VYkoSibNoi2JW?nCW9coTi^KoiBLV_nEWI/3oiJN
W007oiRMV_nIWI[oV9bIoiNKV?nFVYOoTIZGoi:LV@01oi6JV00000oo=9:9og:>KooZbj_oB3Tho`D7
4_lD2QGoCD0jokFYS_lj:BOoB3/eohF5HOm[U8WoEYR=oeBET_mIUI400_mEUXd0WOmGV8ooFIZAoeVJ
TOmIVY7oGI^CoejJTomQWI?oI9jCofNOTomWX9?oKJ6BofnRU_mdXI_oRY^=ok2PQ?nTQfOoV85Sogm]
E?nHRgOoUHYgohIiJ?mLC3goSW]/ogAQC?mnJU7oRWIUoe]<?on6K5Go[hMSogIA;omaDcgoSV<jojF5
DolH2a[o60d0oiQ`A_o4SESocI5Mok22G?m6<R7o:bHSocL[:?m<>S3oGe56odPk;?nORgGoNVmHoiMl
GOmbGTOoDD]3oeE?Aom9@SOoFeQAoda;Aola:ROo=RXRoadB2omCBD?oH5UAocH`:?mUHESoA40kob@J
6Ol^8B;o=2PXohYaF?n_QESoZh1FolBLHomlG3ooaJF3olVJKonlT6[oZ7]Joi]_C_nQM5Co]HUWokjJ
LonYT6_oZhacokjDJOnTO4_oUWaIojfDLon3JTcoXHiloc8T8?lP5Q?oKE]>ob8A0OmA@cCo^In7okF8
IOo?Uf?o]h=6oa`<4Ol<2A;oVgEDol6GG?oLXgGo^X1LoiidGOnURfKoSGaPojREL_nBO63o7@@0ohUc
I_mlK5goD4@iocde:omZHU[o@cTbodTn=_mlM6SoE4Tnoe54>OmbI5SoSGeaoeI3<omcHE7oPW5Qogi[
GOmaGe3oLf1Bof1>@?m=?33oOFmToee?AOm>AD7o>S0_oc8V9OmBA43oGE13oeQ9?Om8=R[oUGm]ojF?
NOmXEd;oPW=Poh1aI?nIRhSo_;:[okNbYond/:_o/JjYojb]YonY[:KoY:ZWoj2XY_nKZJOoV:NVoiFV
YOnAY:CoSj:TohbRXon:XJ400on9X:401?n>Wj;oTijSoiBMX?nDWIl2oiROW`03oiRNW?nIWigoVZ2N
00;oVZ2N0_nLWi`01OnKWY_oVYbIoi^MVonFVYWoUi^J007oUYZI00004_loTY7oD91koi:SS_la7B;o
3PL7oalM1_n^Wg;o`kB9odHd:?n2KVCoXI5`ohfHQomTSh?oGiB@of2ET?mMV8[oGiV@of2JT@;oHI^B
09WoHibCofRLT_mZWI;oJijBofnOTomaX97oLZ6FogRQT_mlXiCoO:6Joi:QU?nNTGSoR6mAojZDN?nL
Rg;oNVeGohn2KonMSG[o9aD6oiJ4MOm]FTWoVHMaob/I3?mZGeKo90d4ojQfB_o2RE?o]g`hojQS?_m]
B2Wo0`X=o`<A4_mH>R3ofZE]ol:;F_nnUG7oLV5=o`d80_l:1@co2P@6odTj;_n9MEkoSgmVohemIOnJ
O5_oV85Xof5HC_lK4@co>C8XofQUG_ln?CSo50l:of5EComQETkoL6EMoh9iL?lN5`ko8A`BocPe:_mF
CcooF4]0ofIJC?oQaZ;oh[Anoj9eEonoUEgoc:akogAF>Oo7X7;ob9Q/ojUiEOnSMEKoY7QGokZ@Jono
X83o<AH:oh]ZCooFYXGoV6a<oj61Jom_D3koDcLRofaI@?n<QF_oDD/goeU:>on8MVKoK5]=ojb>M?nm
Reko`heKol6>HOmUBcGo=a`=ol::E_l]6@Wo^I9VoiYf@?m_CC?oZGaUokZ?NOo3W7Ko`9aaoj^5G_o5
WfcoITd_oga_H_lm=RgoKVUSofiWG?mOED[oFe59ogU_IOmbIE[oL69Eoem@@OmhIUSoJUM:oiB2M?m]
FTgoCcd_oi>0LOmTDTCoHe96oeA5>_mCAS_o7Q8>odTm??m4=SGoC3dhoi:4MOlj:1_oKe]?ogeTD_mn
IDooQG9Moi1oJon=NfcoASDXoheoO?nn/k3o^;6VokF^Z?n`[:So[:^VojRZYOnTZ:CoX:RVoifUYOnK
YZOoUj>UoiFSY?n@X:001?n?X:001?nBWj;oU9jSoiJMXOnIXJ<2oi^QX@GoW:2O00?oWInLoijPW?nL
WY/00_nLWY/1oibLW07oVi^K0OnIVYX0002]oe2AROmBUHcoH96?od5BCOn@PfGo_:M`olNcS?nLR7_o
Vh]^ojZGK_o</iKoUhUeogJAPom/UiCoK9VDofVMT?m/VY7oKY^BofnLTom^W9?oL9fDog:PU?meX9Co
Mj6CogVQT_mjXi7oOJ>HohBRU?n8YIKoQjJNoiNTVOnWWXWoQWELoj:CO?n=P6_oFDdloeiC@_nKRG;o
Q79Pog]YFolZ6@[oSWiXoh5WFomKD4koBSHWojanEOo:SEOo/8EEoiUK??nZND_o6`T0oaD90?nmTf;o
gje[olNNMOneUgcoY8ifoad=0?l51Pko0@LAobTN5On7MF;o5Pl8ocP[9?nBMV7oVH9`oeY=@omeIego
GeMAoc/h;omPH5KoGUUAob/P7?meJ63o50L4ogM]I?mmMF[oKVMLogQfJOn7PG;o=2HKobhQ4onHNUKo
XG@bolZTG_oU]X?oMe4dob`93_o<Z7koaiMZokV8I_nWNF3o[8=YokRDKonmWgOoARTNoiMdC?oAX7ko
^99foiAaD_n]QfooZ8E_ohA[D_o?`ZOoc/J_oh=eI?mhIESoG4i6og5F@?n^PE?oJT8RobdI5_n^R5[o
bhIAomJDCOlM30CoLdXYoj24H_l]6Q;oQea7ojYlIOo2VW7o`IYYolBIK?oHYVko_Yimocl^8?mmN73o
Ph9koaD?1omiL6?o?SH_ogM/Hol^8AGoOW5Qof1C@OnIRGOoHe=0ohemJ_m0<23oMFECogaYF_mRD4;o
GDa0oc0Q5_m<?S?oJEa@oeE8?_m@@S_o?bhVohinL?mZFDSo=B4=ojR@N_n?MF3o@B`Joi=oL?m?>RSo
LV5:ohIeM?nkZk3o^k2UokR^Z?nd[:So[j^VojZ[YOnXZ:CoY:RUoj6UY?nPYZKoVj>ToiZRY?nFX:40
0_nEX:42oiBOX004oiJOXonGX:GoVInSoi^PX`;oW:2Q1OnOX:000onOWigoX:2NoijNW002oijNW07o
VYnN0OnIWid1oiNMV`0001;oEIV8of:BT_mOUIooGij>olg9Uoo``8_oS7=]oaL66omfK4coZiYNonG8
X?nQRG7oUinAogfMUomdWYSoKYfCogNLU?miW9D2ogZMUP2Iog^OV?mlXYCoOZ:Doh2SU?n2YIGoQJFE
ohJTV_n=Y9OoSjNGohnXW_nEWiKoR81]oj2DO?nIS7[oY9R7ohj5M?mVG4_oJeU7oeE3=?lk:A[o@c8Q
ohEfHOmF>2koB3Xhoc0U7_naQ63o^h9Dob<L6_m27P?ogJALol>=KOoMYfOokK9Mon^hMom_CcSo70d2
ohmiGonWSW;o0P@8o`@83_mLDDOoKF1Bo`<41?l90`KoET0eoiZ3M_lT5@koM6IMochf<OlX91goHEiE
oclj<_mHCDOoN6]QobXM4om[HEGoOWEZod4i;_lJ5@koFe=<ofiPGoli:2;o^iQkookGZ_nJKE7odjAd
okVGG_nUPf_od:aiolJLL_nOLeGoPUU6ogA@>OnBLeCo^i]Vol:PQoo>ZW[oX7E9oimlF?niUVSoP5P`
ohAP@omUBCGod/2_om?6]OoLbkWoJU]=obTM5OmRC3Ko`IU/oe]1<_l52R?oV74non>;B_oNXEKoYW]B
ojAZA?mO?3?o=BLboh]]B_nWPf7o]IQYok2CK?nXPVkoejJ7ofQ4;?mfHUGoO7E]oadJ4omoNfkoCDHf
od<j=?m^He[oRgmcoc/]7_mlKegoQ7ASohinJon3Lf7oPG5OohMgIOm_GdooQgMXof]ICOmbHeOo@cH[
of1E@OmBACGoJeiBog9QEomNCCkoMVA@ojF?NOn7KUSo[99ooij8NOmIAC[oSGMTojFCNoll:2GoWhnC
ok^bYoni[jKo]ZjVok:/Y_n]ZZGoZ:RTojRYY_nTYZCoXZJUoijSY?nLXJCoV:6T00;oV:6S0_nFWj40
1_nGWZ;oV9jSoiVNX_nKX:?oW:2QoijOX@GoXJ6P00?oXInNoj6PW_nOWid00_nOWid1oi^PWP7oVInM
0OnHWY`0002_oebGT?mWU8ooJ9VHoejKT_nBWgkojLVZoblN7_l:3Q[o61/Ioi63I?oE_i7o]:63oj^>
Q?n?UH;oOZB=ogfLW?n0XICoPJ6Doh:PU?n5X9GoQZ6FohRRUOn9XiGoS:>FohfSU_n@Y9SoUZ>GoiFW
VOnDZY_oVZbNoi^LU?nNUXGo[9inohikI_n<MVWoMFAEogiaG_m]GDkoI5A0oi:3K_n5MFGoI5=8oh9a
IomPDTKo51DCoieY?OnnR5oo10X3ocXO3OoWZekohZ9LonBTI_o[/U?oml22ocdM6?l<3aco0@00ofQE
AOmKDTgoI5A1ogUYD?n1MfKo7ATAo`P40?mkJU[oRFmLo`h00?m8@TGo:b<PogUaK?lc:bKo=2dUogA]
Hom_IEKoG5=2oe98>_mGCd3oUHenoeU>>onISH3oFe9=ogQXD_oG]H_o`Y9NonBjP?nBITCoQEY2omR]
P_oCY6WoTg9IoiAaG?nONVSoWh1/ogeRCOnZQEgoaYmaohiSDOnhTUkoWGE>oh1H>onZQfGoUWQLojVA
NOoKbK3ofLJ`omW6[ooGbk;oTh9aohmdEooW`HgoOELeobDD3ooDVUook95JoiiP8?o2NDKo`XA3ojF0
EOm:<B_oVGUFoj=kHOnWSFCoB3PTob8=6?n0He7oTW=Coi1eG_mjJEKoNg9TogijKolU7QCoOg9Zoei@
B?n8Ng3oMFAHofmND_n=OFko>b/LogUYF_mNCSooCSh_ogE/Fom6>2WoMfEGofYLCOmHCCgoKEm=oea<
?_mA@CSoS7YaoiB3M?mB?bco[IN5ohmlJ?ld8A3oO6UHoib:NonGR7Wo:14;oiN2L_mkKFKo[:NVok^c
ZOng/:Ko]:nYok6]ZOn_ZjOoZJVUojNXY?nTYZCoX:BSoibRXOnKXJCoVJ2ToiROX`02oiZQY@03oibP
Y?nNWj7oWYnQ00;oX:6S00goXJ6RojFQW_nUXIooYZ:PojBPW_nUXIkoYInMoj>OW?nPWYgoWinOoijN
W_nNWYcoWIfK007oW9bJ00006?mLVIWoKYRDogBITOmUUXgoN9F4oj2LS_lL3Poo5`hDoaDA5om4@Soo
JVEEok:OQOnSSH7oEE@mohbPQ?n>WiCoQZBHohRSV?n9XYSoRZ:HohfTVOn>YYOoT:JGoi:WV0;oUJNI
09GoVZNIoi^YV_nL[9goW:RJoiNGSOnBQ7Ko[IUooi=lJOn1K5coE4Ddoh^2JonFR6WoQGMKoc@T4OmN
C4GoE414oe12=om:?CCo@CLcohEF<onfOE7o60T0ofA7>ooOZVGoij=ComNGDoob_6Goj[YPoknRJ?l8
0@3o3P<@odLe;omBASOoLFECogU/E_n<P6WoQ7MQohIeGonCNEooW81Uoee;>?lg<BSoFUE=ocPc:omK
EU3oNgE`oeI@C_lG3`_oRh5coe16>?mHCT3oRh5coe95=om7?3;oCdLooeY;>_nEMDcog[1hojeiB_nU
MTKoYWM6on:bP?oCX6koJdDWojEmG_nCJTkoZXE[ojV9Koo6Y7_oaImbolbQOooGZgOo_XmNomB/Qonj
UWGoUgQMoi1hH?oMbk;oflR`omW9[?oDaj[oe<:bojJ=M_oE/83oi:QSolVMKOo]XUOomieKon6UKood
Zg?okZ9Hokf4AOmbC2koVWQEojAjHOnNPf7o;b4@oa/;4_mPBc_o_YaTol^[LomRCb[o=RhIoeE@B?mT
G5KoKf=IofAGCOmKCD7oSGa`obdM3_n2LV?oI5A5oe10<Om[FdcoPW9SoeaA@On4M6GoRGIYoe]:??m`
I5CoJ5Y7ogIVEomkJUkoGDdnoi>3M?n1LEkoDSl^oiF2LOn<NFSoTWm]ohMdHolo:A[oXHEcoi=hIomo
K6GoThV8okN^Yoni/:Wo]:jVok6/Y_n^ZZKo[:ZUojVXY?nWYj?oY:FUoj2TXonOY:CoWJ:UoibQY002
oiZOXP03oifPX_nPXJ?oX:6S00;oXZ>U00goXj>TojRTX?nVXYooYZ:OojBPW_nUXIkoYZ6NojBPWOnR
X9ooX:2PoinOWonNWYcoWIfK007oW9bJ0000/OmZWZ7oLIVAogZJSOmhW9SoMifHohNIR_n/WH;oS6eC
ocDR5?lJ4P?oIUa4ofePE_lb;R[o7b@Eogj;MOn<WI;oS:>FohfTUon@YISoTZFIoiBVVonEYiSoUjNH
oiVXVOnKZI[oW:RJoj6[W_nNZ9WoXZ^LojFXVonQW9;oQGMZohigHonSRGKoVXA_ogYZEon1MF?oLUmC
oi:1L?m9>2?oMfIDofECA?mTE4GoAc`iobPF4?n;Je[o/7]CohiTAOmG?3OoZhI;oo>[FOoLWEcoiJmj
oo[:P_o/aWKo]XmXodPR2on^TFcoOFM?og1UEOmHD4?oSX1Zoi1jGOnCNEcoRF];ohiaDOnKQVcoPGMU
og]gK?lV8a[oB4Dnof9MGOm/IfOoHU]Eoa8;1?n=QG[oIee@ocHZ7On9NgCoDDLmoeYFBOm:>c7oaJJ2
onboPOnmQ5Kog:I/onVeN_o/^XKoaiM/oiE]C?nhSF[oSF8lok^ELonMNUgoZXALojEmE?oJ[WgoR5PX
on>^N_mdBQkoX7eKoj^<LOoE_JKog/fdomc;/_oKbZcofL^[omS6]_oJaK?oh/FNoo2hJood`7Woo;Ib
ombKHOm99a;oQf0noljEHOoMX6OofjMbokZ0DOn[Me?oZhERohifG_n@N6[oX81WolbMM_nmUG;oNfI?
oh1hK?mSG5;oPGU^oe54>OmPDdOoMVQJofADAOnDQ7CoUHEfocl_8On5MFOoGdloog=TEOmcJ5CoNVYH
oeU7=On@OfgoNfiKogEVEOn0L63oF4Pfoh1`G_m5=BCoLV9BohQhJOmQCckoWXUfogMQCOmnIeGoZY1o
ohMWD_mhFDGoYY66ogAVIOndZ:So^:jWokN_Y?nf[jKo/ZbYok2[YOn_ZJKo[:ZUojVXY?nVYZCoYJFS
ojBTXonSY:;oXj>Roj:SXP03oj>SX`;oY:BT00CoY:BSojNSX?nWXj3oYZ:O0_nUXIh00onUWigoY:2M
oj:PWP02oj2PX07oWinM0OnNWY`1oifMV`000:koNY^JogVMTOmkW9;oOIZMogjLVon3WHco]jj@olBS
PomQCCkoI5<golRUM_lj9Qgo2P/5o`L80?n5Q77oT9nCoi6TV?nCY9WoUZFJoiNVVonIYYcoVjNIoibX
VOnNZ9[oXJVLoj:ZWOnSZY_oYjbNojZ[W_n`Zj7oWiB<ohj0M?nFQ7;oV85/ohQ^F?mWCccoDcl`ocTT
7omnJUkoNVMDogm/EOn7MF7oJEQ6oeU?C_l]513o=2X^ohAM?oniODoo7P/;oeI45ooh/V?oi:YfogQH
?omD>2;oa9maoo2hL_o/]73ocjE^okVBL_lQ4PWo10<2of1GBOnBNUkoUGaUoiMmHonRR6_oWHM[oiV9
L?lH5Q7o>cXfod91??l?3P[o@D0lofeYIOmLEU7oHUU@oeA9??mgJE[oPG5_og=[Hol/:ASoOG1Zok:C
L_oM/fgojkElokZ2B?oJYG3o_hmSojj2G_nkUG?ocJAmolJML_oC[XWoYhMYojj2FOnfR6;ocj5Vok1k
EonlQeWoaim]ojN4H_n_T7Coe[fWomc;/OoKb[?of/Z`om[;ZooIb;GofLNgomk8Z?oD[6ooml9ioh]=
6OnZQ5Go60lFod8c9_mbDd?o?Qd7oln]POoDWG_oXgAFojB1JonRRWGo[Y=iokF?L?o3UWSo/XiloblQ
6Ol]9bGo8a`GofQMD_m?@cGoDTDfobTK3omfIUKoHU91og1PDOmgIeSoSWi_ogEUEomSDdCoPWEQof]I
A_nCOFcoOFUHoiB5L_m??booRW]XohUkHomaHdcoYIJ5ofmPD_m^GU3oGDXjoj:>N_mD>bCoYHagok2I
P_nSR6koGD8Zoj>>POn3Mg;oZ9VMoknc[Onh/:?o^;2UokF]Z_nd[:Co/ZZUok2ZYon]ZJKoZZNTojRW
XonWYZ83ojJUX@03ojJTX_nVY:?oYZBS00?oYZBS0_nXY:401_nWXj3oYZ:OojJRWonVXIgoYJ6Noj:P
X0;oXJ6Q0OnPX9h1oinOW@7oWYjL0000[_n7V8koP9nAogRNV?n0VZ;oQifGohBPU_n?UY;o;1`GobHO
:?lf9A7ogZafohAMA_m`IU3oNFY@oiR6J_nATGcoUZFHoiRUVOnJYY_oW:NLoijXWOnOZ9[oXJVJoj>Y
VonVZIcoZJbOojV^W_n/[Yko^K>XokbdZOn3MfooSH9goiB8MonUTWcoV7iXohEVE?mdEdSoNfI=ofUD
??moJUOoBS@]od4Y:om6<QooBChood8[:_l?5ROo?bD@olV5D?lE1`GoGED/oofjK_o2RfCo4A83o`X@
6Ol]6aSojKA_omnWGOoL[XCo^HQRod<b;?l41Poo=C0Zoi1iH_nBOW3oUh1^oif5K_nORG3oVH=[odi<
COm1?d3o8R0NodA3?_m3@S_o<c4/ob`W8_mcJV;oJ5aAoh1`HOmB@T7o;bXRofYXE?l^7agoW7mQoooR
U?o/_7KojKAloljHKonPLToo^I=bohYXB?ndSVKoaj9eokVFLOnNP6Co[giFokR2H?oS/g?o]81SoljL
MOo=Y7?o]I9`ogYL@OoXd;Wog/fdomW8]OoJbKCoflZ^omW8]?oHbK?ofLZ/oj1jB_olaW_o`H9Bojj=
G_lI4akoF3h[ofE>BolD3a;o9R@Cod<V8ombFTco80l>o`l70_li;1GoNE]2okJAI_n^UFkoCTHgoa@B
4olm<cOoL61OofiRDomoLV?oMFMGoi61LOnCPg;oNFUKoi:2L_m6=ROoTX9cohalKOn9NVGoJ5E2oi5j
JOmKAcCoNVUEogUYF?mjJeOoVH]bogY[DomQDCkoAcTZogm`HomHASOoO6MCoj>9Lon>MUooAc<JokJM
P?n_UWgoMVIDof]QF_n_WjSo_k:]okZaX_ni/JGo^:fZokR]Z?nf[JKo]:bWok6ZY_n^Z:Ko[:NToj^W
X`?oZZJR0onZYZ<5ojVUXP0:ojRTXOnWXj3oYj>PojNQWonVXYooY::Poj:RXOnRXZ;oXJ6Ooj2PWP7o
WinM0000Ion2W9GoPibFohJLUon7W9OoRIfIohbMXon3W9?oIgMhob4C7?mlIC7oe[mlomFcS_nm/XGo
`kBEokRNROncWGooTY:2ojBXW_nKY9koWJFNoj2VVonSYY_oY:NKojRZWOn/ZYco[J^Lok>_V?nlZigo
]jFUoaHH6_l330go10X>ob/P6_m5>37oQ8AkoiEeDomgED7oQFI@ogMKA_n1JecoEDLhod<i;OmDBcko
=BTYobh[=ol<1`_oGD8Wokf1FOmZ=0WodJm^ooVgIOndP5Oo4A@Eo`PF8_lI413o_XaDooo6OOoO/7Oo
d9a]ojB4I?lI71GoKFiQoi9eD_n8Ke[oVX5YoiV4KomPDTWo8ATNobX]=_lH61So=C8Yob0I4Om?AdCo
AS`fogM[Hon9O77o7Q8<oin@OomkLV7oMF]Ioga^H?lV6AGoYHE]oj]iB_o1SE;on;n2ojmc??o5U6[o
[XQZoiMdG_nNNUgo^IIfohUZDOnHOW7o[hARomFTN?ncP4goiK:0omNUO?n6F3KoTFY>oh]_FOoLb;<0
0_oKb[H2omW:]@;oelRc04KoelRaokjJO_ooeICo/XQAonJXFon8FccohZASolnPG_lV51[oGCTXodH[
6Om>@cCo3@/?o`444?l>2@CoECX/oiiaE_nGLeWoL5]?o`l40_mCACko@S<Vog1TDomQETOoIee@odi5
>_lj<2OoK5e@oeQ;=onBQVcoNVeJof]MConEQWCoMVUEoh5aG?n<NfGoUX=/oi9lIOm^FdOoFDXhog]/
E_n5LUKoRG9Hod`h9_n5LfGoRgU[ofA:>onJOVcoZi1mog1<<OnRP6GoW8Ihohf6PonTXJGo^[6aokb^
Yono/JKo^k2Vok^_Z_nj[ZSo^JbWokN/Y_nfZZCo/j^Rok6ZX_n`ZJ?o/:RTojnWY?n^Yj?o[:JS0_n[
YJ<01On[Y:KoZjFVojbVX_nZY:7oZJ>Q00;oZ::O1?nVXYl00onTX9goXj:Noj:QW@01oj6PW00006Wo
QYbGohNMV?n9WYWoRijJohjNVon@WYooTZFNoi>NWon5MU_oi/Qooo3;X?o1YhgoTXM_oh]gHOngV7So
`jMfoj:MR?nQXY;oXZJKojBUWonVYYooYZNMojNYWOn[Zioo[J^Mojn[WOnTZ:WoXZBBolc6]OmSIGGo
5Q/QogYoJonYUX7oKUQ;oaLA2?nNO5koS6aMogeLAomgFdKoNF9Dodm0<OmJCd?oCT8kocPW9Old:33o
3`81ohIR@oo1PD;oiieBolVSKooHZW3omkYcofe78_l_60[oE3LFonReI_o]_WKoc:j7oknJM?ndT6co
L5i;ogQ`Hold91Co3@X7ofUGAOnJP6Wo6`/5o`D42Ol40@?oKFYXodQ5?_lk=S3oC4A1oc4];_l[:2So
920Mohb8POlF40OoEDi3oaX>0on:NfkoM6QMogmVBooCYGKoik5oomfQJ_oRYg;oaI=TojZ0FonRQg3o
RfiCokVNPOmnJE;oGdhooiUeCOoFZhCoT650omNZQ_nLLd[o_YMeoiajGomaEd;oe/BcomW7]_oIb;D0
0_oHb;H2omO7]@0jomG9/OoQcjgoc:V5oe@/6?obZegokjiWonb/IOoTUd_ociUOomRAEoo^]6coT7eR
oaH=3ol82A3o6Q@;og]OD?nXOV7oX7YMoh9VD?m`F4Ko[YAnoe4i8omaJ5SoIEU:og=WFOmaI5KoI5I:
oh=eJ?m[GT_oKf9=og]]Fon1LfGoPg9Loh=aFonMR77oN6=;ofiG?On>N5goXXmgoh]iIOn<NVOoJUI0
oeM1:on3Ke_oOfeMog=PDOmZDD3oYHYgog1F@ondTWWoUGELoi1mK_mNEe?oR8F8ok^b[ono/JWo`;:W
oknaY`;o_:nW00So_K2Xokb^Y_nj[JGo]ZbTokF/XondZjCo/jZUok:XYP;o/JVT00Oo/:RTojjVY?n^
YZGo[ZJUojbVXon[YJ;oZZBP00;oZJ>P0onXXZ02ojNQW`7oYJ>O0OnSXYh1oj:QW@0006WoRIjIoh^O
V_n=Wi_oSijLoi:OWOnCW9SoU::JoiBMWOo1/h?okLUhol^OSOlb;BWo<cDiob`P5_n8L4go`:amokZb
W_n7PW3oZJVJojRWWOn[YZ7oZJVPojZZWon^Zj3o[j^MojnZW?nlZ9ko^9aZomNlQom]GV[o4@`DojFS
PonTPf?oSFYHocHU6_nFLUGoYhUkohaYE?mhFdOoJe95ogYWF_mGBCkoB3/kocPS7om<>3Go>R0DojAe
C_o9RT_oiY]NocLN5OlP3PCol;I^ooVhJOoQ[Vooh;EYooJnHoo`aIKo7@`=oa@>1On>NV?oDCPUodTn
>Ol21a3o0@TEoaX>1?n@MEcoGT`ko`L31_lN40OoHeUAo`H00?mHDTooIeiIoc/c;olc:bKoAC`cochd
:?m5>BcoP7AZoh=dJOmMC3ooDTXlojJAMoo1VFoocIQ]ok1fB?o@UfOob9AVojn1EonlV7GoY7mKok:=
J_mfEcSoYHaaok:AJ?o9XX3o]hifol2JP?n^Sf[oNeXmoi9dG_n<MfGofLRiomW9^?oIb;H00_oGakH2
omO7]@0momK7/ooQ`j[o_iUYofI58_oj_GCoTE`fokN2FOoNR4gokJaOonBCFOog[eWo`Y]`oe<e9Omb
G53oQ6eBojAoH?neS6_oXGYGogaI>OnVPF3o^i9^oh5O?omMDD7oD48boe10<_moKEooDD0boh5cI?n;
OFgoPgEWohUlK?m^H57oUX5]ojNBO?n7L5WoWXE^ojN=MOnLQV_oNFE:og9NA_m[ED;oDS`/oi1lJ_n=
NfGoQW9NoeY3<?n_UXCo[IF2ojRAOOnDN67oTWUSoiN8N_maJVCoXYbNokbb[oo3]:_o`k:Vol6cYoo0
/J[o_[2Xokf^YP02okf^Y`0=okV_Y?ng[ZCo]ZbTokF/YOndZZGo/ZVSok2XX_n_Yj;o/:NTojnWYOn^
YZCo[:JSoj^UXP03ojZTX@;oZZ>P00GoZZ>OojVRWonZXiooZ:>NojJRW@01ojFQW00006_oSIfJohnM
Von@WI_oTIfKoi>MW?nFW9goU9nEoi:QWOnYXHOoajQ`oh5KDOl@4Aco2`lMoc4W4onkY7go^:F=oiZ@
R?mfLFCoZZ^KojRXVonZYZ3oZjRPojbYWon^ZIoo/J^Nok>]WongXY7og;jBojJ=J?lC3Q_o10`Roa@D
3OncPeoo/h5ZoeHl;On>J4GoSgAQohAOBon2HTkoGd<gofeJC?m>?SCo9QhToc/V8?mE?BooO5a3ojej
B_o<RU7o^7eFo`l65?lO3POohk5/oo_2Joo__6ooj;U/oo2cGOoT/8Wo7`dFo`<:4_lG4@goO65>of9@
A_l:31Ko2PT?oa`@1_nCO6OoVHA^ogUWFOn;M5koD44eoeYDDole<BooA3`coe13>Om[GE;oMVMJohel
J_n>OFSoQGAVof9@@On0LEooWYN;oe=4<OnaSfoo]HIJon2aQOoN[h?o/X=IolZJLOo4V6gogZj6oljO
NOo<XWoo`j1noj5nG?n[QV?oVG5@ogYH>_n_TgWoVh1Zoi1hIOnXUhSoeLNiomO7]ooFa[GoeLFfomC4
]@02omK6]`0komK5]ooX`K;oomJ@on_8Qoo``h?o:Q4MofQ2<_oaYgGoVF]4ohMA<oof^7kod9i`ohiS
Aon<J57oUgIAoj=jEOn[PV7oR690oj1fE?nRMU7o]HIOogYB<?m1;1OoRWITog5ND?mGAC[oOFeSogY]
GOmUF4_oJ5U@ogi`HonHRW[oKU]9ohQeHonUT7coRW=Ooh9ZEOmiHdgoQ6eFofQ?=_n@MV3oPf]Ioij<
NOn;NFCoHd`eoi^1JombFTKoLEa9of1;=OnWT7[oFDDboiF:O?mZI5coTX^<ol:f/?o4/ZOoaK>Uol>b
Y_o3/ZP00oo1/:H03_o0[jGo_:nTok^^Xonj[JCo^:bTokRYY?ndZJ;o/jZQok6XXOnaZ:?o/:JTojjU
Xon/YZ?oZZBR0onZY:45ojbTW`7oZJ>N0OnXXid1ojNRW00006[oTYnMoi6NW?nBW9_oU9fMoiNNW_nJ
W:?oU:6DohnTWOnRX:goXheiog1DA?lU51So9QXFoi9iB_oU`8_o/Hf6ob0F7?ld<RcoYZZKojJYVonX
Z9koZjROojfXWon_ZIoo/JZNok>[W_oB]I7obIAYokEjD?nIJTKoS5a5oeda7_n[LTko/7ANod8R4onO
N53oQVaCoi1ZEomeE47oJTi1oeI2=OmA?cKo9b@^oc@S6OmcFT?oOUhjok1mAooJRCko]H1DoaL?2?nU
NdGooLQ`onJnOonaRf?ocJ1aooNgI?od^gCoMUXmoaPD6_lG30[oUFeDoiUaDom9>2[o?BLOof=AAOnA
OfkoWhA/ojR5J?nRPfKoM69Doa@=4?li=3KoIEiDoclg=?lF40co>S</oeQ@A_m7?C;oETPjoif9M?ml
KUKoK6QLolbo]_nmWhKogKF4ojZ3EOnPMdko/8ANolbPN_niTVoo/8IYokfDN_maCCGoZ8]aof@n:_o?
Yh;og;R6olBTOOmeFTWoO6ADofA??ooB`[God/Jhom?6]OoDa;?oeLFf0ooDa;D0C?oAaKOofLJhok=o
AOoiaYGoj[IhobdO7?nEJe3on[aaoee2=oli70Gobi9VoiicD?moGDSoS79QohYeF?nEO5koXGeQojf4
I_nTMUOoWW1?ok64I?neSFooQVM=ogmUD?mlJ5[oAcPaoeA8@OmWFT[oT89hoij?Qon<OG?oR7]ZohIg
J_n>Og7oHDm1og=PD?n9MF?oT7a]ofE<>omoHTcoPFE<ofUC>omSDckoL5i7oiMnIOnZSgOoYXmjofmL
BOn@NfKoMfA?ohalJ_mcJUkoKFUQoiVBTOo0/Zgob;BZolNdYOo4/jGoa;>Yol>bZ?o2/JOo`k:Xol6`
Y_nm/:Co_:nSok^^YOni[:Co^:bTokJYX_neZZ;o/jRQok:WX_naYZ;o/:FSojbVXonZY:83ojZTX@03
ojfTW_n]Y9go[JBM00;o[JBM0On/YId1oj^TW07oZZ>K0000__nBVY[oTi^KoiBLW?nDW9coUIfMoiVM
X?nIWZ;oUJ2SoiNLV_nUVXOoYH]WokV3@_o8U5GoeIYQonRjUOmiJU[o2PP8obTY5onATH3oZZRSojNX
WonXZ:Go/jJMok6XX_nZZZKo[9MmoljMH_o5QESoaW93oo:?A_oRPDKoU4<Voi=MAomR?BOoa8eRojYf
C_n2JE[oT6U6ohmYD_mWA3SoG3XaofU6>om9<1[oHE50ogQSDOm`EDCo;a`HoiibB_ofWd_ofZEMooK9
P_oi`G;oVGmMoalG6_lN5A_oWWaGoo:hM_oU/6_oaieUoim/@Oo@Tego_i5Qog9NAOmfI4OoQWELohMf
G_nBNUooWh5Toib2GonOOF3oOVEHochh=OmOGDooBc`_ofYIC?nDQ7?oFTXhoh=dG_nhYi3oOVUGolno
[oo@`[Kod;naoj27L?o9VFOon<fMoljWOOnlVG?oZhYTomBVM_nYOUKoZhIUohUV@oo3WWGobZB0oln[
R_nUQVGobJV9ojZ8Ion4IE3oKUQ8olnn/_oBa;Sod/Bdom?4]OoBa;SodlFhomG7^_oDa[Woe<Fgomo5
]?oO/G_on;m`oo[5V?nAI33ohjaeoo[FOon7GdWoFc8CoimnH_l=3@CoO69KoiM[B_mhCSkoP68`oial
FonOPVCoY85PojAeConDJTWoY7mRokV;J_mT@B_oGD@fogYYGonCQGWoGe8oofeUF?mnNG3oKFQQoh1f
K_n@PWSoQVYEojN2HOnXR6_oRgYWogaZFOm;=2CoPfUHog]UConFQVcoOFiEoi1oJOmLBC?oVHA^oh5Y
E_n<LEkoVWm/ofiIA_mGBSWoPGY^ofm/HOmlLWKoZIZJolRc[_o:]:[ob[6XolVdYOo8/jGoak:TolJa
YOo6/:Ko`JnUol6`Y_nm[jCo_:nTokR/XOnfZj7o]j^SokFXX?ndYioo/jJNok6UW_n`YZCo[ZBRojjU
Xon]Y:;o[ZBRojjUX?n/Xih3ojfTW`7oZZBL0OnYY9`1ojVTW00006_oU9bLoiFMWOnFWYkoU9bLoiFM
WOnIWIkoVY^QoiJMY?nJXJ;oXijDol:cVoo[ai[o]8mWol6FDOoS^gSoSFmGoeM9>?n^Xh?oU8Q_ojfT
W?nXYikoYZRTok2VW_naYZ7o[j>Nojf9JooFYV;oml23olak@OoXO3?ofFXgok5B<?nHGcKoYHU/okjB
I?n_N4SoSfA6oiMbFOnGKU[oICTXof@g8On=GdGoNFI@ogmhK_nSVI?o9aXEo`X73On0ISSok:A7onfd
GOokbg[oo/E]ojAnCOlW71So6QPQocDM0OohaHSohZ=Ooog2OoombHkonL=lolJIHOnBMf7oRWQMoi:2
J?nJR73oXhaaojN9K?maHE?oN5e6of==>OmECDGoB3lgohUjJ_maHE3oGdlooe51<?n7MfKo^ZVIolfm
[oo7_K;ob[neolVk[oo6/IcocJ=hojEnEOn<J4?o_IahokZKNOo4WWGo^9AcokjLP?o3WgcocjQnojQo
G?moFcgoK50hoiEjHonYSGGoP6E?oiEmJooA`;;ocl6gom;4^?oDa;SodL>fom;4]`02om?5^01=om;6
^?oFa;So`9Y^on^gKOnXLT_om/jGoooJUOojfIKon/R?omjGHooWYecoD38Coi5Q??oAW67oOU]3ogY]
E?n=LEgoS6mJoiIgH_nBKU;oLUDoob<@1_mKASGoOVQMofE>@_mkI5KoDC/Woib8LOm9?2[oGeQ>ogij
MOn6PGcoRh1foiF5M_miHTkoLeM0ogMK@om`ECkoWH1[oin1Jon?Le[oUh9SohIdFOmiJ57oVXE_ohQb
Fon:LUcoI4`fogQSC_m/FTOoSWm_oe=7>OmNDdWoP7EbojFHT_o5]:cobKBYolRcYOo8]JGoakBUolJb
YOo6/ZOoa;2Vol6_YOo1/:Ko_JnTokb_Y?nh[:3o]jbRokJYXoneYj7o]:JPok>UWonaYIoo/:JTojjT
X_n_YJ<00_n^Y:800on^YJ3o[:>NojfTW`02ojfTW`?o[:>M0000J_nBVYcoTi^MoiBLW_nDW9koUIfO
oiVLWonKVYooUi^SoiROYonIWIooYjFSob0@4_li:2SoXXA8onBkL_o9Wi3oZi5dokbRMOn[TFcoZiR:
ojRQV?nUYj;oZ:NSok6TX?nhVX[o[7MDokRBI_o:YgcohZ9[onR5?oo?Hbco`VHkojYdCon<OFcoXI1l
ojQoH?nOK4ooOUA3oe/Y5OnQJDooRe4`oieV?_nGR7?o/;2/ofUZJolD3Pgo1PP:oj:3Coo][5[omKU[
ok:9DOnlSeGom[j1oi9[B?lj9QGoLU8Wom^TIOod/WCol;=eoljNGOondh7oeZU]oiA`G_n6M5coR7MQ
oiF4KOnQRVooTgIIoaD;4Ol^6@WoQ79IofeTFOlo<2ooPWAVoj>GQonRUXSo_k:Yol^n]_o8_KGo`KV_
ol2j/oo3_KKobkneolJcXooA[hooXWmQok2@LOn`TG;o/95cokBFMonQQF_oLU<kohaZBoo0VG;o[hIU
ojb8K_nTRGKoV89cohMaHonDNfGo/9V5omC1]_oA`[_od<6lom71^?o@`[D2om73]P1>om;4]ooCaKOo
f/FgonNmSooZ/FGoO3lEonblO_obdI3on]ZVogi58Ooo_hGoeYM9olRFK?o=RTOoiIm;olnNJ_mmHTco
K5=<oah=3Ol?1PSo6Pd9oa<?3_l22@ko1`T;obTN6on:LfSoWh5/oj:1I_nFNEcoNFEAoeY?AOmhLfoo
Thj;oijGS?nBT8WoRhJ0ohYeIonZPFOoXWeRofe9:onHM5;oaJ60ogmQ@OnVSG?oTgaUojF?N?nVT7Wo
QFeFoi5kIOmTE3goM6A@oiN6M?mkJ5[oTGiaoinCQOnNThSo_[>YolJeZ_o7/jKoakFVolJdY_o5/jGo
aK:YolB`Z?o0[jOo`K2Xokf^Y_nl[ZGo^:bSokR/YOneZ:?o]ZNSokBVXOncYJ3o/JFPok2VY?n^Y:;o
[jFS0_n^Y:800on^YJ3o[:>NojfTW`02ojfTW`?o[J:N0002oi:IW@;oTiZN06;oU9^OoiJLX?nHVj3o
UYbQoiNOYOnFWZGoUYbVoh1lU_lA0PGobZV3oi9/B?mK@4CoRW9LojnBI_n^SfGoWhQcohf5M_nSY9_o
WjFUoj^RW?nmTgGoc8mPofQ7?omXD4?o`HaNonB7BOo5GR3o_VLfokMoJolF1@GoB4A9odle;on_OV_o
PdT]ojASAOn[IdGoYFI2ojYcCOn[Ug[o]:jWoeQ@C_lW5@[oACDQom6VNonWLd?ofJ1eoal;0olP4Pco
eiQJooZiMOoe`8WonL1jomBHEonjQUOoW7IAong8UOoog8kog[1doi]hI_n3L5ooRWUWoiZ8LonNQfco
Wh=Sof=@B_meFT?oPf]BokF]Xoo5^[So_K>ZolFl/Oo2^K3oa;^dolBk]_o2^[?o`;^eol:n]oo5_[Oo
akb_olnm[OnjWhKoY8I[okJEN?naSg7o^9=doknPP?nZSG?oYXQcok:@MOndSVWo/HQWok2;LOm_Dcko
R6mNogUOCOn4JECoaJfLom:o]P;odL:m04cod/:iom31]?oA`kKodlFgomC6^OoDa;Gofl2]onNdQooS
XEGon[>4ooo5Ooo:WG;oiL2<oe8M6?oQ]7[oMePdodHR4OoWZf_okj=FooBfKon_N5SoJ4i4o`h=6?l3
1aKo20L<o`<42Ol320oo2P@2ob8>2?nFM5ooN50fojV2I?m/C2koQFeHog9QEOlk;RKoH5=>of]PEon?
RXCoW9FBogQTFOmnFTCo/he_oj5jEonfSFGoXW]EohQUAomkGTGoQF]Bodhd6omXCSKoN658oiN2J_nA
PFgoLF1<ofQE@ombGD_oWhYhoif=N_meK5ooW9J?ol6e[oo5/ZWoaK>UolBbY_o2/:Ko`K2Xol6_Z?o0
[jSo`:jXokf^Yoni[:Co]ZVQokFXXoneYjCo]:JS0_ncYJ800onbYJ;o[jFSojnUX`02ojjTXP04ojfS
XOn^Y:3o[J>OojjTX0;o[JBO0On]Xj41oj^QX07oZj6P00001on@UigoTIRNoi:IWonBVIooTiZPoi:K
WonAW9h00_nCVid0@OnEWJ7oV:2XoijOX_n`W6kodj:4oc/H6ol?6A[oCd4noei79_nOPU_oVhEZohj8
LOnTY9SoVZJYojRRWOoH[8?oaHeCochI2?m<:A;o_gi3olmV:_o>FRGo_EX/oj1D=?m=8`go70/3odL^
6?m]>acoaWI8ol5^@_nmLD_o/GAFogQ;<_nCLT[o^jRFofeB@onGKD[o_i5Nod`f8OlC0`3oXGQRoaD<
4?lI51?ociACom:>@Oo^ZUgokZaFoo35SOle9QKo3`d9odT]5?okbHSoj;Qnog]NB_m??2goNfUJoi5o
K?nOR6goXXEUoimmFOnRN5KoZX]fol>k]?nk^[3o_kNc00;o`KVe06So`KZcol6j/_o2^k;o`KZbol2j
/oo3^K7o_J^Mok2JQ_o7ZiKo_in8ojR2J?ngSVko/hUWok:9IOnfTGGo_Yj8okRHOOncTG7oYWmKokfI
NOnMOf?oRfiAoimnH?nMP6koe[fdom:o^OoA`[codL:iom?3^?oBa;OodL>fom?5^?oBa;OodlJiomS:
`?oO^9Koj[1boiQI<oomeYOoQEH^om^bQomjAQ[onm6:ofA6:?lY5QKo[X=Iol23G?nJKccoZ8IeofE?
??l<1`Co<2`/oeA1=OmM@S?oI4Xjoi1_EonHK4ooZGIGok:4I?n]QfWoY8I[oiR0Jom7<bCoIE54ogmY
GOm[FU?oETDmoiR4MonBO6koVhAdoiajGon_Qf?o^iAXoh5K=OnPOF7oVg]TojB5K_nVRW;o]Ib4oi5j
HOnRS7CoR7=PoiAoK?mmJeGoUH=]ohAbG?m/FTGoSHAioi:=S?nVWYgoa;:^olFdZ?o4/jOo_JbRok^Z
X_o2/:[o_jbXokj/Z?nl[JSo^jbWokNYY?ndZ:Go]:JUok>UY0;o/J>R00?o/:>RojfSXOn]Xj400_n/
XZ001?n]Xj7o[ZBPojfSWon]Y9l2oj^RW@7oZj>Q0OnXX9h1ojVQW`0000?oSiNOoi2HX?nAVJ400onA
VJ40]_nAVj7oTibQoi>LXOnCW:7oTi^Roi^KXOo7]:Kog;6?od`Z4?lG51Oo=2PGog=I<onURf3o]jJ;
ohinK?nIUhooX:FSoj2PW?neV7gohIUPoonlROnnN4KokH]BooB1B?o2DaWoiGY5olYW>OnjMckoh:Ma
onJRL?nkKSko/f8eok1E7_nmLTCoQ5Q5oc/S8_n2K4go/IN6og1;>_nZMU?obHaDodXa<OlU2Q7obZ1W
od<E3_m?9a?ol<AYoo2gJ?onb7Ook;mTonFoOOm19@co1@lNo`X=4?o?Y7;o`YEPodXn>_n3IEWoKfEB
ocTc;om5<BgoX7aNoj1[A?nTL4Wo/95lokjf/ono]kCo_[Bbol6g]Onn]K3o_kJaoknf/?o0^;Go`kRe
okni/onm_l3o/[>bokBWWoni[IcoZZ:<oln[R_njTgWo/WeEokV5Goo;Vg[o/hY`ojR;KonXTgKoZ8Y^
ojR2I?nQM5KoY7QLoj1kHoo?^jgobkbgol^o^oo=`[WocKnkolVj__oA`[oocl6bomK5^_oB`KSocKn/
ol_0/oo9/HWobiIUog@i3onPLU3oP5hhooBnNOoecHcoo/R1on^hN_n@Ic_odIERodHK5_nXR57o60/>
ofAMEomnJ47o?R<DofM9@On=Ie3oSV1GohIPAOnNKTkoZG9AojmiF_nZO5ooRG=Foi:0KomiGTooHTH`
ofaK@omKAcGoLUM;ogMGCOm/B3SoLTlgog=E?_n<KEGoVGIKojf5IonEK4[oWWQKolVUR_nkTgOoVG=G
oj^8KOmlG4?oYXafoi1kI?nEPfgoN6]Eog5UD?mcHE?oU89doh]jK_nIS8Co`kNcojfOTonHSXWoRG]j
oi>0P?nMUIco^K2cokR/Z?nn[ZSo_:ZUokNXYoncYjOo/ZRTojnTX?n^YJ3o[JBOojbRWon]Y:Co[:BS
ojVQX?nZXJ7oZZ:Q0onZXj42ojVRX0?oYinM0002oi2HX005oi6IXOn?UiooSiNOohnGWon@V:000onA
VJ40[on@VZ7oT9^ToiB7PoofbICoc9MAoj=hEOo=[87ohkEnokZCI?o2Zi;oP6]Ooe=C@_nMY9coVifM
ok6DOoo>Pd?okIYHolE`=ooOO47ojX=8okQC6oo?I3GodW94oi5>6?od[Foog8E?ol9X>OndGcCocgM3
ok=dDOlh6Q7o;ahTogMWCOm^DSgoKTD[ojM`AOo@TE;oU7<eolFMHoogagWom/5lon^iOOojcH7om;n0
on2`P?o2XFcoh[Anom:NLolC20;o60l9ok:4C_niR5Go>2`/ogULC?lX8QCo1@D>oa431OnKNEWoXg9B
oj1bD?ngW8Oo^K>aok^d]?nn];;o_kJaokje/?no][7o_[F`okfd/Oo9_KGoX9V>ob`b;Ol>4@_oNV]M
oi28Ool_;RKo[8Y`olb`WOo5VGCo_XeUolZHMOo5VW_o]YAhoj69L?nPQVWoXgaNokN7IonRMEco_If=
olNj[OnbYj3oZIjIokR]Y?nl[ZOo^:V[ol2`[?o3]ZGobKZbolRg/Oo9^:coa[>/omo0XooTZ7?okjm`
ojQdAOn?HSooc9EIojEfAOoEX73odi9EomnTJ?oIVFKohj9Xolf6C?oOWfKoDbHNog9=<On>IeGoJdXe
ogMK:On8ITKoR6U5oi=Z@onRLTWoZgYCojinFOnZOeOoVgQGok:<JonELUCoRGQUogANB?maETOoIT@n
og1=?_nLMeooOV9;ohIZE_n[RW;oZhAXoknFKoncT6[oUGIFokFDLOnhUgCo]ieoojR?M_n8L5SoMF1:
ofiMBOmYGd[oQ7UXog]XF_nCOFgoTGYYohMfJ?n7O7?oWiN6ofYXH_mLF5CoDTa6obXc=OmjP8?o[JZ[
okBZYoncYjCo/JFUojnTYOn^Y:;o[jFSojfSXOn/XZ3oZZ6Ooj^RYOnZXZ@00onYX:<2ojJOXP03ojNO
XonWX:?oYYnR00?oYZ2O00000on;UIkoS9JOohfGX003ohbFW`15ohfGX?n>V:7oSYRQohjHXOn=V:;o
S9bWoijKU?oL]X[okKQeom6SKOoL[g3ol;IeolFGJonGPGGo<RHXofQ[C_nDWYGoYjBXolbVS?oFSdSo
dWXeon>?C_o0L2cohHmAokmP<oo<JTKo^Vi1ok=g?ooOUUgo`6Lfok9G:?o6Jcgo`W=8ofTl9olP30co
>bX^oem==_nSQFSoU6Tookj;DOoMYV3oo<ajom:ODOnXKcKolkeiohMB7ongOD?olkn:oe<f:_lL4AKo
9@`0omZZNOo1T5koQE/conf_KOoJXV_o@BPNofeIA?l?20Go2@HDoaD82_nEO5goQfUCoj>1IOnSTWko
]KFbokVf]Onm]K;o^k>`00;o_KFb06oo_;BaokJ^Y_oNdL7oRXAcofIWFOo6^Z;odk2<oh=/Holk:RWo
Ufa?olV]Too<Yh?o_iAXokf>JOn^Of3oYGYRoj5mI_n^TGGo^I5cokF7IoneSWCoYi1moif8PonBP7So
UXIkoij>Q_nUUX_oXiB7ojRHQonaXHko/:6KojNGU_nVUi7oWhn3ojF8NooY]GkoahU@ojAc?omfDCko
NfE@oe`d6om<=2[o[gaAof4a5?mF?B;ofZQaofLf;oo8UFSoeIMNol2CEonaQEgoUVe<oh5QAon3IeOo
RVe:oh][Aon7H3goVW5?ojQlG_n_PF;o/hm[ojV1DoneRV7oK4/ioei3;omE>B_oITTnofY<@?mTA3?o
VGiWoif3KOnLOFGoYH=VolRUOonQOeSoYhEQojZ9H_nMOe_oW8AVoiN1Ion:L5OoUX1Yoge]F?moLf;o
D4HgohIaHOnEOfooUH1`oib9NOnJRG[oFd/eob4K4?mFDd[oT8anoh:>P_mMK6ooMWf2ojZY[On/YZOo
[ZNWojbVY_nZXjGoZ:6SojVSY?nXXZ?oYj2SojJQY_nTWjCoYZ2UojFOYOnUX:D00_nQWZ<01OnQWjCo
XYnSoj2NXonNWJ3oWifP007oWYfP0003ohNCW@2iohVEWon:UZ3oRYJPohVFX?n:UZ3oRIJPoh^GXOn9
UJ7oTIRZoi:GXOno/[7oA2lTodQ0<?naSdoodImSoj5hEOle:2;o10L;ofMTA_nAVY7oWiZGolJIMoo:
SE7oe8]AomjGFoo7Q3oof99Dol1/A?nlJTSoaHMNokAlBOo<Q53o]El_okMS=?o2K3ko_W54ojYmIOl`
6aOo@B`^of1=?_nDNEcoQf8fokfGIonBKT7oml20ook<QoogagWooLbDooG5Q?oa]f7ooln=od4/5ol@
5BSo4A<GohaaA?o[YU_omKIjoofiL_oVZ6co]HecogY/F?m4>c_o9alQofYNDOn1KEOo5@H0ogMQD?mi
K5_o/kFcokFd]?ni/k7o^[Bbok^e/oni/k;o^[Bcok^`Z_ogk=go@ch^okFaXOo9ZXOofj1Yoj1aEOmU
>c?o^WQ:okfAHOoIYW[oeZQlolBCK?o8UWKoUfQ@ojf1Jon`RfooZgmNojUhF?nPNV7oJEI5of9:A_mf
GdgoMf9<ohehLon6M6WoSgeUoi1jHOnBOVGoGda2oe0m>?n:NVWoVHMSoij7KOo=Y7?oVFM3of<j8_n_
NTkoWW0oolf8DonWMe3oj:APom6@LOo3UV;ofJ5hobLD4OlP4aCog:UWojeoCooS^8[o]H5AoeL^5_nD
OF[oOf59oh=SComYAcGoJD<boe<]7olk:bGoIUa=ojB8I_njRf?oS5e0ojN6K?meED7oAbLIogIHCOmn
HUKoN5i;oiIlJOnFNVOoZheeojn@LOnmV7Oo/XIUok:5HoncQfGo/h]^okB@M?nOPVCoP6E<og=MB?n0
KUooNFQJohQaGonDOVkoXhalojbCP?nQQW7oPee6oe0h;?mF@CSoTWMYoh]jK?n2Q8?o3Q0Dojn[/_nZ
Xj[oZJBWojNTZ?nUXJSoYJ2WojBOY_nUX:OoXijVoj2NY?nOWJCoXZ2Woj6OY_nPWZD00onOWjD01?nL
WJ?oVi^QoiRKX?nIW:81oiRMXP000on5Tih0BOn6U9ooQI>NohJDWon7UJ3oQI>NohZHXon;VJCoRiNS
ohnGY_n7UjCoVYR]ob@G:OlX9bGoSg@domVWJonhR63oFT<^oaLB1OnKRW7oQHQoojRQSonoTFOoSU`h
oiM/BOo<V6[oe9EKolN2B?oARego[6a9ok5jE?nlQEOo`WU9okm^?oo5OTgo^G54ojmQ:OneNe3oHdHd
obdJ5?lj9R?oJe8oojV?LOm;>2Co6Pl=oiib<Oocbg[od:ebonBoMOomeH7ok;^2ooG7Q_ndTE_o=b0C
oblD1_niS5[onKUaohQ82_oOWUOobXa:olVEJ_n6MVWoQgQboi65K?nAPFCoGDI0o`X52_mA@3OoNfeP
ok>`/?nf/;?o]k6aokJa/Ong/[800_ni];@0J_nj[Zco/J6Loa<<2Ol;107o]HQUomf>ConcPUWoOT]2
ol=h@?njQT[oaHaOolVEJOnhPeco`Xa]ojemH_m`ABgoWfiCojE^DOnhOf?oXGIPodL`8_m?<R[oNem0
ogYQ@Om5;2koA2lZoi=kH?nUQVOoQfU=of14=_maFDSoWhQTomBWN?o6Wf_ofJM`ok=mB_njT6goFc0=
omJ9A_oFQD[oiYYRonNTHOm_B2WogY5DomF7C_n^ODGoREL^on2]OolY1PCo_YUfol65AOnYN53oX8UN
oiaiF_nHNF3oOUm:ofi9=OmgD3[oIE0moah?2_li7Pko_99coj5gEOnNLUKoZh1Voh5LAomWASCoB2XO
ogMND?mK@SGoME]?oif2LonDNFCoYHM_okFAM?niT6goaIUcolVLN?n`QF;oY7eIoh5N?_n@LUSoPFIC
odlg9_n7KEWoPV]IohafI?nNQ6ooRfU?oh9I>_n8K5koEc/cojAnJonPO6Oo6@d9oaP<3_l^82Wo[9jZ
ojNQYonUXZ[oX9jYoinNZOnPWZWoX9jZoijLYonLWZP3oiZLYP08oiVKYOnHVjGoV9bUoiRLYOnHW:Co
Ui^ToiBKYOnBVZ@1oi2HXP000<?oQ96Poh>AWOn3TIooPi:Noh>AW_n3T9coQI:NohNDX?n5TikoQiBP
ohJDWon8UZ3oRIROohjCYonBQXSoGSlIom>eK_ob`hkoaiA`ok2>J?nPQeSoajZ@oc/e:_nWWHKobYi`
ohiO>OnaSFWoUW1<olVHLonkPEOoVV@gokn;IOn@F3KoYfe2okMbAOnaKT3o]gmBojUjDOoAR5Go_Vdm
oj1mG?mnKeooC44nofAC@on`VX3o3P`9oa0A8?noUEGobjMeob<>8?mH?Pkom<VAoc<D5OmdCbkoo<Qg
onneQ_oHUV;ohIINolbAH?oN[FcomkEconZVHOo9UfooPg=XohmoMOn?PF7oTgiLohYZHOlP3P_oMei?
ojbKT?n`[k7o]JncokF`/_nd/;?o][6dokJa/Onh/[;o_K2boj:;N_nRPV[oSF1:ojQU@?oUUEOoZ7E2
ol67L_oj[G[of9]RojifC?oFWG;ob91/oi=M@?nNJe3oX6mEoi=G>_nYITGo/W=Coj5dFomM?RcoK4Le
og=B<On6Jdoo?28NofQ>A?nKNeooZ85Qojf:J?nMNUco/8]VomV[NOoVWFgokkEaonFWGOoEUd[o[gi8
oahL6omC<aCoE2lVodTU4_n:L53o1AHFoj1WB_ngRUWoTVTmon^YH?mmC1OoU6m;olFKL_oKXfKoK3l`
obdG2?nVQVKoXGmPoimoHonELUOoWgABoj1dB?nYQ6koWGY/ofi8;_nELDkoRf0jok23GonUNEcoLTHb
og98>omH>C3o90/9ofU9A_m`CD;oQ6IDoj2:MonkYXooa:N6olj[P_o=YWko^I5ZoiM/A_n2EcOoN50i
of<o;omiFdgoITDdog=IB?n9Lf3oTG=MohaXC_nWPEgoT75Goe0g9onIOF[oU6]Aoi=QAonMKekoVWin
ojNKZ?nRWj_oX9nWoibLZ?nLVjSoW9fXoi^NZOnHVjOoVIfXoiRKY_nGVZGoUYZUoiJIY?nEVJ?oUIZT
oiBIY?n?UZ7oT9JRohfEX_n=Uj<00On>V:@00033oh6AX?n0T9ooPI6Poh:BXOn1TJ3oPY2OohBAWon6
Tj7oQ96OohFBX?n6UJCoQiBPoi2BW_n4UjgoUINAon^hN?oQ^6[o_9Ifod8R5OnMOe_oc:Ubon6oV?ni
Z9;oWY5noln`S?o:XG;obJElokJSSonOU9?oYi>;okFLQ?nfVh;o_IB1oj9hGoneS73oTg5Goj^BPOnM
XZgoZiF0olb1BongQ4CoYF=4oi9X@onhRU3oijUbocHN0?mH=Q[okkIiogiG?ol94Q[o=BL1okN:JOlF
61Oo8A09onB`LomS;1Goe:AOombSJ?m08Q_o@STBonB_LooQWfkoNEY7ohEeI_n7O6coN6UGoi1dFonG
K4ooTFE:oh]VBOn/W8koZk2cojn]/_nd[kKo/JjeokF_]_ne/;Co]:jbokJWYooT_XSoo;1VonIm@ooZ
ReCoaWi1oiEW?Ood`HcohYiNolR5D?njR6Wo^H=NojQfE_n@GdGoPDP_ohi=<OnaK4CodHIGokj2E_nL
N5goT7ILoiYhFOnCKe7oTVmBoiYgF?niU73oYgaFoiQZ@OoAYgOoh;R4olNML?o5U6KoeI]IooW:ROog
^G;ohieJojEW=_nKN5Oo<aT9ojQlF_mXA2_od9USodX`7?o:PeWoVgUCoah60?o2Qego`hYJonJ/J_oe
/Xgol;iboj62B_lR2P_o@BHEok28J?nQOf7oW7aPoiUdD?nKLT[oNePlofI7=?nDLeooVgIKogmH>?nH
K4_oZ7EAoiEJ=_nmOe[oP4X`odhQ5OmX>37oDQlBofi;?_n:NGSo]ZRVok:NS?niWWgo/Y1[ok>;IonR
LD_oW6I8oga8<_m]?S3oJClcof`l;?mlEd?oJe0gofa>=omkED7oR5`loiU[B?nSQg7o?RTIok=oG_o0
ICco^Vm?ok2@QonKWJSoVYn/oibKYOnIVjOoV9^WoiBHXonBV:?oTIVSoi:HY?nAUj?oTYRToi2FX_nB
V:CoSYBPoi2FXon>UJCoSIJUohVDYOn8U:GoQiBT007oQi>S00001_n0T9ooOXnNogn@Won0TJ3oP92O
oh6@W`;oPY2N0;_oQ9:Qoh>AWon3Tj3oQYBLoh^CW_n0TjSoUIRLokFBKOomdhOocJfEoc4T8_mfI4Oo
eJmhokJ<G?nhY8SoWIJ5ojVJR?n_XI7oWYJ=oiVOZ?n?Vk7oWJ2]oiVIW?nIW9ooVYRLoj:NXOnOVYoo
WIjToifPZ_nOYJ_oThnBocPA2?oDYF[on:]dombUN?nmQe3olZ=Hon>`M?oQYfgohJYLojAaC?lF1aCo
D30FonfeO?lh7PgoGCDDonb`Foo=UV3oaHQAom:FI?l@2`Wo20DLojnGDom/@cCoE4/fogYVE?n0Kego
FTHaohi`FOn7GdOoSV]@ogIF?OnbZ9ooYZbgojjZ^?naZk?o/Zfeojj//onb/[Oo[JfbojjNVooQ]83o
lZAMonn<A_o_T4SokJ1PoknJNOomg9ool[]Yolb7@OndL4Wo]X5Rok9iFOn8BROoZVLoojmW>ooDS4oo
hIMFolN>F_mkHDCoQGMRog5RDom[DCOo^XeSolnMJ_oDZWcoaYmholNIJooR[73ok[j5ohm]C_mPB37o
dZa]ooG@V?od^X;oXU`WomjNM?o9P4goY612onjZF_oSW6?oihm?onnUIonHAa;ogJE[ogi49?o5R6Ko
biN0omJQI_o[[Vco_H1SonNmN_nUP6ooWWYNokJ;IonbTG7oXHIWojF3G_nJMeOoVG]Todhf9olM2PCo
SW]/ogaDC?n>He?oZgQIol^>GOoRWeooe8mFoj5P=on[JD_oYFA9oi=WE_nCQ8GoZZBXok2UV_o2[9;o
^iUcol2FJon^NU?oVF0moja_D_n=CcCoR4/_oiaL@?n?FckoM4``oiQdF_n@J5CoV6iDoiAbF_nPRgco
ECTXok5fDonYI4KoXgU_oinHX_nEW:coV9bXoiNHYOnEVJOoU9VWoi:IY_n@V:GoSiNVohfEYOn<U:?o
S9>SohbDXon:TJ3oSIFSohbDY?n9TZ?oQi:TohBAXon2T:;oPHnQ007oPHnP0003ogb=W`;oOXnQ0;Co
Oi2Poh2@WomoSikoOhnNoh2@Won1TIooPiBMoh>CX?n3UJSoSIFPoi:6OOoX[6goGCl`ob4K6omYFcko
bimWomb`O_nkYh_oNWEZohb:Q?nDVj3oUi^Soi:M[On:VK3oUYbZoiNLZ?nCWZ_oU9fXoiBMZOnEWJ_o
Uin]oibO[onWTYKo_I]cohIN;_o7Y6?o6P43oe]=<_lP4AKoi;=Nok=lDOnMI2_oi:aYonRSGOnaR5?o
cYaGoo2UEooW[gKohJ5Gon>MH_naOE[obXeSolb5<?n2Dbco=P`=omF^F_m?;2;oFUDmofaE@om^FDCo
:143ogmTDOmdED?oIThkogMQC_nm^;GoYZflojfZ^_naZkGo[JZcojj[/On^[:koZZZXoj>CS?oL]hco
e9ELon>DCOoYVU7ookn1ogaH=?m^Dd3oV6U>olElC?o2LcSoYUT`ok5M;?oKPTOoc7Ddon^IFOoo^X3o
bG/nok9b?on6HDGoT7EOob0G6?lj:1ooZh1Kom2NL?n_RFWoCC@Ooib0GOoQ[W;omKYkok^<H_mR?2Wo
bYAconRmO?od`F_o]812ogmD@_nWHSkoZfe2oj9Z?_o5QCko_78koo2/KOoJWV_ohj9<ombBEOoCSEWo
OeLhoc0@1OoA]6OoDBHSoj5oK_mG>PkoWW9Hok>8K?mO@c?oGd/noj:3L?nZOeooX7UJoi]hFomjGTKo
@R/Lof51;?mbD3[oOeLmokR2G_o;RUcobHeJol23E_ngK4;o_fTkol1iD_nOOg;oY9VIoj^JU?o5ZYCo
dZQoolRHJOo2TfgoY71?oja]COneKDSo^Vi5okAU?oneL4coYfi=ohEC=_m^@2OoOEY5ofQKE?l/:RSo
L5U<ok9nHOnTKUKoWXb?ohjI/On@VJ_oTYJSohjDYOn>U:SoSiN[ohfGZOn9UZOoQiBUohRCYOn3Sj42
ohF@XP08ohJAX_n3SYooPi2Qogn<X?n0SjCoOhnToh2?Y?mlS:01ogj=XP000omjS9l2og^=X02nogb=
WommSYkoOHjNogn@X?mnSiooO8fMoh2AXOmnTJKoP96QohB@W?n8TIcoa8mWodTY7olb8QSoK5</on:b
Moo8XG[oPG1Moa8>1_mNGU[oTZ2Uoi:KYOn>VJOoSib/oiVLXonGWJOoTij/oiJKYonDVjWoUYfXoiVK
X?nRWYcoY8UUomf^QomP=AoomKaWojAh@OniReOoNee1oo>^F?oWX5kohZ=WolZUJOo`[6Goa95XohmJ
;?ob[5Co_X9Cojmk??nMO5Co3`l0oal@6OnlT6CocXMFon2MH_o1PSco]8AYohagG?m_FTcoKEU8oe4m
:omjIE[o5PH4oa420?mdI5koZZR[oj>/^on[ZKGoZjReojfY/_n^Z:WoZZ6IojFKS?nNRG?oe[20oh9;
6?o`[V?ool5domNAF_nMMeOo60X=ocTP9?n8DSWo`WQ:omIc@ooJLSColhe5oo2ID_oQWE_o^Xa/oj=[
@_o9TVKo`YMaom6VNonLNf;oS6U:olnOKOoN[7GoaYedofI6:OnONeSoeZA[ombSHooEX6kodImjolfD
J_oPZVgoiJQKom>JFom@9@go`HYQog0k6oln60ko^XA>oo>nOomS?R7oJd0Qon^XDon4ERgoT5djolVO
EOle3`Wo_IEbolBQH_n3G4?oiL2Eom^aQ?n`RfWoAcL/o`h31_mH@cooZh9Zok66IOnTNeKoXGeMohe^
EonFOFWoXHakogaSEOn@K5WoZWQLok1jDOniOUOo_6e3olU^??o8OE?o]IB7oiV@UonZX:Wo^JVUol>S
R_nfTF_oOE`noi1WCOml@bOoa7YAolIc@OnlIC[o/5hfojiV@?nXJ4CoYfe<oi5N?olU5Q7o1P@5oh5P
C_nHGd7oYFa;oh9cM_n8UkKoSiFWohfEX_n6U:WoR96YohF@Z?n4TJSoPY2Woh2@YOn2TZGoP8jSogn>
X_moSJ;oP8nSogn<X?mmS:3oNh^QogZ<XomiS:CoNh^SogZ:XP7oNHVQ0005ogN<W`2`ogR;W_mjS9ko
NhfOog^=WomlSZ3oOXnQogj>Y?miT:OoNHZJoh2>VomjSZ;objNAohMTComfEcSoe:ioombWK?nVPF;o
E48do`h80Ol`;RGoQXn?ohnJY?n<WJcoR9RWoi:IXOn?VZKoS9Z_oiFIZ_nBVZ_oTYfYoiFHVOo0/Ioo
hiQ=ojae@Om<>Qoohk5KonfcKOof[fkocjiVoiEA9ooT/VWoPfY:oa/@4?n:Eb[obii^oh5C<_o/]Ggo
fYMPonBKB?nRL5Oo3PT2oa842?nTO4WoRU<dom2LA_o6S6?o`8iTog1;<Om/ETcoJUM8og1NCon1KfOo
?B`Zob8?4on=OWooYjV_oj6[^OnYZ;3oZ:NeojVU[_nUW9OoZYZ9ojbGOonbTfgon]JGomNHF?oaZECo
oKISon26B?o2JBkod9YTon6YKOnoJ2[ogF/eom9Z>?oOMcWok8e8omjIF_nbQUOoMVYIocLL0on<J4Co
bjQkonBkO?oc_7[ol;MbomZQD_od_F_oi:m[olnFHooPXfkohjY_omZYL_mcBA_odjaoon[0M?oEXWCo
_GEAoo^_Noo;Rd[oc8a8oj]W@?mK;Q3o`h9MooW6N?m<;ROoFRdKooZhK_lo<Boo;QLEomZFF_oBUE?o
d8eTonJ[GOoJWgKon/N1ong5ROoSaYOoXYN5odY5??m4=BcoYhUjojV8JonVQF7oXX9Tog9F@_lN1`So
M6AWoc<U8om_FDSoRfM5ojiaAOnoMd_obgI:oki/@_naNf?oSGj0oiBEZonGVKKoW9f/ojJKTommJ5?o
NF18ogMHA_mX>bOo^WUDom61Coo@Nd_o`fm1oki]@_n_Hc[o]W18oka`@?n;IU3oTGMXoj1[BOnaJd?o
[Vm4oj6?RomoSJ[oSI6VohRBX_mmT:SoPH^Woh6>ZOmlRjD2ogb<YP0<ogn?YOmmSJ?oOXjTog^;XOmh
R9ooNh^PogN8W_mgRJ7oMHVQogB8X_mdQj;oMhRS0OmcQJ000007ogF;X?mdRYooLhVNog>9W_mfS:7o
MX^OogV;W`02ogZ<X02Zog^=XOmlSZ;oO8jRogb>X_mmSJ;oP8nToh:>Y?mmPhSogkYfooFjK?oc_8So
c99EolFEF_n_Qf3oSgMMohAkIomoOgOoTYVPohjEX?nBV:?oSiRTohfHZOn=V:[oU9NUoiFHY_n=W[?o
UibQol>WR?o^[f?oUEm2ojMm@ooZa7Soo/Edoo>jMolL40koHdTUolbGJ?lG4QCo0``Kof98:?oWYdko
o;R1ohY_>olj9`OogIiLon:GG?mL>bOoID@[ol:8E?o_XfCo^hmOob`O5OnSME3oQFMEofA9@?mSC3ko
Ie4nogmTD?mjFDOoMDHnoiJ9R?nOYK;oY:FgojBU[?nPXj[oW9RBojRGO_nhWG_oajV:okVJM?o2SECo
ljALooVaH_oGST3omimEomQk>_oTUE3olYiJomY];OoYI2SoiFl/onV:A?oYWEOo[7=0ohY[Fom_I5Go
EdHhoin2LOnPO5_o^I1Moo38O?ogcXgol;f8onRfJOoX]WGoiZj8oo>mJ?okaGgoj[F9ok^>DOoN[Wco
k[Z0ojAjE?nKLEGoWVHnolV2B?oRVTSoj9UYoo2WF_o0ODComL:6ojIgDon[LdGon<5aohQM@?moBc7o
iiEEomfOE?o2O4WobI5MocdH5oo5Tf3oY7AEocdX4on7KUoobJZ0ol>RO?nkW7[o]Y]iojF:K?nMOfKo
XWmZofQHC?lR6ASoGeIHogENDonON5So]7]DomB<Foo5MT;oXf]?ohYlQOn4SJ?oSY:aoi:E^?n=VZCo
V9fGofIEBOnBMf;oASD_od0Z9_nLLEko/gMAolV3BooBQU?o`W11ok1E:oo0H3_od7Q3olR2E?nmO53o
[6HdokUhCon/O5koV8V:ogf;ZomlRjcoO8^Qog^=Y?miS:X2ogR;Z@04ogF8Y_mfRJKoNHVSogN8XP?o
MhNQ00OoLXNSog>8YOm`QJ;oLXJSog25X_m_QZCoKXFT007oKhJU0002og69X0;oL8RO00?oLh^RogB9
X?mhRZ000_miRj42ogZ<XP03ogV=XomkSJ?oO8bS00;oOhfU0:[oOhn[ogUH>ooj_VKon/=Uom^XL_oE
Zg[oeZMaolnRK_nbVGSoIVIKohbGX?n7UZ?oRYNWohbHZ?n>UZSoSYJZoi6FZOnBUjSoRiNYoi2@U?n>
MVCo]851oieaFolZ1@Co^Z9`of4`2_n`QeOo4@PNohmn>OoHXG3o7PT2oaD82?nGKTooeY1EonVdKOlQ
3a;o1P`Nok^1COo]/6Go`9]Oon6JFOmL;0go[7PnofQ3>_l>2a;o_8ARoh9_I_lc9RGoAS/hobTK5Om2
;BCoId]0of94>Ond/[OoW::iojFQ/_nNVHooXiV0ojRINonaWG[o[IEbojR?L?nIMEKo^GaDomR<EOog
]fcok:ICooneI?on]6co`GHboo>SIOoWPDOogF@/om9/8ooiZ67oc8M1ojM`?OmK?B_o8QDPohAgJonH
PecoZHMIoie^Aoo0Tecoik]ioe/U3_oIZWco[XQ>odhU7?o7XWWoXWM@ohE?<oo_]7?oi:QXoo_=S?o=
ZGKoVgMDolnQOomY;Pcoj;5_ol24D?o]/V3ooLMnoo:fN_ola7_ook=booJhLOof^6ool:=/oga98oo^
/fCocIEPomVWM_nQLTkocJ^5omjeQonlXhkob:j:ong;Y?oZc9Woc:aholR[RonfVhgoNEmBojB8M?nW
U7;oPGAQohEhLOn<L6[oZGe/ojiaA_o?TfWo/XI]ohemOOn2SJGoPIBcohND]On4T;GoOI6XohfEVOmT
ET[oRG=MofILEolR5QOoH4@hoh5E>_naKe;o`F]6om9^A?nlFCGo[54iolA/@_nmNEGoVE`joj5U@_n`
OFCoXXN5oh22TomeRjKoNHbTog^9YOmgRJWoM8RUog>7Y?mbQjCoLhNUog>8YOmfRJKoM8RUog>6X`;o
LXFR00OoK8BQofj6XomZPIooK8>Qof^2WomYPZ3oK8FS007oJXBR0000]om_RJ3oLHZQog29X?maRZ7o
L8ZQog28WomcRIooMH^RogJ;X_meRZ7oMXbSogF;X_miSJCoO8jVogb<YOmmSJKoMHnRok2OV?ob`GWo
ej=>oiidI_l]9R7oK5P_okjFGoniUW?oJV1?oh><SOn6UiooQINVohNHZ_n:UJOoSI>YohfE/?n;UJKo
TiBIoi:3Noln9aSoPFPkoe0j;om5=Bko71PCofEF?_n[LDSoF3LWomf`Ioo_Y4coeIQTom2MKon`L3Ko
`GQ1omf[DOlb51;o8`h6omR@E?m8;B3o5Q8DomZDC_n^PDSocI1Eoim^AOlM3@Oodim^oa/F2OlB30ko
7Q/NoaD=4_lD1PKo?BPUod8`9?nRYJWoV9Z`oj6EWOnRUGWo/iakok:INonMQ6SoRFiGodT^6_nPMdoo
/WU8olV;GOo:RT_oei5?oo>WKOoTUDgocHM7omB;E?o0JC;ofWLmonVAA_oj/V_og9UBon>ZL?nSOF3o
CD4aoc/]8onNR7_oWWUKol6BG?oY^G[ojKEXomjPMoo`]X;okl=loii`B_oFZfSodJQaojAhC_oZ_fco
kKeYoo?2N?oZ^GWoYG8mokf4EOo1PeOoijIaokf0C?oAWF;oh;J1oeT]5_oRWeoolkInonfiKon[MU3o
eJ5hoehU4Oog^Xco@R`Qof=>?_oRZeKofjieomVgPom@=2;oeKJ7ooWG/Ooeg:Koi/J@okbQQ_mOAT;o
LeiFojJCO?nRR7?oRgMYoj^IS?nPQ6ooYGQGolb?GonkS6_oVhV5oh69VomoT:ooN8fbogf?/_miS[?o
MY2eohJ?WOn7NfcoL5m;oeIBColB3Q?o@2hVofM4;On?CcOob758omM^>_o:ICSo/Udkoii@<OnLGTWo
IC<Loh9GAOn:LG3oOgbEogF8Z?m`SJOoMhVPogJ5Y_mbQJ_oL8NVog26Y_m`QZGoLHRWog27YP03ofj4
Y009ofn5YOm^QJGoK8>Uofb4Y_mYPJ;oJH6SofMoX?mZPjCoIX2P007oHGZJ0000/_m^R:7oKhVRofj8
XOm_RJ;oKXRQofj7X?mbQj3oLhRQog:7X?mdRJ;oN8fVog>8XOmgS:GoN8bUogV:Y?mjRjGoNhbLohB9
S_n[TWKoUfi>odLY;_l?3AWoGE8`olBWM?o8Yi?oTH9eofMWFon;UICoPI>Moh>EZOn7UZWoS9BZohNE
/?n:UZ;o[9b:ol>NP?m780GodYeKonJ_M?oV/V?oDRP7olJGF?oJVF3oWW1:omBMI?og[eOoj:ANonZR
EOo^[f[oejAdoknBEonmREKochi6ooZVGOm8;R[o7ALRom6LH_oIZVGo]H5Jom6KFOnnT5ooc:9^od8_
7_lF2@Co7A<Cob/Q:OlR5Aco?BX/od/j<?nQXYcoWIVIoj:>Q?n_Vg[o/YYnoh5WD_mA=BCoUGANojEm
Goo2TEko^HeLol>KN?o=TekoaGi3onJPKoo/YF3ohJ1Wolj=F_nnMSgofhY7onBBBOoVWESo^g<YonJQ
G?ncOD_o[I=[oiEmKOnCMGGoYh1ZomNWJ?o2VfGoWW13ooNnN?ok^gConL24ooFmN_od^fWof:U_ojUn
GoocbhSollV6ojakAooV[g7ojjeXolF2@_on^h3ookf9omfTL_mW=QkojLVQodhT5OoNW6KoVWeEofHj
2?mX=bcoVW9CooJcLoog`GWoNVE<obhB7ooNYf[oXF19ogeO?onlWX?oek28ooKAY_oMaI_ofl2KokBL
Q_mOC3ooJ5E7okfXT_naU8WoO6MMojZLRonWSg?o[HMNoj5nI_nGQ7ooPhJEogf<ZomnS[3oNX^dogV=
[omdS[3oLhnmoh:9WOnCPg3oMFIEoalI6OlE3aGoAblVoimdGOnWIdKo_6e2omEhAooAMDGoZU@]ohI0
;?mfA3[oJDHmoiN4POmiOhooMXJVof^5[?m^Qj_oMXJRog62Y?m^QJX2ofj5Y@;oJh:R00OoJX:RofZ2
Y?mZPZCoJX:Tof^3YOmYPJ?oJh>W00?oJ82T00?oIGfQof9oX?mSPJ400OmUPZ80002bofZ5W_m/Qj3o
JhJOofZ5W_m[QYooKHNOog28X?m_QiooL8RPog69XOmdS:CoL8RPogB<Y?mdRJ;oM8RQogN8X_n0PZ[o
MXVQofUWN_lf6b?oCcl]ogiDAOn`R57odk5jogaRGOl?20SoDD/iogQgJon9UYcoQ9JXohFDZOn7TJSo
PYB]ohnLXOniWW_o`HYFok1mFOn?FBgoj[ANonNYGooDXf7oMC/=oo?=Q?lO0@7oV7iAojZ2H?n<JSco
eYM>om2VNOlQ4`;o:@XDonVZFoobZ5GogY]<oobhH?o`/5cokKIbokJ7Gol>2@SoVGMEomfKC?nXPeoo
eJ1ooi=jIOlX50go<b<ZobhN9_lY61coK5E?oh1jJonDS7Go[9=jok:INon^WH3oIeDmohA/E?nROUOo
eJ=Xon6/M?m58PooBc8QooS@U_oVYEKolk9`om:<D?nnOT_o]gU;on2QI?oc[f?ojI5>on>DD_oTTdOo
njeNomVFDonJKeGoWgeQoiUlEonaSF7ohZn0oc8N3Ol]4bGod:URom>MFon7C3Woj;Econ^iK?o6V6[o
I3<PomRQJOoNXg;oOUY9oj1bAooV[6cojJaUolR<BOnCJC;om]VXoeDT6?oicI;o/G8moo2]G?nlOESo
RUhmomfEH_oJSeOodYEVoo[CSook_7;o/Va>oj^:>oo;VWoo?1dBom2bT?nBID[oh[^;ogMOA?miHeGo
Y99ool:bV?ndXXWodk^TokJNOono[iGoNFeIoh]dI?neSgooRXbNogB6Y_mbRJooLh^gog>:^?mgR[[o
MHVXogB=[OmcSL3oPHBJoiV5LOmOCD7o;B@WobPJ7omnGE;oZ7AGok=^COn9@RCoYUPlokEO@onjGCoo
RD`noedg<OnHPWgoPGn4of^7Y?m[QJ7oK8F/ofb1[ombOZCoKh>SofN2X`;oJH6S0omZPZ@2of=oXP03
ofJ2YOmWPjKoHgnS00;oIh2V00GoIGfSofAmXomRNj7oHGfPof1lW`01oemkWP0000?oJ8>NofZ5X?mX
Pih00omZQJ002?m/QJ7oKXNSofn8Y?m`RJGoKXNSofn;XOm`RZ7oL8RP0_mcR:40X_m`RZOoO8JRohf>
X?m>?2SoeZIPonjbL?o/a7Wo_j1ZogUCBolY3a;oKU/log=[FOn;VjKoNYJRogjDXOn9U:SoQ9Z`oh^P
RonjUFkoVFiGo`D71?n<JcKolJEFodPY4?oc/GOojj]OonnbKOo1Odoo_J=[oa8:5?l84Q?oVem2om6K
I_lE20ooBS8DojZ6FOlf40WogKAbolZNH_o7U6GoijYIoi=N=_lE3`[oUVHnob<S:_neRV;obYMbohMZ
AOmaDSOo?R4eoc0T8ol]8BCoGEE1ohn4I_nFQFWoYi1lok:JNoncTg;o_IIaokZJM_mjHSooU751onjg
QOmkBbWoP68foocMX_od/ggo`WU@omjFJ?oAWeooc8eHom^=GOogYf?olZ5?oo>_Lon7CAooSe@Oon^U
GooNYFGoijIRonFUI?ol_hKooKMiomV>JonDL3[odYUQonN/Joll71Wobj9XooRjOooY[eWobhmNonRi
JooneY7ofjAToiAK<?oGWg7oo/^@on>RJ?n1BbKonknDokEX=_om/f_ojJMIooZoIOohZ6?oml=koo^j
Jooo^F[oAblWogIK=OoobHoojZU>olN8G_oCVf3odI]^on2]KOo3T6coh;BFoiAeDom4>S;oGDU0ol:[
S?oJ`ISoeKVNokbHMoo0XhkoQWQYohN7Q?n2R:KoMhfbog6;[omdSK?oMHjgofn8/OmbQ[KoLXRZog6<
[?meQ;goNWnHoj2KQ?mNCCOoETHkofeEB_n`Q6go]WeHojekE_nLHdcoU5A7ohI1<?nMDc_oReD[oiV0
P?mjPZGoK8F/ofj2[?m_PjgoKH:/ofb1ZomYOZSoJh2ZofQoYP;oJ82T00_oJH6UofZ2Y_mXPJGoI7jQ
ofN1Y?mWPJ?oIX2SofAnXOmTOJGoI7jVof=mY@02of=lY07oGgbS0OmLNJ01oemlX`0000?oIXBNofF3
WOmVQ9h00_mYQj401_mZQj7oJhJQofR3W_mZQJ3oKHRSofb7XP;oKHRQ0:KoL8ZSog28X_m`QJ3oLHVQ
ogJ9YOn0S:CoRWi[oo_8OOoQZgKoRfiNocHY:OmbHdkoSWeNoiZ9JonBRX3oQI6Mog^EX_mlTZGoP8n/
ogZ;/?mcLgcoXW8lolnBI_lk5`Oogj=]oehl=?l230CoilE^ogQF;?nRQ4?olii1olFCE_lI4Q[o5@X9
ojIfA?oKUTKo]gM8onNNG?nKHSOo;P/3ooG:U?mVAS;o4@`Noe@e6OoPWFcoaI=PolQn@?n9F3;ohZeh
o`h>3?mOC3[ocI][of0l=oln>2ooDSXgoe4k=_mcH57oQgAQogaVE_mVCdGoVWUComBaK_nbSfgo:`PG
ogY@=?oW]VSofJUXomjWL_oY[6[ofZaPojj@COmVB2_oX7M8onZ/GOoZZU[ofZUcojN6HOoK[G[ofZ9Q
oo_1O_n^McOo_iATomFTIOoS[FCobY]MohMQ>OoAV5gokiU?onZGK?oDVToon[9honb`LOn@HDco[GU1
ooJjP_o@T5goiZ]WokEmE_oGXV[oj;IRooRoLOo?REWonlZ<okIf=_oGTUOoo<1kooBnO?neP5[oeHeU
ojelC_o<RekokJUAofm0?omF8R;oo/N@ol:>Goo_^WSoolQconV[M?oMYU[ofJQhokbHK_oE^hgoc[:L
olBPR?occ:3ol<RColJKMOnoUVkocZb=olZdVOnm/IooShVDogV<[?maRjooLHZ`og:;/om_R;7oLHFd
ofn6Z?m]RJcoL8JnogZ:Z_nOXi?oVGeBohaVB?nQLeSo[giJol6FK_n1Ni?oT8NQogAWNon<Ngoob[VZ
omK2]OmnNhooJWfWofJ2ZOm]P:WoK86[ofZ1Z_mYP:WoIgjWofV0ZOmWOjOoIX2U0_mUOZ@03_mVOjGo
IGjTof9nX_mROZ?oHGfRof=oY?mPO:;oHGfSof9nY?mQOJCoGWZQoeijX?mLNJ3oGW^R0OmLNJ000003
ofJ5XOmRPIgoIHBP00?oIHBP0_mVPj00Y_mUPYooJ8FRofZ7Y?mYQj7oJhJQofb5XOm^Qj?oL8NTofj6
WOm`RjOoLXbWoh=nN?oZ]7GogZ=Loe8_;?lF1QOoJEDdojb?H?nLR73oASdjoe9IH?n2Ti_oNi2TogR@
[_n1SZ?oV7n:okJ4=_oNWUcoe9=Uolf2COlS3`[oCClOojj4Bol>3b3o>Rd;onVdL_o^]GWoW6]0oiA/
@Oo0Pd?olZaZokj9G_oMUe7omZiWom2LI_od]6koGBhAoaHC:om08Q7ogX/lonZPE?n]QUoo]XQUolnB
EOlF5Pgo91<7onjdL_m]ABOoBT<[okfKROnYRgSoME]:of5==?nAOUgoFd<cojF1G_oY`HOoek=kojB3
FooIZW_o`9EbocLB1_nTIcoobGTionn`MOn[RfWo7@/EodhK6OoaYFColJaSoiicH_lK3PkoD2X@on2O
G?oLUe?ohZIbofdg:OnAFSoobhiLonZ`Qole51?o?2TDon^RH_nFIDWo9aH9ol^BFooc_77oUV9:ol>=
GOoJYUSoJBlDonNfLomoBAWoci][ooo?ROo_]6Com[9/oo2bK?oa]gKoQTD@om>JIon8EbooMdThoj][
A?mW>QKoHR4Iom^JEoo`]g[odiAJon:cH?mE9R?o`hmYokj7F_mdCcOo_IYVokZBL?nCL4_ock:3oknQ
Q_oAZhkoi[f=on2hP?nmUVgoa9U_oknKM_o=/8[ob;>Aoi^7O_mlRjOoLXb`ofn8[_mbRk?oKXN`og:8
/omaRJkoJXN_of9n/omUP:[oLXFLoi6:Soo7]I3odKZ7ojbMS_n1OYWoJHFdof^7]?m`QjooKh>Rofn3
UomcPiSoJWnYofR5]?mXQJ[oKH2XofYoZOmXOjP2ofMnY`0CofQoZ?mUOjKoI82Uof5mXomQOJ7oHWjS
of1lX_mNNj7oHGjSoeajWomOOJ;oHWnToemlXomPO:CoGgbSof1mY?mNNZ;oGW^RoeUfW@01oeikXP00
0omOP9d2of21WP2Xof:1WomTPZ3oHh6OofB2X?mUPj7oIXBQofJ5XOmWQZ;oJHBQofb7Y?m]QZCoKHRR
ofn7Y_mZQZKoOHVEogUQBOoWYU;ocYY[ohUOAoncQeko]8MPohedHOl?0@3o7QPCoeaSFon3U:7oMXj]
ohfCR?n1F4codZiOoj1eAOoPYV?og9AFoj9f?_oSWf[oQdPbo``=8on7Jdco;ADBoheW<OoPU5?o^XiB
omF=@OnkPfSo4a@AoeXn5OoaYe7ol;=LooReL?oi^gOoQ5D^ojEcC_oWZ5WolK1^o`L:3olM4A3ocYUR
oj1jDOn>Id?ojk^2ok>=LOo<]XOom<nXomo3TOo1YY7oCSTQolJcOooXcIkooMnaoe<T2?oL]7OomMQa
ooK7MomE:1Co@bhJomFdLooma6Goo;UWooW2S_mjE2_ogZ^0om:>??oi]EWo[7Ljog]I@OndRFcoWfI1
onFRLOoFSESol:mXolFFD?oU[e_olZi@on2`J_n_RF;ogYUIonJ_K?mU>C3oeIQNook2K?onbi7olK>3
oo;3J?n`PfCoR68Xon^dK?n;DBgoj[6<oo:iMOoRYe7on;f2olR7CooDU6Sof9]aogPn7onKK47odHmC
ojmmB_naKegoUE@ZomZOIoo[ZfConLF5oga?;Oo<VEOobiQYob@@3OnlXH;oD2`PokZEO_o:Z8KoJU4f
oeHi7ooXai[oi<BConC5X_nVQV;o[Xa`ol^^Roo:/8[oSG5Pogb9Xom^R:coKhR_og2:/_m]QJkoK8F^
ofb5[OmZQJooJ8B`ofR4[_mVQK3oIH6bofmmZ_m_NZKoJ7n`of21]OmWQjOoJXJ[of^3[_mZP:koJX2a
ofR6[_mRP;3oHgnZofN4X_mYOjWoIh2Y0_mUPJP03OmROZGoHGfSof9nY_mPOJGoGWbTof1lY?mNO:Co
GW^SoeemYOmNOZGoG7bRoe]kX_mLO:<01?mLO:800omJNZ3oG7VPoe]hW`01oeYgWP000omPPYl0Z_mO
P9goGGjLoemoWOmOOI_oHGnMof:0WomSPIooHh6Pof>3WomVQJ7oIX>PofZ5X_mYPj7oJ8JXog22XOm/
PjGoLHV[oeaXO?o6R5KohZILomZSGOo=TfGo/hiYoh5]E?mYE4OoL61=ofaZDon2SHooMXR^ojJSS?n?
H4GoVhMHoa432OnNNcGogiQ5okZ:I_n_M43o/8=9ogE<8OoRYe[oGBHSojZDF_ld4a?o;Q`>oo2eGOml
BcOo4AXKoc`W4?oc/7SoW7I3od4T5Oo<VUSolJ9Eok:1JOlI407ojk5go`d51Olc8B3oJdHVoiEZ@_oa
[6KoOVM1ocPK3oo]aH;on]^Qon_CTOm7;2Ko<ahKom[4TOooijKol<Z4ol6BHOo@X8;oWg=9on^aLOoJ
VUKo`9Y]ofAA=?mcEBcoj[Ijonj^J_oQXegoe[5`ojZ0C_o_]G[omK]UooS0K_n_SFSo;QP@ofLn9?oi
^GComkUgohMR@OmgCBgonJi]ooNbJOoa/6_oFB@=ooNfJOod[77oeZAYohiF<?oBWV?oPd@/om^RD?nj
OdooWV4joo>cL_o=T5oo[7I1oo_>TonUJcSoe9UPojmb>?oi`h_onKIjokQ_>_olah[olJ9WooBmL?ok
_WKo`89<oiUW@oo;T5WoVEA8ooc<Pooc^VgokJ]_ojI]@?o@WV7oZWeOof94;_nUSg?objV8okjIM_oR
^hSokLV@onG3V_nCO6KoHd/jokbUROnfWWgoN5e>ofejUOm_RJgoLXZaofn8/Om/QJkoJHJ]ofV4[Om/
Q:koJH>TofV2YomXPZcoHh2SofN0[omVOk3oI7nVofB2WomXOZ[oJX6[ofUnZ?mYOZOoJgfYofJ0ZOmW
Oj_oJX6SofZ3WomVP:coI7n[0_mUPJP03OmSOjKoIH6Xof5nYOmROjOoH7bToeikXomNNZ;oG7ZRoe]k
XOmKNj;oFGZPoeYjXOmKNj800_mJNZ001OmJNj3oFWZPoeUiWomLNJ3oFgRO007oFWNN00000omMOYgo
GWnNoen0W`02oeamW005of20WomOOIgoGWbLof:0X?mPOYh00_mRP:00X_mSPJ7oIH>SofF3XomVPj?o
IH>RofN2X?mZQJ?oJXBTofZ1XOo8YG?oFD4WojNNJOnFJ43o71L<oc@X7_nTU73oUh1goga`Hom^LUoo
NHVZohI]E_lm713o[haZoah21on^V5Go^XE4ok5bGonGLC3okjUSonRF@_oa]4OoijIOom^]I_m04Q;o
M4<[ooJLFOo3UEko=1LOoieV>Oo`]Ggo?RDPob0@7omX@Qcoj:IGohML@?ld8POoaIQ>oe8[6?ndR53o
DRdVon2RH?nWNECoSWMLoi]oCOoab7WokLR4oo;DTonFM4SoaII]om2nXOnZR5GogiY9ono0SolT6ago
CB@@onbPF?og_7GoME8lob4?6_mhCC?ocXINogh^5oo^^W_o9ah=ob/@2Oo3QUSomKUUomf/J?oeah;o
YFe9omJME_o^[f;okZefohQH=?n?CCWom]2EojF3A_oJZV3ofY][onRTK?oa`8;oj;aRof@M5_o;U6Oo
DAX=olB6@?oj]GGon;5KooVkM_ol`I[oo]6<ooc=O?nFH3GoGRH<oo6cO?ml?AOobXeToo>fMOo//fOo
n;YmoobmQ?ndQ4koj[Elon>[F?ol_GgoTT8Pook6Noo0TV?oPeDoonf`J?oOY5ooW7U]ojnQJ?o3XX7o
_9f0olNSOOoN]7oonLfConNkP?o;YWKoUWIFol2WU?mUCCgoN5e9ohV2POmfQ;CoJ8ZcofZ8[?m^Q;;o
JhJZofV4[?mWPJ_oJhN^of>0Z_mUPZkoJ86^ofN2[omVP:coIGjZofIo[?mVP:ooIGj[ofIoZ?mVOJKo
IgfWofIoYomXP:SoIGfTofR1Y_mVP:SoHgfUofEnYP?oI7fU00KoHGjUoemkXomLNJ3oGW^RoeejXOmL
NJ02oe]kX@?oFWZP00OoEgNLoeUiWOmKNiooF7RLoeUiWOmHN9coDg>G007oEgNK00000omKO9coG7fL
oeenW@02oeamW008oeinW_mNO9goGWbMof:0XOmQOiooHX2Qof1nWomRP:03of>1XP2Jof:1X?mTPZ7o
IX>RofV3XomYPJ;oT8><ochM7Om<;Q[o]H1JoaL65_nhVG_oaJYooeI1>ol=1@3o>3PRohF7U?n[OU_o
T5XVonJ^F?nfPfCoF3TWob071ooY/f?of:EXonnVG_oBTeGo[7EUoe`a7_oEXU_ol:]/onRlL?oNWVOo
ikM:omNVM_nRK3gon<Y_of=88Ol_6Aoo/h9GonnM@?odZgGo]XQMolJDJ_o<RE3ojIeGohaP9_o]]7_o
6P/?oaT=5?mnH47okkigoo[6OOonfH;ol]:CoiQ_@olU7A[o@b@Aon^eK_oMXE[oMELgol:DJ_oRVTco
jj9:om^LH?o7WWKofJEAonjaE_oDUESokJAKok:8FOngQEkol[1fom>JDolm71KoNE8SooO9POo1UV;o
IChconZMG?o/dg[om;m^ooNkO_ln7A3oN3`IooFgI_o0Te?o@A/AonbgJooPU6?ocXe5on>JI_o`ZFKo
Yf]9omFYO_ond9KoLChDomV]MooU_H3oomfZomBTKooQYeKolKjAolN?G_o7Q4oocj9Voha?<?od`7;o
FBl7ohiH?oo[^8Gob8i]on^aHOog`7go^Y1Ooe8S6OoY]WgoLD/XoiIPCOoJZ63objB7obLC2?nbUXKo
E30JomJ`RooYa9Goh[VColRVRoo6[i[oN699oij4G_nNTHGoN8>cofJ9/omYR:coJX:aofV3Z_mWPJ[o
IH6[of1mZ?mQP:coH7j[of9nZomROZcoHWj[of5mZ_mROZ_oHGj[ofB0[OmVPJcoHgbUofInYomTOjSo
HgjWof9mYP;oHgjW00WoHGbUof9mY_mPO:CoHGbUof1kY?mOO:CoGW^Soe]hX?mLNZ800_mLNJ400omJ
NZ7oFWZRoeUiX002oeUiX007oeYjWomINIkoFGVMoeQhW?mHN9goFGVMoeMgW001oeUiWP0000GoF7ZK
oeUkW?mJO9goFG^LoeYlW@02oe]lW@;oG7fN00CoFgbMoeamW_mLOIkoGGjO0omOP:40S_mPPJ3oHhBS
of>0X?mUPZ;oJ8:SofV0U_nPO6KoYG4^oo[5MoniVGGol[miojV2EolW5a3o@d4hofMNBon;OV[ob9QQ
omR?C_og^UkoiJQWobl=2_lN3`;oaJ1Wob@42?o:TU7okKI^ob8=4_l920SoXgPlooRYG_m]CC7o60dU
ojUf@?oLTGGoBa<<onR]L_oi/VWo`h=Rom2DGOoh^6koLD`goa040oo:SUooiZ5Rol^BHOo5VDgol:el
odTe;_lX4QKoJD<SooFoNOoobX;ok;IgooG:V_nCIc_oED/kol2ML?ojbhKomK5ToiIdE_lW4@?oe95?
oo:eKon2Hcoo?a`7omFEEool/GGoa81PomZFG_o;QSSoZ6DMon:RI?o[/6koGC`PogQ7;?olcHWo]HQ/
oclV4_niLd7on=ZIook7L?oMY6KoXgmQok9/DOo][DkohZYQog0d:?oIVE_o]GQ1omVLG?oANB[ooKYc
ohYJ?Om;;QcomLZBoj1b=?ngReooQU`eooWDU?o``hKooLUjok1d@Oond9?oTe0MomV/N?mb?akoeZ=Y
olB<J?nXK4Goi;2:oe<K3_ohaFGo^7aFooc<Q?o1QEgok:m_oiQXA?oMY7[og:9YomF[Q?mXECgoX8=f
ogmHC?naRF_oj<>BonG1UooE^IWo]9n5oiR3Ion[T6koPgARogEoZOmQPjkoHhBZofN1/_mUPJSoI82X
of5nZOmSPZkoGGf[oein[OmMO:/2oealZ`09oe]jZOmLNj[oFg^YoeimZ_mOO:SoHgjYof9mY_mROZSo
Gg^V00?oH7bW00CoGg^VoemkYomONjKoGg^W0_mMNJ@02?mKNZ?oF7NQoeQgXOmIN:;oFWVSoeIeWomG
MIooEgJP0_mHMj401omGMigoFGVOoeYjX?mFMYcoEgNMoeEgW?mFN9d00OmEMi`00003oeIjW?mHO9ko
EWZL00;oF7bN00?oFGbNoeQiW?mKO:001?mKO9l0WomLOJ3oGGjQoeenXOmMOZ7oGX2Qoen0XOmQPZ?o
Hh2RofF2Y?mOQ9koWXZ@ojn:@Oo`]gWo[iENomBRG?o1V7SoOVmQohj9NOmWETWoJEX`oiMkAOod]h[o
Ne4fonR_HomkF37oTF4^og]ID_l;4@coY7m1oo:VL_lM40oo2`h9oi1Y@_o^ZV;o<a`Ao`TJ4?nCJRoo
lZMNomZ[F_of`6Gom;=Qoii/C_mA9`Goi;ImoaH10?l@1@3oe9LkohYP@ol72@;oHChLooVUI_o6QT_o
c9MUonJcK_od`WGog;N2onJhM?oJZFgomKQloh=SBon>F3?omK9bomnHH?lP3a?o70lCokeg@Oo9RE_o
;0l:od@R3?oZ]H;oQelaocX[6_m57`?oi:5Gol27COn6Ebkon;j2ooBgNOoi]gSogim2oog2Q?o9UV7o
gKabonjgUOood9koHd8XofXh8Oo?PESoe8lkonRCG?oIPSWoiZ1Goe/^5on1CcKoo[I/onZUIOo/^goo
XfdiooFnNOoh_goomKj<oj5[=oo``GOoUV=6onnfROn>EBGoo]>AonnaL_oe^XGo]H@dojm^G?nJCB[o
kZUGoo>dIonMF3CojjeXof0L2oob^6?oo/1gooN]D_o`Xf?od:]/oeY0:OoQ^hKo_jAmol^VQ?o4UG;o
d:1bonFgOOoSa97od[ZBoin<LOmNAcSoHD0gojFFPOm_N9coI8F`of>3[?mTP[;oIH>Zof>0ZomPOZ_o
G7bZoean[?mIO:[oFGb]oeQj[?mEN:WoEgV[oeUk[?mHNjWoF7^Xoe]lZOmMOJSoGWbWoemlZ?mMNjOo
GW^WoeekYP04oeikY`;oG7ZU01;oFGVToeUiXomJNZGoFGZToeUhXomHN:;oEgJQoeMeX?mHMZ7oFGNR
oeQfXOmFMYooF7RPoeIeW_mHMj3oF7NOoeEgWomDMih1oe=fW@0000?oE7ZNoe=iWOmDNYh00_mDNYh0
0omGNj3oFWbQoe]mXP03oeQjW`03oeUkX?mJO:7oG7jS00;oGGnT09coG82RoeeoX_mOPJCoHGjSof9o
Y?mPNjCoIg:Oob8O5OnoSFgo>BT`oea24_nQPW7o?R/Foib?M?mXE4coGTT]og9L?_oR^gko4P<7onZ]
GOoO[F?ol:aHolVAM_lI3Q;o/haZonjhGOnAI4;oO4dTolf@K_o`^FWoO5HWod/V5?oJWFKoo[e]olNM
KOll80[o^GhfoofkR?oCWF_oijaZogU<=Om]Fd7oeYQ?ogY7;ol22PgoHC/VonJJB_nhKBWolKM^ooo;
LOoU^gGo?b@Goc@S;?mX@BoomZiaoj1h@_o@WeSoehi9omb@FOnDI4ko^GQ<onZKD_oGW5GodIU=omfQ
D_oWWEcoH3@LobPT:On>H3CooJiXofY1:ol^71coUVDkooo4OooIXUco[7Y7onjiM_on`GgoGCh?oelh
8?ob/FWoRea0ogHe8OoUQeCo`hHloeTY7_of`W[ojZQHol>9G?nQHTCom;Q^og=;9?oH[W?olj]ZooBi
K_oSYGcomK^5ooG2NOondI?o/hIJolN=G?o_^8Oo^ha4oo:eQ_nHDcCollMcoo>oQooUW6KogIeMooVg
IOobZG7odIAVojUd@ooW]gkoe9U]ooJgK?n?ES7of;I^ocPE3_nlWg?oG4<`olFVQOo>Z7ko_iA]ol^L
O_nSPfco]Yj9ojBBO_nANfOoO5a9oj6@L_mgOYooI8B`of:3[OmQOk7oHH6Zof60[?mPP:koGGn]oe]n
[_mHO:coE7V]oeAh[?mENjooE7V]oe5fZ_mCNZWoE7ZXoeMjYomINjOoFW^Voe]jY_mKNjOoG7^WoeUh
Y?mNOJT3oeYiY@;oFGRT00KoFGZUoeMhXomGN:?oEgRSoeIhX_mFMZ83oeMfXP09oeQgXomGMZ;oEGBN
oeMfX?mDLigoEWFOoe=cWOmCMiooDGJN007oD7FM00002OmCNIgoDGNLoe9hWOmENiooE7ZOoeEjWomG
NYooE7NLoeEhW@02oeQkX02RoeQjWOmHNigoFgfQoeUlWOmKOJ7oFgjRoeenXomNOjCoGgnTof1oYOmY
OIcoH7bYof]aMooFYW3o@alOogQI9_n6ESKo]Iimoif0L_lQ5Pgo_jZ6ohea?_oCZ6oo>1XCokJ;Eoni
UFCo]Flhonn[DOniN3OoMdXiojR6CooZ[eSom[IcokI/G_n:CB3ojZM/oo6YO?ncLC3omK9Soe@c7?lC
423oHT8Fojn8G_lK1P7oa8E8oo6C@?o;UUSoDQH7olf5H?mhDc[oaXUDoo:bKOnXLdOo^i9MonNbJOoH
W6?oM4U2oa`I7_mmBbGo[HAUoeHk:OncNdSodI1Loj=]=ooQVECoiHY4ojaa@?m9<R3oK4@YonBCC?oZ
SS_ol:=MokR0A?noP4Coo:AYokj6F_mE<QCo]7QHoo[8Moo;Yh3o=Al]ohmG=?oi/F[oeI9^ohmG:ooY
ZUColJi/om2;D_olXeWogjeXoe<[8?o;WFSon<B5ombQCook_X_oo/FDoh=HA?mnCb3oolZ6ook>Q_n@
FC[oHRl;oo?8OOoncIconm><ol^FI?o@VV[oikUZokUkDOmk>Rcoo=::olRJC_oi`X7oGC<RoimW?Oof
_7?oIbl;onZiL?n2ES?oI38/onJfN?m68`oogJm^ol6;IOo@/Xgo:QD=olJVS?n[SGCoPfMHojb5M_mR
B3OoKEA4oknWU?nPQ6SoZHYTojBCN?m`NHkoI86^ofF0/?mRO[7oHGn/oemoZ_mOOjkoFWbZoeMkZomE
NJ[oEGR]oeEi[_mEN:goE7R]oeAh[?mDO:_oDWVWoeAhYomGNJSoF7ZXoeQiZOmINjWoFg^Zoe]jZ?mK
NZOoF7VV1?mINJH00omINJOoFGZWoeIgX`02oeAeXP0=oeEeX_mFMJ7oEGFQoeEeXOmGMZ;oDg>OoeAf
W_mDMYooDgFOoeIeX?mCLj3oDGFPodicW@01odebW@000omAMi`0VomBN9goE7ZOoeEjWomEN9goEWVN
oe]nXomFNIkoFGbQoeYlWOmINicoF7ZKoeUkW?mMOj3oFg^QoeinY?mLO:;oGGfSoeinY?mOP9CoF8>_
og=nTooEYh7oe9]XonJkLOomb8kojMNQogMG@_lS8a3o[i5[onZgHOoZZfkoaI5?odT[4ol]6PoohZmZ
on6ZKOoe]G?obI=LolnJH?mW@S3oFSP<onFgL?o7UToookmcooVcL?oZYFOomjiSoeTn8?l94QooQ5a3
oiAS@olg71Go`9F0ohEC=?nPOF7oaW`oomJBH_nJK3ooj9a;om^?C?lP3Qco81`Qof=69OoEVUcoahmH
oj]gEooJSeGo=QT9od8N4OoTYgKo9Pl@oaD>2?ncM3Cod8EGod0^;ol<3aco>AL8onZHF_oZWUko_8AE
on2XNOo/XfKohHa:onV[IOoW]6oomJi]onneK?oIXW;oIT0XolF2AOoh`gKo_YaiolNAF?o^YUOogJ1M
od//3?oBPV;odiaDonfaK?nDEb?oSf1=oh1=9?nkS5SoklIJoo[EQ_oFZ7Gok;Qeoo:mNOoc`Y;oUF@o
on:gJ?oHYW?oejmgoo[EY?o:U5kom;Ycoo6/M?oDUeSokKj7ofH_8_okdhooLD`^oh]?;?omaWkogJEh
oo2hH_oT[7Ko]WYBooNiJ?n`OU7on<>>olnPJ?n]TW3o[Y5eom^`RonYR6ko?B@Fol2HPOnmXH?oT75J
ojV6LonfUH3o[91boj2AOomoR9OoJX>`ofIn/?mTOZgoH7n]oeemZomLOZ_oFGbZoeIkZomENZcoEGR]
00CoE7N/00?oD7RWoe=iYomCN:P00_mFMjP01OmENJ_oEgVZoeUiZ_mIN:KoF7JU00?oF7RV01CoFGVX
oeMgYOmEMJ?oEWJToeEeY?mFMZCoE7BRoe9bX?mFMJ7oF7NSoeMfX_mCLYkoEWJQoe9gWOm@MIgoDWBO
oe9dX?m@LZ3oCW:Ooe1dX07oBVnK0003oe5gW0;oDWRM00CoDgRMoeAgW?mEN9goEGRM0_mFNIh2oeQj
W@2AoeUkW_mKOJ3oEgVLoe]kXOmJNZ3oGGfSoe]kXOmLO:;oGh6Loe:7Y?mOPZ;oU8B<olbTKooH]6go
WVX`okfaLoo8Zh;oTXiaohUZH_nROd_oPEPXonC8JOll:B_o9A`KonjkJOnLLeKo:aT;ooRnIOol]VKo
9@hToah50?nmUV3oN4XYon^bLOla81Wo?b`Koo>dLoo@UUWoVF0^omFEFoo=WVCoh9a:ohUP:Ol8413o
=R<Dol^=EOm9;Qco1`/9okN;E_oLVecoME<lobXV8OmcFd?okjI]olMY:?oQR4GobIM[oj9nJ?oFRf?o
]gM;oal51olm:BGof8=1onj:@On0DCCoCcDYoj=_D?oPTecoUF10obD@4?l^51;omjQXoo>`Eon^RU_o
PF0noo2kJ_ol`Gooo<66onRhR_oi^6Kokl=]obd`;om18PComKMeomfYMOlU7QOoQ5HgogeH;onEEcco
m:a`okmgBooUWFGoXVi>oiAX<?oaaH?oomZVofm26ooY]G?oom2<oogDW?okdG_ok;^0ofdm6ooU^Fko
nlb5oiaM:ooJUf?oYE`foo[?ROn?HT?oTUlVomjVO?oQWF3ohZaloedb3ooa`FcocheIoo^lLOooaGKo
m;n8on^kT?o[b9OoCS0EomF/NOoIZGSobZ1hojR2H?oAYX7o_iM`ol>GM_nUNUoo_If5ojZEO_lU5`oo
QX^LofAmZOmRNj_oH7fWoeenZ_mLOJcoFGb[oeQl[?mDNjgoDgZ]oe5fZP04oe9gZ`09odigZ?m?MjSo
DWRZoeAhZOmCMZSoDWJXoeAgZ?mFMjSoEgRV00CoEgNU00CoEWJToeEeXomEMJ?oEgNU0omDM:803OmE
MJ;oEWJQoeEfXOmDM:3oDgBOoeAeWomBMIcoCgBLodmcWOm>M:3oCG:Ooe1bX?m?LIh00Om:Ki`000;o
CgFJ00WoDGNLoe1fVom@MY_oDWNLoeEhWOmDMicoEWVNoeMjWomHNj000_mHNYl3oeUkX003oe]kXOmL
O:;oGGfS00;oGGfS08KoIgN[oef2VomJQi[oIG^LogmoS?m4:QKo`i5Yoc0O0_nKNDkocKnHocLI4om^
FCOoDbd2omjcKOnlS7GoTf/`onjVE?nCI3Co818Vom:RIood^gSo_iYaofHd6ooAT73oIbhZomZYK_la
9B;o;ad?onBOGOnVHQoohimSohmB:OmA9@kohI=EojmiDOl601?o>Q`JolZ;GOl^4`oo1@/FoiEYA?oG
Se[of9AIocDT4OmIACSo`85LomV3D_o?SUco3A4?ocPK2ooALcoo^VdgojIZ?omgFDOo]gHoooVQBooY
Vdoo/gDmohI73oocYF7oTVI0obXN6?m3;RWoj:]^ooG4K?mC>b_o<ATYoi]_@ooj`G_oL4/Soch_8oo:
ReGookU/og13;omX=AOo[713ooNmTOmY<aSohIYIomN[MOnZJU3okJ]SoiML<_oTW5;oo<><ohE;>oo<
SF?oo/R8ol:HHooIXeooo]F8om2RKoojcH3ol;iloo2[O_olagCon<9iojmgEomc@AgoUD/gonJgJ_o?
X7_oeIm]oo:fPooPYe[obImcod4Q3_o/`h_oLS<Pom6NL?nOOE;okL^Koe/g7?oVaY;oc:9mono1QOo_
a9;ogJj3olBDIOo<X7?o`Ya^om:YNOoDZWco_YefokNVR?lY60_oTiNVofAlYomRO:_oH7nYoeYmZ_mI
NjWoEG^Zoe=hZP;oDGV/00GoCWJYodmgZ_m@N:_oD7R[oe5i[002odefZ@0:odifZOm@MJWoDGBYoe9g
ZOmBMjSoDgNWoeEgY?mFMZCoEgNUoeIfY0CoEGFS00SoE7BQoeAdX_mDM:;oDg>Qoe9bX?mBM9ooDgFO
oe=eX@;oDWBO00OoD7>JodibV_m@MZ3oBW>NodUcW_m;L9ooBg6P007oBW>Q00000om?MI[oCWBIoe5g
W002oe1fV`03oe5fVomCMY_oEGRM00;oEWVN00SoEGRMoeIgW_mHNJ3oEWNNoeQiX?mINZ7oFWZPoe]k
X@;oG7bR08OoGWjTof1nY_mQOZ?oGX6Poej2Y?mUO:SoNfQXomn[Q?mMAB_oi[^9on7=Q?md@C7o]h]5
onb`MooCT4koolB7ooZjKoon`Foohja^og]4<ooF[F7o`8ISoeDa3OoHYU_odHLXooVeIooNVUGoIThm
oe8e7?oaZ63om;5^omFDGOoSVeSoc9EKolBFI?o8TekoZGmAogQL?Oo3PE3o[WIHoh=QCOnhMCoo_WA2
okn4J?lI41Wo3PL8ohUP??o2RE;oSV15o`0?8?lY2P3odGi;omJ4@_nILTWo4Q8IocdM2?oNYfOofJM_
om^VN_o=Re;om:5Fon6UK?n3ES7oaIAaomfVM?oa]6OoTVQ1oe/f9Oo:U6?om[I]oiY[>om09a?oiimX
onjLEOoKUfSoh:5^olB4BOoBRTcom:5Tonj<EOnmPSood9ADon>aK_m17Aco`XIHooJfJ_oL[VOomkia
oiiU8onbSekoo/]nonjoMomE8@WodJ=_oooAS_o4SUKo`HQDomZOI_n_LCoo_7i;omNGIoo/^7coE1@A
onFWM?ojcXcoom:7ooO<Q?n=GTKon<65okAiC?oBYgkoMe8coo?=UOmC;a[ommjOoo;4U_occiSoajZ7
olRLN?oCW6[o`iQYohifFonZRFKodJQmok>@JonPRFooQgAMof=VKOmUOZGoGg^ZoeUiZ?mGO:coEWZZ
oeAiZom@N:/00_m?N:`2odefZ@03odaeZ?m=MZWoCWNZ00;oBWFX00_oBgFYodeeZOm?M:WoCgNWoe5j
Z?m>M:?oDWNToeAfXomEMJ?oE7BRoe=cX@03oeAdXP03oe9bX?mCLj7oDg>Q00;oDg>Q00coDGJPoe1d
W_m?LigoCgBNoe1dW_mBLi_oCgBLodadW?m;MZ3o@g:Kod=_WOm2KId1oci/W00000?oC7BHod]cUom>
M9T00_m@MY/0U_mBMicoE7NLoe9eV_mFNIkoEGRMoeAgW?mGN9ooEGJMoeAeW?mFMikoFGZQoeQjWomJ
NZ3oG7fSoeioYOmJNj7oDhVGoe^0Z_mQO:koI8>Qof=oV_n4NWcoPUhmoe<e6?oogYcoe;YSojb2M_oI
^WGoSVDhokZHJ_nQR67o@blOomRZHon2Dc7ooKAaon6]<oo?S73o810Uofi04oodXFCojjUOomn<B_o[
Ue;okj=UoondH_mdC2_o4a4>oi]O=?oCRECo80H7odTJ3?oCT5Wo;Ah:ohEYCOn1GdSo:AlCohEQ??n_
Q5gociEDoh]eFomgBSKo`7YBolAbC?n>GT?o9R0IohYE=_ngJD3of8Q8oh=S?OlQ5agoOT0SomZDE_m@
:@[o?a`;oja^@?ojZF7ojZ9OojaS9_o4Nd?oRT/LoonaJ?oXZ5gomlV0ook7NOo/Ye[omJeTom>JJOof
/F3oeImHoedj5OncPd[oolMboln8B?o;S5Oon<AlogEEA_m64Qkof9aKok5/@?oGQTSoa8ULochB2_oF
Vf[ol[Z:oeT]9?oe`W;okKeholN?O_nVKDOon/J2olBLG_nIJ4[oPDDQonfWGOogYf?oJbP^ooS8N?o@
T5_olJ]jokJ8E?nnSUKol[m]ojm^@Ooj]VCon;]NonVbMOo?Segon/5fol2DKooWc93odJn5om>gROlj
:QGoKdX_om2DJ?n[P5Ko7Pd<ofeBA?o4WGoocZV<okFHQon]VH3oKg5cofR1XomKNZWoG82aoe9jZomC
NZcoDGV[odigZP;oCGR[00OoCGJYodaeZ?m:LjKoBgBWodafZ?m9MjWoBgJY00?oBgBX00coCGFVodef
Y?mBNJOoDGFSoe9fX_mBM:7oDG>Poe5aWomCM:7oDW>Qoe=cXOmALJ02oe9bX00>oe=cXOmDM:;oCg>M
oe5fX?m>M9koCW>ModicW_m?LI[oCG:LodQbW?m4LIco@G:Koc]]VollKi`1oceaW@000_m:MI/01_m;
MI_oCWFLodicVomCMikoDgJLoeEhWP?oE7NM0_mEMYd01?mHNJ3oEgROoeMhWomHO9h2oeUmW`2@oe]o
XOmJOZ3oG7jOoe]mW_mNP:7oGGnPoej0XOmUO:SoOh^Toea79oog`WcohKf=oa450?o3Vgcoh[Aaof4f
4_oP/hgo;1TBoiM`D_lX4`oobZ=PoonmJ?of_W7o[7mNoln??OoZVUgo5ad6obhP2?oGXgKoB1d0oo:_
L?m8:2;o0`XAog569_niPDOo5@H<obXG5oo<U5Oo]HeWolRCJ_m;:AGo0a0Qoah80?ngPECoEC`HoadH
2OnWJTooSf=2oclU6_m58Qoo/g]?omF5A_nWE1gojZaUooNkLOnkO4coj9IPol:AIOl]927o:Q`Mok^4
D?n^N47oYX5Book5N?ooa8Ooe9QWooo9S_oochSoJTXGoe0b7_og_h?ohk9codXN9Om]BQ_oZgE@ocHU
:?mF=agoo[iYogM=AOlk81colki^onbhQ_mT:P_ohImOom6@DOoPWF_olK1foiIQ=onnP4gomkEPonNU
E_oh[FGoo<I[onZcHoo4ReSoMd@PooZgLoo^/f_oQdHaooFhL?ok^gKoHb0PombaJ?oga8Goi:=MomFH
H?mP<B;oKClYoo_CV_om`H3ol;=]oo6bIood^WOoo=J7ooS8T?oO^IOo9AL7omBdSolZ8ACoKDX`on^/
Noo6VFgoS7=Toj>4Joo3X7ko[i1aoiYoKOnST7[oVYZGoeYeU?mCOJcoDgbZoe=kZOm?NJWoC7Z[od]i
Zom:NJcoAgJZodIdZOm5LjSoB7BYodMdZOm7MJSoB7JW1?m7MJH01Om:LjKoBgBTodigY?m?MZCoDWJT
00?oDGJR0_m?M:001?m?Lj3oDG>Qoe9dX_m?LIl2oe1bX00<odmaV_m>L9coCG:Nod]aW_m:LYkoC7:O
odQaWOm6Lj3o@G6Noca_W_lnLIko?72M0OljKi`000;oBWFK0_m;MI/01?m<Li[oDGJMoe1fW?mAMi`3
oe9hW@;oEGJM00[oEgROoeIgW_mEMYgoEgZOoeQkX?mIO:7oF7^PoeaoY?mKOJ3oGGnR0_mLOZ40Q_mM
Oj;oG7ZOoeihU_n5QX_oIDHYomR]MooDZW_o^X18omFOG_oIYV?om:EKojQY=?o`]G;o^8I4om6EA_m5
:AOo/8m?ojaK8_mZBBKoiImaoahM5_lV9BCoeiIRokUg=OoNRD_o[g<koclT7_nOIS;oiYEMohAP>_mn
HT7oRUa1ofeE=ooCUESoWG5=od4l?OmoFd7o]81GobDI6OlK40oo]HQEod@U6?lC4Q[o;a01omBHGoo:
N2[oeYINodT`2on4Gbooo[=UooF/GOoMXUgoQe8XojE^DooUY5WoN5E;obLG9_oIZ6KoNC/EocXO3?o5
T5WonlR4ofQ48_ll5Acoc8aGooK7OomgAS_oQe<[ooFhQ?mg@b?oXVA6oo6dG_nQPe7oBbL:onn_J?o`
[5[oiYU:ooFXKOnAH4KoHbhGoo^dIOo;QC_oj:9LokF3;ommE2gohImSok=mEOoHXfGoml5iolBBIoo>
Vf?oc8mJomNEC?nICbkoo<:1onNGEOo__73oX7Y;ogQ29?ond8[okk^9oi1DAoo=VE_omlJ?oeLO3?o]
_W?o_H]QomVdNOmU>2OoaZEoodXc6?o[a:7oQfQ9ojimC?o/]WGogKf9omfeP_ncTV_o>207oe]0=On:
IfOoWHEcoiJCTomUOIcoDgZ[oeEkZomBNZ[oC7NXodQfYom7MZOoAgN[odEfZOm8MZ_oAWBY0_m4LZL0
1?m5LZOoA7:TodEcYOm5M:D2odEcY@06odMaXom8LJCoBg>TodmeXom>M:7oCW>P1?m>M:000om>Lj;o
CG6Qoda`X002oda`X00=odeaX?m@MIooC7>LodacWom8LIgoAg6OodIaWOm5LYko@72Moc]^W_liKigo
>6jLocI]V`01ocA]VP0001GoAWJJodQeV_m9M9[oBGBJodafW?m<MIcoD7NNoe5hWom<Li[oCWFLoe5h
WomAMicoDgVNoe5gW?mCNIkoDWRMoeEhW_mFNIooEgZPoeUlX_mLOjD00omLOZ<0QomMOjCoFgfRoeb0
X?mMOjCoHWRNohj>U?mS?A?o_XY1ol^<F_niSE_oNeY6okf7B_oU_7Con[ARon2ON_o_[V_o<2HQod`V
4?oDUFOo9AXJon:LJ_nWKT[oUe/aoo2QF_oYWeSodHIJonFLB_nhO5ooY7M=okAU<ooMU47ogIi?of0i
<?l230oo/i1UofiE??la:BGoX71>okJ2F?mdABoo]GI@onjXDOo2OUCoK4XbogaUA_o@VEookZ5GolnF
K_l_7Bgo:1h]ol60BOoY]Vkok[edoofgHoob[6[ooL]^ojU`B_n<Dd3ok;e[oiAP@?m181KoeYeGoo:g
Gooa_7cobiIWoo6eI?oT`F_om<VCoo[1MOonag3oj[IbonNMIoob^VComLElom>0COo]XESoaHaXofi3
:_oT^7?ok[Mkoi5D=Oo//W7om;5Woof_L?o]ZWWoBaTHom2VKOm25Q7oQTd[oofkJ_oKUd[okJ]IojED
=_oi]6?obHeNoeT^4OoUZDooj:aNom:=I_mg<AWo[X@monVhMOo_]gOo/h53okV7I_mO;27oaYQ[oiEQ
A?nTMd[oICLeol>SLOo]b9oom<V6om^]K?oodI7odJ9_oh]_D_o8UVWo_IQfoij4L?nVRgWo]IAjok>J
QOnKV9[oGGFGoe1gZ_mAMZWoCgJXodUhZOm7MZ[oAGNZodAfZom2MJco@7BXod1cZ003od5dZ@;o@g:V
0om2LJD01_m6M:KoBGBWod]dYom=MJKoCWNUod]cXP;oBgBR00GoC7FSod]cX_m<M:CoB72PodE]WP02
odUaXP0=odUaXOm:M9koB72LodMaWom2KYco@W2Ood9aW_m2LIoo?FnOocQ^W_ldKYco<VfKoc=`W@01
obe/V@000_m5MIT01_m7M9WoBGBJodafW?m:M9_oBg>KodmgW`;oCWJO00_oCGFLoe1gW?mBN9goDGNL
oe=iW_mBN9goEGRPoeIiXOmHNj?oFGbToeQkX`03oeYkXP;oFgbS08?oF7nVoeQiX?mOOZWoJhBUoifF
RooN^Y;oKc@Oom2ZI?mdGCGo[HIJoe8l9?o8XFgo<1<PofPi3?oMWFWodWU0onbdGOnfOcooc8TYooB_
H_o2QSGohk=cof50;?lH4acoXh1CohMB;om08`goeIUQomfLE_oWX5go[gUBoaHB4?nbT73o:aP:oa@9
1_n1ECOoQfA8olf=E_oXUDkogYUHonjKDooHUeco<ad]oel`8_on^g[ogZEHoeXf5?n9F3oomZUTon>/
JOla80OoCSDAon>_MOoP_7codYEFoonfJooPZ53of9eWokYjEOol_G7oo/b1oo2jM?od^F;o`8UDodhb
:?mjE3KonkikoimS>Om]CR;onl>6om2UI?n7CBKolYMOoo^kIomfAcCoAB@[oiY_;_oc[eKokZYcoe<Q
2Oo?VUWon;QGom>DA_ob_fookZ5Loo:lN?oDX5Ookkb7oe@V5?o_Y5KohiUPojeZB_oK[ecoJ3/SolJ6
Goom`7?onk9]onn[H?n=HSGoJS@Loo:iPoole:;o_HQGoo6mMOoZ]FGoeiQVolb>F_o4UgGokLZ;onjn
POoIZUcokKedoo[EVoo0W7OoMe@molZPNooF[XgodZj?omZiT_oB/X?o`:bBoibNXOmKN9WoCGV]odih
Zom<MjWoB7RZodEgZ_m4MJ_o@WF/od1dZ`02od1e[0?o?g>Z0_m1LZP02?m0LJSo@76Wod1aYom3LJKo
A7:TodIaY?m:LjKoBW>T0om:Lj401Om8LIooBG:PodQbXOm8LZ;oAW2Q00?oAW2P00coB7:NodEaWOm4
LYko@g>Qocm`WoloL9ko?W6OocQ_W_ldKigo<FfMoc1`W_lZK9X1obY^V`0000Co@gFIod=eV?m4M9So
B7FJ0_m;MY`01_m<MYkoBgFModUcVom;MIgoCGNNodmfV`;oD7RL00?oDWZNoe5iW_mEN:000_mFNJ40
0omEN:3oEgZRoeQiX002oeQiX025oeUjXOmJNj;oEWj[oe]kX_mJNj3oDGZPof9eQOnMTX?oZ7eBoj5/
?onnRF7od8]AojAc@?oj]VcoEclXocdT3?ohZ7Coj[1Vod`o8oo;OTgoo;mlomn?G?oZXFConkm]of8h
;OlL82coPE0ZooBODonaMUGo^XU3oc0K2onLMf3ofI11ok]mE?o=RecoOeLooddi;onOOfSo8AXBokNB
Fon/MCCoP69KolB=B_oGXFKo;bDIoe/j7Oo[/FGoo;UNom>@HOo6SeWojkAWooRiM_mI?T;oCbhWom6>
FOlf8aCoLE0VooNbH_oSYfCooZmRoki^:Oo_ZFGoSV12ofi09Ooj`7[o/HA=od</A_mD<QComkiYoj9[
C_m0:2Go]We<oij3Gom98RCogZQfonnnH_oZ/W?o^GI=olAcA?ol^G?on;Y[oj5QB_n3CRWociYOog0e
=OnnTEcoolIjonZkIOomcIGoR44Oom:AHooQXVOoYVa4okn=EOnIGC?ojZMbonJ?COoGVE;oJ3DUooG4
O_okbhooXVTTooS2Qoo;VEComl22oo:^Lool_6ColZUPooZfNOocaX3omm::ooO1OooZ]Wooo]VPohIZ
>_n_Ug7oejj3om_0S_n_RU[o`iEWomNZP?o=ZhGo^:R@ogQoP?mINikoCGf_odaj[?m;N:[oB7R/odEf
Zom2MJco@7B/ocmc[002ocieZ`03ocadZ_llLjWo?G:Y00;o@7>X00Wo@7:XocmbYoloLZOoAGBZodAa
Y_m4LJCoAW2SodE^XOm7LZ800_m8LZ800om7LJ7oAFnOodE`X@02od9`X@;o@FnP00go@FnOodAaW?m3
LIko@g>Qoc]]WOliJi_o>fjNoc]`W_leKYco<VjNobm]WOlZK9[o:6fJ007o9FbH00001_m1LY_o@W>K
odAdV_m8MIcoB7>IodYeVP;oBgFM0_m:M9`00om<MYkoCGBModmfW`03odmfW`;oE7FM00KoEGNNoeIh
WomEMikoEgVPoeQjXOmINj82oeQjX@2?oeQmXomHOZ;oF7jRoeIlX?mGOJ7oFWfRoeYZQ?nAPGKoKD0D
ooC0P?o>UDkolK5^omZKFooc/g;oe8mDonnWI_m39R3o<1l;ooR^LOla8Qko:b8JomF@>ooZ[77oOdHW
ol9oDOoXWdkoiZ9Eok^1A_lF6RWo61X:on:RCooCU6koOedjom:MHOnjKSCocJI`oed_7?mU@1ooj[An
obhC6?nOKbkok[1ZoiYgG_m381SoYW51ooJlK?mF<Qko>B<Vojj6A_oj^eWooKakolF7BooY/GooGCLT
ojM_BOnBH4;o=b@Hol2;E_oj/F;oi:5Toc/O7Olc6QGokJm^ooo6QonbNdWofi9Ooo>SH_ol`GCoeH=5
oo^gLOon_WooeXiKoo>eLooBYFCoaX]KoofjH_oaXVco`XM0okV6Doon`GgookIVolnAEomc?b_oV5/g
on6IGonBCbCo^7Q:okmmA?oCSE3ofIaQoe`V4?o_[Gco/V@Nooc8Q_o_[6Oo^WDgobd;3onXP5Cok:]k
ooo:NoneO4WoC2<:okb8H_ol_7WonkeZojI`<ooKYXOoj[IjombfN?mE?bSoWGiMooW9VOmhFC_o<bHH
okfHMoo0WW;oITLZojV1IOo;W7KoaZIooiR6HOn1Oh_oGGNYoe5k[OmBN:_oCWF/odMeZOm5M:[oA7B/
od1b[?m0M:go?g>/ocmcZolnLZ_o?G6Yoca`ZOm1LZco@76ZocmaZ?m0LJKo@7:Uod=aXom4LZ@00om3
LJ<02?m4LjCo@g6SodAbY?m4LJCo@W2RodAbXom3L:;o@g6R0om2L:42od=aX`0:od5`X_ljK9go>VfN
ocQ^W?leKI_o=6nOoc5_X?l]KIoo:VbIobM^V@7o8VbI00001_loLY_o@7BKod=dV_m7MigoB7FJodUf
V`?oBGBL00GoCWVQod]fW_m<MYkoC7JNodegW`02odihX0CoDWNO00?oEGZRoe=hX?mDNJ400omENZ80
POmCNZ3oDg^OoeEmXOmDO:3oEGfQoe9nZ?m@NZCoI7V=ojROUonfTVooMcl@onnZGOo0UEKoE34>oo70
M?on/f7olje_oiQDAoon[f[oCc@Sob/I;?oDNE3oljY@olVBEOoSYegok9Q7oo>cJ_ok`GOoHC<]of8a
9OoFSTgoeJAmoaDE3On_T6KobXI6omRWIOoKV6;oc8M3oonaJ_nVJTgojZ9RonnKFOoW/f[oHC4SoiaW
AoojaW7oa8M=ojAR;_noPe;oeJMbolNLG?n@F1kon[9gonfKCOo[ZUcoH2TMoe8R9?oFR4SomZ1CooJb
IOoe]7So_Gm@ojE^>ooKT4[on/1VolbVEonjTDoon;AToo>dMonFLSko^XM9ooFOD?ooaW[o_8=Hod4H
5?nHIdCoo[R5oh167Om16b;oikQ]onF`Goo@VUcomke;ooZ^LoohZfSo/fM4okMe:_oo`e_onKAYooRb
KOoUZEgon;IfoofgE_oCUeWobIi_oog8RomP;bOoYG53ofHb6_od_XOom;=oonjZM?oTVEgoZV`koiIT
=_o=UFCoi;>=oo;4PoogdYWoB2PJogaG>?o[]HOoaIigok2FMOoicY_odJioojV<JonnVW[oa9YbokFF
K_nlY83oZZ>Uof5gX?mANJ_oD7Z`odmh[_m<Mj[oBGJ[odQg[@02od9dZ`0=od=f[?m0M:[o@7>Zod1b
ZOlnLJSo@g6Zod=bZOm4LZSoA7:VodAbY?m5M:Co@g6RodEcY002odAbX`0GodAaXom3LJ;oAW>TodAa
Xom2L:7o@g6Qod=aX?m1L9ko@g6Ood=aX?m2L:3o@FnPod9`X?loKioo?g6Qoca_WoljL9ko=VfLocA^
WOl_KYco:fbLobI/VolTKI`00OlMKIX00006ocmcW?m0MIco@gFKodAeV_m5M9SoAWBI0_m4Li`01Om5
M9goAG>LodQfWom;MIgoC7NO00?oBgJN0om?Mj000om>MiooCWJOodmgX002odmhX02Boe5iX_mANZ;o
E7fSoe=kX_mANZ3oDgbRoeAlXomDOJ;oDX2Toe5nY_mKO9_oNH>BogAXJ?n[OfooJSTToj5[@?oVZH7o
`h=;oh1Q8ooX_VCookITooFoNon^LSooe95Eomb^G_l]32?o=R4MombaHOmO@QooKe4^onnbNOoUXF7o
i:1Kom6DEolh70ooSfA4ojie@ombF3koN54]om^JCooX[VKogZIPonjgIoob^f7oolR0olVNKOmV@Roo
QePjooJfIOo_[V[oEBLYocdR:OnOLc[ookajonbYO_o]/gGon;=QombOC?oT/fOo]HY>ogIK=Ook_Eco
nKYKoo[0N?o[XeWolYmSomN?E?m=;Ako<QTEon:LHOnfOe7o;1L2ofe98?on`7ooKDDRogeA<OoNZgOo
g:1GooBcGoohb8SoW60hooJaIOn4CS;oBQHHolnKG?nJE3Koa816ooFdNOoTZFconL64ooC0P_o;S57o
i:ASook2M?oKY63oZ7EEoeDY6oo]YUgomkEconbXD_m?40koIdDaog=88Ood/FWooJYHon6NH_n7EBOo
n/V=ookLWoocbWgoj;Yiofi3:OnbQf?ofJIfomfaOoo]aY?ohJm`olbWM_o</Xooc;2>olNTO?nmY7go
Z8m^okFZXOmbPYcoFGf_oe9l]?m@N:goDGZ[odiiZom:MZWoAWBXodEcZ?m6MJSoAGFWodAdYom5M:Oo
A7>UodQbZOm9LZOoBG:UodQbY?m8LjCoAg:SodQdY?m7LZ<2odQcY00GodMbXom6LJ;oAW6RodIaX_m5
L:7oA76PodEcXOm3LIoo@W6Nod9`W_m1L9go@g6Rod5_W_m1LJ3o?g6PocibX?ljL9co=VjJocA^W?l_
KYco;FjLobU`WolSL9h00OlKKIX00006ocacV_lmLYWo?g>Hod5dVOm2M9Oo@WBI0_m0Li`2od9eWP03
odEgWom9MYgoBWNN00?oBGJM0_m;MZ002om=N:;oC7NQodmjY?m=N:;oCgZToe5lY_m<Mj7oCGRRodmi
X_mANj?oDgfU00;oDG^S08[oEG^MoeMmVOm@OJGoCH2/odikY_mKOjGoKGMhoiYnEoo<SUWoRTl:omFU
Jom;6ASoX68hoo6bJ_n3ECOoXX14ooNiMOof/UgoNSl_ocTH1ooIYV7oAR<Joc<J5Oo^]V7ol<9eojIn
COoo^VWoahALolZ:GoneNTOo>2LZoe4j:?o?VH7o@1dHom^]P?m69a3oP6Q1ooS6L_nSLTko?b0FoeLi
5oo[[fcolkiWol2<G_njND7omZm<olfSIOlg>2OoCb`BomR7F?obZ5[ob8MHoc@A;Om14`Somj=Jok^7
HOla6b?oFb`QomN;<?oe/VkoO4P]of/o9OoLYecoo/:9on^VMOo`XV7ookmgojI/B_mX<A[oehi@oo>R
Ion<C1GoOCdKooJlL_ohdHCom]6^oiML??o;OT3oi9MHohQ86oo_]6CoKc8;oj]cH_mcAQKoQ4`LokYc
C?oh_gKoSelkoiIQBooKY6KomjUEolZ6H_oj/V_oe8EMol>JKom>:0WoW6HbomnDB_ok/fCokZeSoog<
P_ode97on=6;oog;ROoGXV_oeZAcolVII_oHZG;of:U_omJXK?oN]X[oc[FFokFNPOnCMU?o[9Egoi^2
K?nOUHKoRiRToe]iYomCNZkoDgZXoeEkZ_mCN:[oD7RYodegZOm;MZSoBgJWod]fZ?m9M:KoBWFWodUd
Y_m<MJSoCGFWodadYOm<M:?oC7FQodegYom:M:@6odQbXP04odQcXom6L:3oAW:Pod=bWP;o@W6M00ko
@72Lod1_Vom1Kiko@FnNod9bX?lnLIko?72MocYaV_lgL9[o=G2Kobm^V_l^Ki_o:FnIobE`V@7o7VjH
00001_lnMIco?GBJocecUoloLiSo@G>FocmcV0;o?gBM0_m0MIh00om2MYooAgBKodUfW@03odQeW0Co
AgFO00WoBGNQod]iXom<NZCoCGZTod]iXom<NZCoCWVQoe1kXomAO:@00_m>NJ40Rom<Nj?oBgjTodim
X?mCO9ooDWfQoe1lXomKP:GoL7j=ojZGQOnYMe;og9]RolVGHOoOV5koPdPNokF;JOm071OoYV`lonND
C?og[7;oPETholZHJOoOVV;o/GA=ooVdL_lm7A7o50`GonB^GonoREGoaXQ=ooB]Fon8ESco`HA1olV?
E_m@<1oogJAUocTF5?m9;bKoj:EPooJbJOneOUOoXgUSonZ^K_on_6ooTfa<oeHb8OnlN4OodXYFoeTZ
4_niKC_omJ5MooRcJooKSTWoRETjol:6D?oi[F7ob85:oehS1onRJDcok:1Oon^ZH?o:NB_onZe^ogY@
;_lg:A3oWf4aoo>/HooN[F[odYI[onVPHooNYFCoDQ<5omN8COndLTooaY9PonfiN_okeXgol[YXonN[
IOmg?RGoi9YTon>HDOo2NSKogYmSonJeO?o`/WWoo[=^olb1BOo`_7ko`7a7onFNF?ok]6KoF34Kol2<
C?ojYg?onZ9Gol9dBOmc=b3oa7mFonZLD_ok/E_ol;]hohi/??n]PE[ohjMgoo6eMookaXKom/Z@olfO
IooM[GGoe:inomFZQOn>ME_oMfE<oi=jG_nQS7GoZ9:6oi28M_nJYZWoHWRUoein[_mIO:GoFGbYoeMl
Z_mEO:_oDGVZodigZ?m@NZ[oCGNWodafY_m>MjOoC7JVoe=hZ_mCN:SoDWRVoe9hYOmBN:CoCGJTodeg
YOm=MZ@00_m<MZ@05om:M:7oBW>QodYcXOm:Lj;oC7FSodMbW_m6MIooAGBNodAcWOm3LYco@W6Kod9b
W_m3LYko@W:Nod1dW_loLiko?WBNoc]dW?lhLiko<G2Koc1aWOl/KiKo:76F007o8fnD00001_lfLiWo
>GJLoc]eVoljLYWo?WFLocmeW0;o?GBK00Co?WFLocmfWOm0Miko@GJN1?m3N:004_m6MIkoAgJOodQg
XOm7MZ;oBWVVodUkZ_m7NJSoBgf/odUkZ_m:O:_oC7ZVodmmYom>NZGoBgVRodaiX?m:Nj3oBWbRodam
X`;oCWnT07koCWnVodinZ_m>P:coF82VofIkTOn;T9Woh9]`oi1G>Oo?PeGoRDPSooBaPooJND7ocXLf
ooZJD_mY?3SoABdVonR/LooGT4?ol[1Joede;omJ;SWogj=PoclR8Om;:a?oj:0ooi]VA?n9Gd7oehiB
on6HD?oZ[fcolj9GonRLHOoc[fkonKAloiEZ>_lb51GoNTHWoo>WDon?Dc7oMC`Xom5o??oOQ3golj1T
om2DH_n6FC[ohIYPoob/F_nXM3Co<a/DoeXT6?o6PdKol[AZoiYT?ole7A;oOe0Won>WJ_oWYf_oe8iE
olj<DooTVUoookj7okEeC?mlBCCobX=9onRNF?nSH2KodY=Sokn7H_noODkoi9eXogeH=_o9/iOogkRD
ol2<IomaFE;oQHJ=ogN0S?n1N7Co]I=jombLF_o9SV7oJC<Eol65EOod[F3olJEdog@k7_nGHd;od8M6
oo6SG?n<DbKofHeMomUoConEDbkodY1>on:HA?o9WfWoGd0Uod/X=_n8GE3okKicolj@E_oQ/7KobJIa
ojfBK?nQQfko[99kofaE@?mlJ5GoYiF6oiZ:OOn=PGgoH5eGoh^DX?mXNj;oGWZXoeemZ_mNOjkoG7b]
oeQjZOmHNZ[oFWb[oeQkZOmDN:KoEGZXoe9jYomANJD2oeMjY`06oe=fXomFN:GoF7VVoe=hXomBMj;o
CG>M0_mAMZ402?m;MJ3oBgNRodYfXOm9MJ3oBWJQodQcX?m:M:?oB7:R0_m7LJ003Om5KikoAg6OodI`
W_m7LZ3oAW6OodA_WOm1LYko?g:MocedWOlfLIWo<g6Iobi`V?l^LI/00Ol]L9X00004ocIfW_liMj3o
>GNPocYgX0;o?GNQ0_llMZ400olnMj;o?gRSocmiX`02od5iY00@od5jY?m2NZGo@WZTod=gWom4Mj;o
AGRUodEgYom6NJSoAWf/odMo[Om8OjkoAgn^odR0[om9OZcoBGfZodUnZ0;oBGjV00?oBWjUodQmYOm9
OZD00om:OjL0Som<P:[oBX:_odb1Z_mJQ:GoHWnHohFAR?nn/YOoGUHoom>UK_nbN3Ood8@mogU:=?l/
8@GokJYNok1h>?mRCAgo`7eDoo:GCoo/Ve?ogXA7oo>?:OnXEako`7U:onRND_n9DS7o718;okN3?_oK
/GGoBCTBomnXGoo^ZeWoGSlAohU@6ooTZEcofJJ2olbIJ_o4PDoofHM3on>KEOo<U6CoVe8PonnEConQ
Fb?oMSlMok9T;?oTTdOofiiKojMaCOoBQFCocG/eojYP6OoDTfWo`8]OombGI?nDDbKoY799okb=G?oS
^X[o/XIGok65GOniU7coMEeEoj6BT_nKT9KoQGn:ogalS_mlPY_oLGZGofQlWomIOj_oEHBaoe^1ZomR
PJOoDX2_odV1]om7P[[oCGn^oeZ1Z?mOMhgo_Z:@onZNIOok/77o`X]Kog@n3Oo5L2[om9MBolR5G?n2
ARSoHCDToflY2?oGPTWoV5TYolj7A_oXSdOoYVXion6gK_ncREKoc9U_ooBhOOo3QEOoh[65ojN6Holb
70WoGDU4ok:IPonfWHWoYi:0ojbKRonLSGkoVHf9oiRCS_m@EEkoKgnTofN2[OmPPJWoH82[oen0ZomL
OJSoFW^VoeYkYOmMOJSoFGZUoe]nZ?mHOZOoEgfWoe]lYomJO:KoFGZUoeQhY?mEMj7oEGRSoeIiXomC
MJ3oDgJQoeAfXOmAN:CoCWJRoe9iYOm>MZ;oCWNRodYdW_m<MZ3oCGNQ00;oBG>L00goBW>NodQaWOm:
LiooBgFQodYcWom8LIgo@W6Kod1aV_lnLi_o>gBJocQcVOldM9co<G:K007o<gBM00008_ldN:Co=g^V
ocQjYoljNZKo>gVWoc]jY_lkNJOo>gZWocakZ?lmNjWo?WbYocmkZ_llNZOo?g^ZocilZOloNj_o@WbW
odAmZ_m5OjgoAWn_odIo/?m2P;3oAX>codB2/Om5P[?oAXBcodR6]?m5Pk3oB8FbodJ4[_m7Q:goB8B^
od^4[om9Pjd3odZ3[P1nodb6/?m9R;GoC8^iodV5/?mDR[3oChO4oeR3/omRQkCoRY:Yog9]NOm;Ec_o
c9=`oh98:_oPTEcoS48lob<C9?mB;R[ociECokb;@?n<I5GoLClWooJMJOmnDBkoXWm<onZ9<ooURDco
kjQfogXo9_lj61cobGiEon^@C_nRNgcoSdPeonfDE?mk;1WoISXgol^6A_oZW4SoTTXLogTl=_nlPU7o
ijaUoia_C?nBKeWo]8Q[om>YP_ncVggoSY:DojjY/On1O7WoQX^<ogB3WOn2Rj_oPXB@oh6>V_m_RJOo
KXJaof23/_mPPZkoG7nXoeV3[OmEQ;CoG8Rjoef5]omHPkSoDhFjodn4^om@P[OoFHFaoeB0YOmEPjCo
E8:YoeB5/Om@PK;oEH:]oeIoZ?mCOZ_oD86aoeB1]OmSPZ;oSIJIohmlKOn6GDOodheCon>KH?o:S67o
SE<dokUY?Oo_RU;o`X5Koh996Oo`Rc?olY91oiYG:_oc/7Woo]20oo[?Q_omchooom2<ol>;FOnaQU[o
/YMhod/i:?n6MW7o^J6:okjXTOngXXkoZIR6oj:CPonVVYCo/:ROoc`m@?mgPZ7oJH>[ofJ6Z_mRPJKo
Hh6Vof61YOmRPJKoIH:Xof:0YomMOJ?oH86Woej1Y_mMP:GoGWjU0_mMOJ@01OmLO:CoGGfUoeMiXOmH
Nj?oEGRP00;oEWVQ00SoEgVSoeQjYOmEMj;oE7JQoeEgX_mAMYooCgVModagV`;oC7JJ00goBWBJodae
X?m:M9koBgBOodYcW_m8LIcoB7BNodIcW?m5MYko@GNNocmfW?ljMYgo=W:J007o>WJN00001_lfOjoo
=7f]ocIn[OlhOZoo>Wf_oc]n[`?o>gna01[o?82bocj1/olnP;;o?H2bocj0/_lnPK?o@8:cod63/Om4
Q;CoA8FgodF4^Om5Q;[oAHBiodJ5^_m7Q[_oBHRlodZ9_Om9R;goBXVlodb;__m;RkWoBh^hod^:]om;
RKOoBhVfodZ8]P;oC8Zh07_oChbiodf<^om=S;goCHfnoe2?_omMS[CoC9C<oeb</_mDUl_oGIG0of^C
`omgT:OoZ9FKom2]NooUZf3obheYoiAI7ooOUS?oQSPJod`D5_naS4_ohZ5Hog`j3_nFEcOokI]Eok5Y
@_mS<1Oo[ELUol1[@?odV5ooQ4XSoeDU0OnaLd?omZmFojIZ?_m9=b[oUH5goe9HE_mUM7SoX9VSohZA
X?mcUJgoLIRkofF?]omSTK_oHY6koej@]omLS;?oGHffoeZ=_?mBS;koCXc4odb?]?mERK3oE8Rhoe><
^_mKRZKoDhbToe>;Z?mCRZkoE8Vfoe6:__mFQk?oEhN^oeJ5[_mFQZooEHJ_oeF4]omGP[goFh>eoeV1
/?mCP;;oDH6iodn2]OmEPJcoFH>]oe>5]?m>Q[goD8>iodb5_Om:Q;SoDh2WofF1W_n?PX[oR86>oiMk
LOn`LDKo]X5Fofhm7omY@BkoX7eTokn9F_o3Re_oXfhmooNjMOnjQUOoQUX`onc7R_oieXGoh[Agok^F
HonnXggoXhmeoin:MOnbVH3o]9j6okVTS_nWUX;oYIF4ojbPUon]Y9KoS8R4ohfD[?m_Qj[oK8R[ofR1
Y?mZPjOoJHBVofR2YOmYPjKoJH:ZofN3Z_mTPJP00_mRPZP01omSP:GoHh6Vof9oY?mRP:CoH7fRoeal
Y?mLO:<00_mMOJD01?mJNZ7oFgfUoeUlY?mGNJ82oeQkX`03oeQlXom>MY[oDg^O00;oD7RL00goD7RM
odmfWom?MYooCGBMoe1gX?m<LYcoBG>KodUeW?m5M9_oA7JLod9fVom0Mi[o?gJK007o@7JK00001?lf
PkGo=X:doc^4]oljPkH4oc^2]P03ocf4^?lnQKWo?hJj00;o?X>h00[o?H:gocj3^?loQ;Wo@8Jgod>9
_?m5RkkoA8W0odJ;`_m;Rl7oCH_20_m>S<<01om?SLCoDHo6oe6?a_mBTLKoChk1odn>_om>S[l00om<
S[h0TOm>T<3oCho0oe:>`?mCSl7oEHjooeFA`omGT/OoHIFjof2F__mJUl?oFiS4oefG`_mkW;goEYo?
oejQc_m^W<WoKIc4ognL[OmOJ8[oMFYPolbZO?o9WXSoDS<Tof]CD_o7UG;oWf/kofaW>?n@QhSo]j^>
ofm^DOm:IecoSXa^okF/U?mMNhGoMJ:hohZf[ommV[;oKYk5ogJ^bOmWUl_oHi?Bof>Fa_m[WlgoI9O:
ofRF`OmZUKcoHiK4of>GaomUTlCoGiC3oefD__mLU<GoGI;3oefB^omES<_oG8bgoeR>]?mES<;oGXO4
oeZ7cOmIRLWoFhW2oe^:]omMRjkoG8b_oeZ;/omKR[CoG8ReoeZ5]OmHQK7oE8N]oe6:[om@Rk7oChV`
oeB<]?mDRK_oDXVmoe29__m>RL7oCH[1odn=^_mDRKcoE8Fkoe69_?m7RkSoE8k8oeZ4]?mZQ:SoJWnK
og68Y?n?W:OoI5iPog9HDon7FdKobHE;onbIA_oc/Vgo`hIFojmnC_obbhoon=>GomR_Noo>Zh7o/i=e
ok2@NOnYQg3oZ91dok:KP_n[Uh3oXI1koj>DP_nTV8ooTHEcoijES?nAU:KoMhb]ofn:[_mcR[7oKhJ/
ogB:/Om`R:koL8N_og26/?m/QJkoJHB]ofR5[OmXQJcoJHNYofZ8Z_mXQZSoJHNYofR6Z?mTQ:[oHh>Z
ofF5ZomSPj[oGGfToef0Z?mLP:SoFX2XoeUnY_mHO:CoEG^SoeQmY_mGO:H00omENZ@2oeAiX`08oeEj
Y?m?MIooDWNQoe1fX?m;Li_oBgNOodMfWOm4Mid3od=gW00001oo>HRnocR9_?lkR/3o>h^nocb;`?ll
S<3o?H[0ocn<`OloR/3o@h[2odJ=a?m5RlCoAHc2od28`?m1RKoo@h_3odB<`_m9SlGoCI35oe6?a_mE
T/WoEi;8oeRAb?mHT/SoEi37oeF@aOmFS/KoEi;9oeZBb_mJUL[oFY?800;oF9?803goEi;7oeZEb_mG
T/OoFYG:oebEb?mMU/WoGYO:oenHbomRVlkoIIS=ofVHb_mTVm?oJiW=ofbLcom^WM3oKYgAogJQc?me
WLkoMj7DogZWc?mkY]OoOJOGoh6We?moZ=?oOZ[=ogjYcon2Y]3oRJ[Eoh2/e?n3ZM?oPjKEoh:Wdomm
Z=SoPJGCogjUeomoYm[oN:GLogRSdomnXmSoNZ7Gog:Rd_mdW/koMIk<og6Pc?mcW/koLIg@offOdOm_
WlooJYc?ofVKc_m[V/coIiW:ofJHb?mTUlSoIiK7ofJGa?mPUl?oH9C3oebDaomJTlKoFi;000;oGI>o
06?oGI?1oefA_omMTL3oHI71of2@`?mNS[koGhfoof2>`?mQS/3oGhjooej?`?mKSkooGHo0oen?`?mN
S[coFhfmoeb?_omKSkkoFXjmoeN?__mGS/;oEHk3oeF>`_mFT;koEHg4oeR<`?mAR/;oBh_7oe69`?mB
SKCoDX^lof>8_OmhNHkoSg9DomBRI_o//F[om/N3oogIUooid8KocjZ2ojR9M?nENV;o[YAiojfAMon^
SWGoXhiaoj>@LonIR6_oX8abojR@N_n_SHGo[9F7oiNEQ_mOK7CoOi2hogV?_OmgT;KoMXneogN?]_mi
T[SoM8bdogB=]_mdS;CoLhfeog6:/om`Rk?oL8bcofj;/OmZQjkoK8V_of^8[_mYRJooJHV`ofR9/?mU
QjgoI8J/of:6[_mMPZ_oHHR`oej7[_mMR:koFHB]oeJ1[?mIPjooDgjYoeJ0ZomDOZWoDGfXoe9mZ?mB
NZKoEG^XoeEjYomBNjOoCWRTodijYOm;NZCoBGZSodQlX_m7Nj400Om6NZ000004odBAaom0SlGoA977
od:@aP;oA97700OoAY;8odNBbOm:TLWoC97:odjCc?m=T/_oC9;;00;oBY3900KoBi7:oe2Bb_mFU<_o
FYK<oenFcOmPU</6of>Hc003ofFJc_mTVLgoIY_?00;oII[>017oIY_?ofBIcOmVVlkoII[>ofJKcOmT
VL_oII[<ofJKcOmXWLooJYoAog2OdOmaX=;oLZ7Cog:RdomeY=KoMZCCogVWeP02ogZXe`09ogbZfOmo
[=WoP:cIoh:/f_n5[mgoQZoMohR^fon8/MgoQZoK00;oR;7M1?n7/=`02On7[m_oQJkJohB^g_n4[]ko
QJoOoh:/g?n1Zm_oOj[JogbWe`02ogfXe`0IogbXf?miY]KoN:KGogRVeomgYMKoMZCEogFSe?mdX]?o
Lj7Bog:PdOmaWm3oL9k?ofbMc_m[VlgoJY[<ofVIb_mWV<WoJIW9ofZHbOmYVLWoIiK7ofRGb?mZUlSo
J9K8ofJDa@02ofFCa00;ofBC`omQTl?oHYC4ofBFa_mSU<CoHi?3ofNFaomUULGoIiG6ofFEaOmUTl@0
0_mPTlH01_mPT/GoGY74oejAa?mPT<KoH977oej@a@;oFi34027oG9>moeV@__mIR/CoIhbkogJ;X?mh
LF[oU6L^omn`J?o/^GGoj/5fohYYBOnPQ7CoUGYSoj^@MOnQQVWoYHQ]oj>4K?nKOfOoVWeToimlI_nR
NFSoXWAQojB3LOmkMV_oD5mZoh:I`?mlU<;oOYO0ogfF_omkU;coO9FnogZB_?mjU;`00_miT[/01omf
T;SoMXniog>@^?mcT;SoLhngog>@^?m`S;@00_m_S[P06_m^SkSoJhjfofR=]OmZSKOoIXRcof>8/_mR
Rk?oH8^coen9]?mORkKoFXJaoeV5/OmJQ[7oFXJ`oeB3[OmCOj_oEh6]oeUo[?mIOZcoEX2^oe=o[?mA
OjcoCWjZodalZ?m9O:KoB7^T0Om7NZ<00004oe6Gbom>U<SoCYC8odnEb@;oD9K:00GoDYO<oeBGc?mE
V<goEiS>oeFGc@02oeBGc009oeJGcOmFU/coEIG;oenEc_mSVM7oIY[@ofVJd?m/VlooKig@00;oKig?
02?oKik@ofnMcomaWm7oLJ3BofnMcom_W]3oLIoAog:QdombX=;oLIoAog2Nd?mbX=;oL9k@og6Od?mb
XM7oLj7BogBTe?mgYMKoNJOFogZXeomkZMSoOJ_Joh2^gOn1[MWoQk?NohFag?n4/=_oQK7LohRbg_n9
]=koRkCOohffhOn?]N7oT;GQoi6hh@02oi2gh003oi6hhOnB^N;oTKSQ00;oTKSQ00SoT;OPohnfgon?
^>;oS;GQoh^dgon;]>3oR[?NohVcg`;oQ[3L00?oQk7MohJ`g?n3[m/00on2[]/07On1[M[oP:cIoh2/
fOmoZmSoOZ[HogbXeOmjY]?oN:?CogNRd_mfXM7oMJ3@ogBNc_meWlooMYk?ogFOcombV/_oLY_;og6L
c?m`V/[oKIS8og2Kbom`V/[oKi[:ofnLbom`WLcoKI[9ofnKbomaW<coM9_<00;oLi[;02SoLYW:og6H
bOm]Ul[oKIS:ofjHbom^V<[oK9O9ofjFb_m_V<coKYS;offGbom[V<_oKIO9ofVEaomTUlWoIIS?ofZH
don4WLWoc;FHokb5@_oYZVOojKiloj^;M_n[Sg_o/iMnok:FO?nXSWCoZY9loin3L?nMPW3oX8=coj5m
KOnPMFCoXGAHoiiiHOnGQ83oQhbNogjI_On1WL[oQ9c90_n2V/P02On0V<KoP9S4ognG`omnU/;oOiO3
ogfE`OmlU/7oMi>nogZF`@03ogVE`0;oLi:n00koLY>nog6C__m]T[coKHnlofn?_Om/SkcoJXnkofV?
^omXTKgoIY2nof>=^omPR[SoGXRfof6;^@;oGXRf00[oGHNeoef6]?mJQ;;oEh:boeJ3/_mBP[3oD8>`
odn2[om>PZooCH6^0Om<P:d0000PoenKdOmMV/goGY_@oefJc_mNVm3oGY[?of:Jd?mPVm3oHIgBoenL
dOmNVlooEYO;oeVHbomLV<koHI[?ofJLe?m^W=CoKikCog2OdomdX]CoMJ;DogNRe?mhXmGoNJCFogVT
eOmjYMOoN:?EogVTeOmjYMKoNZGGog^Vf?mlYmT2ogfXf@;oNjKG013oNjKFogbWe_mlYmKoO:SGogjY
f?moZ]WoOZgHoh:`g?n4/]koQ[CPohFcgon8]=coRKGNohZfg_n=^N7oS[[R0_n@^n401?nA^n3oUKcR
oiNlhonH_N<3oiRnh`05oiVoi?nJ`>GoV/3Toi[0i?nG_N800_nF_>402onF_^;oUKgSoiBlh?nE_N?o
U;cQoi>mi?nB^nCoTK[Soi2ih_n?^N;oS;KP00;oRkOQ01SoR[GPohVdgon8/mgoRKGOohRcgOn5/Mco
Pk3Ioh:^f?n0ZmSoPJ_IogjXe_moZMOoOJODognXe_mnYmGoOjSFogfVe?mlYM?oNJ;AogRUd_mhXm7o
M:3=ogRSd?mgX/l2ogVSd@0cogRRd?mkY=;oOJKDogjRd_mmXM7oO:3@og^OcomjW/koNIk?ogVMcomf
VlgoNIk?ogZOd?mkW=3oNYgAogVNd_miWm;oMioAogBNeOmdWm;oLY_8ogFJaomiVLcoP9_>ogioN_o_
_hGoo/V@om>/M?ndT7go]9j8olJ[U?nPQ6ooV89bojFGR_nLVXWoXZ2DoiVDR_n8Ng3oRgESoib1JOnJ
N6?oTG=ZohMnR?n?X[ooRJC=ohZRcon:X]3oRZ;?ohVQc_n5WL_oQIg:00;oPi_700?oPY[6oh6Ja_n0
W<L00_mnV/D07_moVlOoOi_6ogZIaOmiUlCoMYO3ogNHa?meV/GoMYK4ogBD`omcU<7oLYG2ofnD`Om/
Tl7oJI72ofR@`OmVS[ooIHfnofB<_OmTRkcoIHfnof:<_?mQRk_oH8Zjoe^9^_mHR;SoEhRhoeF8]omC
QkKoDHJeoe67]P7oCXBc00001OmZW]7oJIg?ofZNdOmZW]3oKJ7D00;oKIoC01;oKJ3CofVOdOmUWLko
HIc<oenNc?mRW/koIYg>of^NdOm`XMGoM:7FogNUeomiYmSoNJWHogZZf?mnZ]SoOj_Hoh2/fOmnZ]L3
oh2/f@04oh:^fon1[M[oQ;3MohFagP;oPZkK0on3[m`3ohB`f`09ohFag?n7/mkoR;CNohZfh?n;]n7o
S[[TohfihonC_^?oTkoR00;oU<3S00OoUL7ToiW3ionG`^CoV/;Uoig3ionP`nSoXLCX00?oXLGW00?o
X/KXoj?7jOnRa^P01?nPa>H02onOaNOoW/CVoig3iOnOaNOoW/CVoic4ionK`nOoV/;VoiS0i?nH`>?o
U;kU00?oU;oW0onB_ND01_n@^n?oSKSPoh^fg_n9]=coRKGOohJbg0;oQK7K00?oQk?MohRbg_n9/]h0
0_n5[m/3ohB^fP;oPJ_H04coPjgIoh:[eon6[=WoQZcIohF/f?n6[=WoQjgJohR^fon7[M[oQZcIohF[
fOn4Z]OoPZSEoh>Ye_n2Z=GoPJODoh>Xe_n5YmSoPjKFoh6UeOmnY]GoP:SGognWe_n1Y]SoPJCEoh6S
dOn5Y]7oPjSFog^?V?oR`9?oh;Z@oiIgA_nTNF3oYYV3ogMQCoo4[IooRWeeofe/Iom_OGCoNhN6ofA/
KomiNWKoVi>5odDl>on>N6koV7ENohegKOn5R9ooVJkFoiB]eOnBZmCoTJ[Boi2Yd_n=Y/ooSZKDoh^S
dOn<Y=;oRJ7@ohJPcOn3WlcoQJ7>oh>Oc?n6X/ooQJ7>oh>Qd?n0W/goOIk<ogfOc?miW/[oO9_;og^I
bOmiVLSoN9W8ogNIaomdV<WoLYO;0_maU/X03_maULWoL9C9ofnDb?m[T<CoIi33ofF@`_mRT<7oHI32
oef?`?mMT<7oFhnooeV?__mESKgoDXZk0OmBR[`0000]ogJTe_mbXmCoM:?Eog>TeOmfYMOoMjKHogJV
fOmeY]WoLjGHog2Ueom[XM?oIZ3@ofZQd_m^X=?oLj;DogRUeomlZ=WoPJcMoh:_g_n2/=koP[7Moh:`
g?n4/=goQK;NohFag_n5/mooRKCQohZfh?n:]N;oR[KPohVehOn9]N3oRKGQohVfhOn;]n?oR[ORoh^g
h_n<]n7oS;SRohbhhOn>^^?oT;_Uoi:mi?nC_NGoU;kV00;oUl7Y023oV<7UoiW2i_nJ`nOoVlGYoic5
jOnLa^SoX<OXoj36ionSb^_oY/_/ojO<kOnVb^_oY/[ZojK:jonWbn_oYl_]ojW=k_nWbncoY/[[ojK:
k?nWbncoYL_ZojC:jOnTb^SoYL_ZojC:jOnTb^goXl[]oj79jonPan[oWlOYoio6j@;oWlOZ01WoWLCW
oic3ionK`^KoWLGYoi[3ionJ`NGoV<3ToiNohonF`NOoTKcRoi6mhon@^n7oTKcRoi:liOnC_>KoS[SQ
ohnhhOn=]n3oS[KQohjeh?n</]goSKCOohjeh?n=/mkoT;KP00?oTKKQ00?oT;KPoi2eh?n?]=l00_n>
]=h0;On=/mkoS;7Kohjcg_n=/]coRk3Johfbg?n=/MkoSk;OohndhOn;/=goR[3Lohb`f?n=[m_oRZgP
ohV`hOn6/=goQ;CRoi6[_oo5[iGo`jB3okFDJ?o4U73oT7]TofmHAooF_JGoi]K6ojN[X?mGJ6GoFfM/
ohV>U_na[:coZYb@oeMAEOmZFE3oTW5Eoi=gHomYHFWoUJC0oibdf_nK]M[oV[GFoiRbeonE[MSoTjcI
oi2YeP02oi6Ze`0Roi6[eon;YmCoRjODohfYe_n>Z]OoSJWFohZZfOn8YmKoQJKDohBWe?n1Y=7oPj;B
oh>Qd_n1X];oP:7AogjOcomjW/ooMig@ogJKc_meVlkoLiW<og>HbombV<_oL9K9ofnHb_m[ULSoJYC7
ofNCa_mVT/GoHi;4oenA`_mMT<3oFY74oeR@`P7oF8o200000omo[McoOZcKogf[fP02ogn]g00<ogj]
g_mlZmgoNj[LogVXf_mhYmWoLZ7Cog>Ue_mgYmSoNZSIognZf_n2[]_oR;;P0_n9/n402On;]N?oS;KT
ohfghon=]n?oS[STohfghon?^NGoT;WSoi>mi@04oiBniP;oT[gU0onC_^H01onD_^CoUKoUoiO1ionH
`^SoU/3VoiW3ionJa>P00_nKaNT00onMan_oWlOZoj38j`03oj79k006ojG<j_nWc^WoZ<oZojS?j_nY
d>_oZm7/1On/cn/2ojg?l0;o[<k_00Co[Lo`ojg@k?n]d>co[M3/0_n/cn/01_nYcnkoZ<o^ojO>kOnX
cnkoYlk]ojS=k@;oZ/c]00GoZL_/ojS:jonWb^[oY<[/oj?9j`03oj;8jP03oj78jonOaNWoWL?W00?o
WL?W0onL`^H01?nK`NGoV/3UoiVoi?nH_^<2oiJlh@08oiRlhOnK_N;oW;kSoibnhonM_nCoW;kSoifo
i?nL_^<3oiZlh@05oiRih?nI^^7oUkSOoiNhgonH^N000_nG^=l01?nH^N3oVK[QoiNhgonE^N02oiBi
h@;oT[OO01coSkOQoibgdono/ZGoZhMTomJWNoo9TUgoYGMAojb1JooG[WcocK29okRgV?m7FE;oAE=@
oiNKUonZXYGoZYQnogQ^H?m>?B_oTWIMoh9WD_mgIekoO8>CojRmi_nS_NKoWKWGoinhfonN]N?oV[GN
0_nH/m`00onG/]_oU[7JoiFag002oiFag008oiFafonC[m[oT;7Lohn`fon>[m[oSJkIohb]f?n:ZmT3
ohV[f@0:ohNYeon4Z=OoPZKIognTe_moYMOoOJ;DogbRe?mhXLooMYk@ogBLcP;oLIW=00OoLiS<og6H
bom_Ul_oKIO9ofVGbOmUV<[oI9S:007oHYG800000on3/]koQ;?OohFdh002ohFdh00LohFdhOn2/N7o
OjkNoh2_gomn[MgoOZgLogZZfOmm[=[oQ:oNohNbg_n:]>3oS;GPoi2ii?nB^nKoTK[Voi:kionB_>Ko
U;gWoiBnionD_^SoU[oYoiNni_nI`NOoVL3Yoi_2j?nK`^[oV/;XoiS2j@CoV<;X0_nK`nH01OnK`nOo
WlOZoj38k?nQbNcoX/[]00;oXl_]00CoY<c_ojK<kOnWcNkoYlk_0_nYco001_nZcncoZm3[ojgBk?n]
d^co[]?]ojoDk`;o/MC_0onbe?03ok3Bl003ok7ClOnbe?;o/MC_00;o/MC_0_nbe?001_n`eO;o/=Ca
ojoCl?n_e?3o[mCaojgAkP?o[]3^00Co[Lo]ojc>k?nZc^goZ/k]0onYcN`00onVb^_oYlc]ojS;k002
ojK:k008ojG9j_nTbNWoXlOXoj?7jOnUbN[oXlOZoj;6jOnQaNP2oj;5j@09oj;5j?nSaNKoY<GXojG7
jOnWbN_oY/OYojG6j?nTa^SoX/?V00;oX/?U03[oX<7Voj72ionO`NGoWl3Uoj31i_nR`nSoXL;Woj31
i_nO`NGoWl3Uoig1iOnL_nGoW;oToiboiOnN`>KoVl;YojC1f?ndYI7objAfojQd??oSYFCo`haEonfk
UoobaHGon=fdoj^_U_lA81Oo1A4=oh27Pon`Zi[o^ZN8okB[Uom^Gd[oRFeDoiMgI?nCNFooMWB0ok71
i_nY_n_oY/3RojVnhOnY_>OoXKgSoinkhOnN^^3oW[[Ooibhg_nL^>3oW[[Qoi^ggonK^>3oV[KNoiNg
gonF]]ooUKGNoi>cg_nB/]_oSk7L0_n>/=`02on=[][oS:kJoh^^fon9[McoQZ[IohFYf?n4Z=OoQJ[H
ogjWe?mkXm7oNJ7C00;oN:3C00OoNIk@ogJMc_mdW<goM9g>og>Lc?m`WM3oK9[=007oKI[>0005ohZi
h`03ohJeh?n5]>3oQ;?O00;oPk;N00SoQ[GQohFdh?n9]N;oRkKQoi6liOnB_>CoUKcSoiNniP;oVL3W
00?oV/7Xoi[1i_nJ`^L00_nL`nP01?nMa>WoX<KZoj36j_nPa^X2oj77j`06oj37jonOan[oWlOZoio7
j_nPb>_oXLW/0_nRb>X02onSbN_oZLoaojO=konVcNcoYlk]ojS?k_nYd>ooZ]7`oj[>kOn]dNoo[=3^
00;o[m?a00Ko/=C`ok;El?nce_7o/]G`okGHlonffO@2okGGlPCo]]Sc1?nff?83okKHl`;o]MOb1?nd
eo401?ndeo;o]]ScokKHl_neeo43okCFl@08ok7Dl?n_d^ko/=?_ok3Bk_n^dNgo[m;`ojkAkon/d>d7
ojc?k@?oZlg^0_nZc>d01?nZbn_oZL[Yojg>kOn]cnd2oj_<j`03ojc=k?n[c>_oZL[Y00;oZL[Y0onZ
bn`00on[c>goZ<WZojS9jP02ojS9jP03ojK7j?nTaNKoY/OY00;oYLOZ01koXLCVojC6jOnVb>So/l?:
okbRPOnnSeOolkYlooFeL?o7U5_ofjR4ooKAS?m`F3Wo0Pd8o`D<4?l22QGo1@TBoc<Y9OneVX?oZif6
of=@>OnMPFOoWgiZoiioLomQE5GoV9jhok30k?nZ`nGoZl3Pojk2ionU`N@4ojC0h`03oj>oi?nT`>Go
XKgR00;oX;cQ00SoWkkToi^khOnJ^^3oVKWOoiRhg_nF]mkoUKSNoiFhg`;oU;OM00?oT[COoi6ch?nA
/n000_n>/=`01?n</=coQJkJoh:[eon0Z]P2oh2XfP07ogjWeOmmYM?oOZCCognUe?mnXm;oN:7CogJN
d@01ogFMd0000on>_NH06?n=_>GoS;_Toh^ihon:]^7oRKGPoh^ghOn:]^7oSKWSohnkiOnB_^OoTkgU
oiS2j?nH`>GoVl;Voic3ionM`nOoWLCXoik5jOnPan[oXLSZoj;9jonPanWoXLSZojG:k0;oYL[[0_nV
bn`01_nUbncoY<_[ojC;jonTbn_oYLc/ojK=k@;oYlg[017oZ<g/oj_@kon[d>koZ]3/oj_AkOn/d^ko
[M?_ojoElOnae?3o[m;^ok?Fl_nbeO7o]=ObokGGlOnff?7o]mWbokWKm002okSJl`;o^]Wc0onkf_@2
ok_Kl@03okcLl_nmgO;o_Mgb00Go^m[d00?o^]ccok[Ml_njgO800_nig?400onkg?;o^m_aok[Jl002
ok[Jl009ok[JlOnhf_?o]]SaokGGl?nde^oo/mG^okCElOnce?3o/]?_00Oo/M?_00?o/M7_ok3Akon`
dNl00_n^cnd02?n`d>go/M3/ok3?jonbdNko/M3/ok?Ak_ncd^oo/M3]0oncdNh3ok3>k@03ok7?k_n`
c^co[lg/00;o[lg/00?o[/c[ojk;j_n[c>/00_n[c>`07onZbn_o[<c/okG=i?nVVHooeJQjoo>kOoo/
/gKogj9SombVJOn[LT_om/5goedl8?lG6ako8R0Soc8c?_lG5R3o>RXSok:?LOn?ME_oQVeDoieoIOnA
LEcoJ4Xioi9jKOmVGFGo^lOZok3:jon^b^Oo[lOYoj_8ionYa^D00onXaN@3ojW3i@;oZ/CU00KoY<;U
oj?1honR`>?oXKkQoj2mh?nK_N42oiZnh@;oV;cO01;oV;[PoiRihOnH^N7oU[OOoiBegOnB/mcoS;CP
ohVbgOn7/=goQk3NohF]gOn3[M[oPjcIohBZf?n7Z]WoQjOHoh2WfOmmY]L1og^Te@000onC`NT03_nB
_nOoSkcToi2miOn?^^;oS[WQoi6li?nA_>?oTkkUoi>oi_nG`NSoV/CZoio7jonLa>SoXLO[0_nPa^X0
3_nRb>coXlW]oj;8jOnSbN[oY<[[ojC;k?nVc>coZ/k^oj[>kOnZc^koZlo^oj_?konZcnkoZ<o^0_nX
cnd00onYd>koZ]7_ojgAkP02ojgAkP03ojcAkOn^d_3o[mC^00;o/=G_00go/]Oaok?Hl_ncenoo]][b
okGIlOndf?3o]m_cokSKlonifoCo^]ceokWKm?nlg_Oo_Moh00;o_Mcf0_nngOL00onngOKo_]kcokkN
l`03okgMlP08okkNm_nngOOo_]kfokoNn?nogoOo_MkdokcOlonmgo<2okkPm003okoOmOo0h?Co_]kc
00?o_]kc00Oo_=ccokWKl_njfo;o^=[aokSIl?nhf_?o]mWb00?o]]Sa1Oneeo05okCFl003okGFl?ne
e>ko]]G^00;o]]G_0_nheo401?nge_3o]]G_okKEkonfeNl3okGDl003okKElOnddo3o]MC_00;o]MC`
02Co/m;_ok;AkOnadO3o/=7`ok;Al?nad?3o/M?cojfndOnaSWCoWV8]omFKG_oHX6GofYmXooRiMOo3
P57oj:=Cok=kDOmeGeKoKEm>ogU`JOmdJV3oJU<moimjD?mdDcCo/Y=goimnI?mnGTSoU7UToiQnI?mj
J6CoV:2kokGAlOncdNoo/<c[ok3=j_n_c>T3ojg:i`03ojk6j?n]aNOo[/KX00;o[/KX00GoZLKWojS6
j?nYanSoY/CVojG3i003oj33i@;oWL3S01;oW/3Toijoi_nN_nKoW[oVoiZkh_nE^=ooTkcSoi6ih_n@
]n?oSkKToh^ch?n:/mooR[7NohZ`gOn=/=goSZkLohF^gOn3[Md1oh2[f`0001;oUl;WoiK1i_nD_nCo
TkkSoi:mh_nC_nGoTl3Woi:niOnG`NOoVL;Voi[2iOnL`^KoX<KZoj77jonRb>coXlW]ojC8j_nUbN/3
ojK:k008ojO;j_nXc>[oZLg[oj[>k?n[cngo[=3/ojcAk?n^dnh6ojgBk@03ojkCk_n_e>oo/=?^00;o
/=?^00?o/MC_ok;El?ndf?001?ndf?03okOIlP;o^=[c0onjg?<3ok_Mm0Go_]ke2_nogo@3ol7Pm0;o
`^7e0oo1h?@3ol3Ol`;o_mge00?o_mkfokoMmOnng?@00_nkfo800onjf_7o^m_bok[Jl@03ok[Jl@;o
^m_b0onifO000onifNoo^][aokSHl005okWHlPGo^][a1?nif?801?nhf?7o^MSbokWHl_nheo42okOF
l00VokKEl_nge??o^]?dokWFmonce_So^/kHokJ2D?o0PTkof[=momBJD_oPX6[ol[meoo[EW_n[LCOo
fHY9om6:Foo7TEOo/XAIokZ=GOnDIdWoPfaDojF:J?niUVkoYh1MoiA^DonHO6KoM5U2ofICBOmlOY?o
^/odokCAloncd^co/]7]ok3@k?n`cn_o[lkZojk=jOn`c>/2ojo;jP03ojo;jOn^b^Wo[<[X00;o[<[X
0_nYanD01onVa^SoY<CXojC4j?nS`nOoX/;Voj72ionRa>T00_nP`^L02OnN`>GoWKoSoi^ni?nJ_N?o
VKcRoiRjh?nG^^3oU;WSoi>hhP02oi2eg`03oi6fh?n<]=ooRK?N007oRK;M00003OnIa>[oUl;XoiG0
i_nD_nGoTkkToiBoi_nD`NSoU/;XoiO1ionJ`nOoW<CWoj77jonRb>`00_nTb^h00onVc?3oY<[/ojG;
k@03ojK<kP07ojS<jonYcN_oZ/k/oj_?kOn/d>ko[M;]ojkCkP07ojoDk`07ok3El?nae_7o/]G`ok;E
l?nce_7o]=ObokKIm005okKJlP?o^M_d0_njg?D3ok[Ll`?o^mgd1Onng_D5okoOm0Go`N7f2?o3h_H3
ol;Qm@;o`Mog00?o`]ogol7Pn?o0g_H00_nogoH2okkNm@04okgMm?nng_Go_]keokkNm@Go_Mgd00?o
_=ccokgMm?nlg?@01?nmg?H00onmg?Go_]keokkNm@03okkNm@?o_]gg00?o_McfokcKmOnkf_@00_nj
fO<2ok_Jm00QokgJl?nifoKo]m_lok[ImOo:g>Ko]JnKonBZJOndN4Wo`IA/omjHCOod[V?oi;1OooCK
Y_mmDagol:APom>3@OoOU4oocXeFokYoA?nXM4ooL5Pmok:SS?o0YH;o_IA[ojZ3H?mlHd[oE3PRohec
I_n3Oh_o`M?aokOFm?ndeo3o]MC`00;o]=?_00Oo/m;^ok;AkOndd>ko/]3]ok7>k?nbcnco//o]00Co
[/cZ01So[L_Yoj[;jonYb^coZ<WZoj[;k?nXbN[oY/SZojK8jonTa^WoYLOZojC6j?nQ`nKoX<CZoio2
j?nN`NOoW<3Voi^ni?nG_>KoV;gWoiFji?nD^N?oTkSRoi>ki_n@^^@1ohnhh`0000CoU/?ZoiC1j?nB
_nKoT[oV0onC`>L01OnF`^SoVL?YoiW2i_nRb^goX/S/00;oY<[^00WoYL__ojK<l?nSbncoYLc]ojG=
k_nUc>koY/k_ojW=k?nZc^`00_n[cnd01On]dNoo[=7/ojcAk?n/dNco[]?^00?o[mC_0_n`eO001?na
e_7o/]Obok?FlOnce_42okCGlP04okGHlonff_;o]][bokKJlP;o]m_c00?o^M_dokSJlonhf_<00_ni
fo@00onifo?o^M_bokWKlP03ok_Mm0;o_]ke0onogoH5okkNl`03okoOm?o0h?Go`N7f00;o`^;g1Oo2
hOD4ol?RmP04ol;QmOo4hoOo`^7eol;Qm@?o`n;f0oo1h?@00onogO7o`=ocol7Pm002ol7Pm0Go`Mod
0_o0go<00oo0g_Go`=kfol3NmP03okoMm@;o_mkb00?o`=odol7Pm?o1h?@00_o2h?P3ol7Om`03ol3N
m_nogOGo_]cd00;o_]cd02Go`]g_ok_MmOnhh?ooan;cok:aY?naUFOon[]_okAf@onYL4Soj9U?oo6a
IOoY_7_onN[4ogIF9ooe[6?ojYA4onN>@?oAPD7o`gTfok]oE?m[DSGoViR=okZ/UOnWQfCoZHEQohM/
D_mP@2WoXH1^of]OH_ng`mKo_M_eokGGlonheo?o]]GaokOFl_nde?3o/m;^00;o]=;`00?o/m3_ok;@
k_nbd>h00on_d>d02On^cnco[Lk[ojg>kOn/cNcoZlc[ojc=kOnZbn_oZ<WZojO9jP02ojK8jP0>ojK8
jOnUanWoX/KXoj75j?nQa>OoX<CVoio2iOnJ_nKoV[oWoiVni_nH_NGoUkcToi>ki?nA^n<1oi2jhP00
00coT/7Zoi2oj?n?_^OoSkkWoi2oj?nA`>SoTl3WoiK2jOnI`nWoWlO[oio7j_nRb>`2oj?9k@09ojC:
k_nUbnooXl_/ojC<kOnUcNkoY<c]ojK>konXcNcoZ/k/00;oZlo]00So[M7_ojcAk?n/dNco[=7/ojgB
kOn^dnko[mC_ojkCkP;o/=G`00Oo/MKaok;Gl_nce_7o/mKaokCGl_nce_7o]MSc00?o]MWa0_nff_80
0onifoCo^=[cokSJl`02okWKm003okWKlonifo;o^M_b00?o^mgd0_nmgO@3okkNm@Go_]kc00?o_mod
ol3PmOo1hOH00_o1hOH5ol;Qm@Co`n;f00Co`N3dol?Rm_o2hOGo`^7e0oo3h_H2olCPm@03olGQm_o4
h?GoaN7f00_oa>3e0_o4h?H3ol?Om@;o`mod00?oa=oeolCPmOo4h?D00_o5hOL01?o4hOKoa>3fol?P
mOo3h?D4ol;Nm00Uol;Nlonog_Oo`]ogokg<conm/IOoJTTHomnQF?oc/6Ko_WHkonBBDOoG/H;oITL/
od4e9OmjE2gonJeRooJUDOoUS4?o^VHYomZ;Aoo0PUGoS7AFoaD@4Ol[9R3oCd<boiR1J_mnGd?oTFe@
oiUiGomHBT3oMgb6okoEkOnje_Go^=SdokSFl_nge_;o]]GaokCDl002ok?Dl@03ok7Cl?nad^oo/M;_
00?o[m;^0_n^dNd01_n^d>ko[Lk]ojc=k?n]c^go[<c/oj[;j`;oZ/c]0onXb^/03?nUbN_oY<SZoj?7
jOnSanWoXLGWoj36j_nNa>SoW<;Woi_1i_nJ`>CoVL7XoiO1i`7oU/3V0003ohnnj009ohjmion?_^So
TKoWoi?0ionF`^WoW<K/oio8k?nOan[oXLO[00;oX/S/00WoXlW]ojC:k_nQc>coX/g]oj?>k_nRcNgo
Y<o_ojS>k?nZc^`00_n[cnd00on]dNoo[=7/ojcAk002ojcAk003ojgBkOn^dnko[]?^00;o/=G`00Oo
/MKaok;Gl_nce_7o/mKaokCGl_nce_7o]MSc00?o]=S`0_nefO400onifoCo^=[cokSJl`02okWKm003
okWKlonifo;o^M_b00?o^mgd0_nlg?<3okgMm0Go_]kc00?o_modol3PmOo1hOH00_o0h?D5ol;Qm@?o
`n;f00?o`N3dol3Oloo2hOD00_o2hO<3ol?Rm0;oa^7d00?oaN3colKQm?o5h?<02?o6hO@2olORm@03
olORm_o7hOOoan7g00?oa^3f1Oo6hO@2olOQm`05olKQm_o6hOOoa^3folOQmoo6h?H00oo5goD08oo2
hOcoa>3jolkOkonRY9goWHeaoh1R>ooe^GKokjE6on:<?OoCQD_oBShaod4^>?lW6AgoVf]8omj@A?oT
VT[og8Y;ok5Q:oo=PD3o[W97oiZ6K?lC2Pko7ahToaHM7_m>A3SoRVA9oiefD_nJOeoo>RTGog]jOon3
T:Wo_=CeokWHm?nhf?Co^=Kb00;o]mKb0_nce_801?nbe?7o/MC`ok7Dl?n`dnl2ojoDk`;o[]?^00?o
[m3]ojk?k?n]c^/00_n]c^/00on/cnco[<o]ojc?k@03oj[=j`07ojS<k?nWbn_oYl_[ojK:j_nUbNWo
XlW]oj36jP02oik4j003oig3ionJ`nOoV<;V007oUl7U00001On:^N?oS[gVohnlhon?^n;oUL3V00;o
V<;V00OoVlGYoic6j_nMan_oW/S/oio:k?nPbngoW/W[00;oXLc^0onUbnd01?nTb^coY/c^ojS<k_nY
cNl3oj[>l007ojS?k_nYd>goZ]7^oj[Ak_n[d^oo[MC`ojoDk`02ok3El004ok7FlOnbeo;o/]Obok;G
lP?o/mSc1?ndeo801?nffOCo]][bokKJl_nff_83okOKl`03okSLm?nigOGo^Mge00;o^Mge0onjg?<0
0onkgOCo_=keokcNm@04okcNm@03okkNlonogoCo`>3e00;o_mod2oo1hOH2ol3Pm@?o`N7f2?o2h?H0
0oo3hOSo`n7golGQm`04olGQm`03olCQmoo3hOOo`n7g00?o`n7g0_o5hOL00oo6h_Ooa^;holKRn002
olGQm`03olKRmoo5hOOoa^;h00GoaN7g02Go_N7`okgOoooEgm_oYhUToi9^FomPD3?obJ5comZ8<?o`
ScgoUeLYoeLm:_mTCdKoSFQAok1bBOn]DbCoeFdkom]g@oncEbKoaf/koj9D:on2Dd?oJF5LofQOF?n9
Lf;oSVU=ojEcConUM5CoRgeTob8X5om]HV7oIFUlokCJm_nhf_Go]]SbokSGlonheO;o]]Ga00;o/mCa
00Go/]C`ok;Cl?nbdo3o/MC`ok3Ck`03ojoBkPGo[M3^00?o[=3`oj_?lOnZc_000onYcNl4ojO;k@03
ojK:k?nSbNgoX/S/00?oX<KZ0onM`nP0000<ohjmion=_>GoSkcSoi6niOnG`^SoVlGYoig7jonNb>co
W<KZoig7jonNb>coWLSZ0_nNbN/2oj7<kP?oY<[/0_nUbnd00onXc>koZLg_oj[>l002oj[>l007ojS?
k_nYd>goZ]7^oj[Ak_n[d^oo[M?`ojkCkP02ojoDk`03ok3El?nae_7o/]Ob00Co/]Ob1?ndeo801?nf
fOCo]][bokKJl_nff_83okOKl`03okSLm?nigOGo^=cd00;o^=cd0onjg?<00onkgOCo_=keokcNm@04
okcNm@03okkNlonogoCo`>3e00;o_mod0oo0h?D8ol7QmP;o`>3e0oo1hOH9ol;PmP03olCRmoo5hOSo
aN7g00?oaN7g00?oa>7gol?Qmoo3hOL00oo3hOL8olGQm`03olCPm_o5hOSoaN7g00CoaN7g02Go`nG`
olSQoon_/j[oY8a`og1KE?m7?bkoTWABomNECOofWDooeWllonfVJ?oQ/h7ocY=UokUY??o>KcKoiW/i
ol]a>_nYDAcoe7Lmom1h?_nYJD7oP6I?okRLOOoEYgoo`XeSoj=bC?n;H4OoPfmQobDR6OmLAdSoO6en
ol3@j_njfOGo^=KbokSGlonhe_;o]]Ga00;o/mCa00Go/]C`ok;Cl?nbdo3o/MC`ok3Ck`03ojoBkP?o
[M3^0_n/cnd00on/cnooZ/k`ojW=k`03ojW=k`?oYl_]00CoY/[/ojG9jonSbNgoX/S/0_nQan/00onN
a>SoW/CYoik4j@01oik4j@0000KoSkkXohbki?n>^n;oTl3Woi[5jonKaNT2oi[4j006oic6j_nMan_o
W/S/oig8j_nOb^coW/W[0_nQc>h2oj?9j`05ojC:k?nVc>koYL_]ojS<k_nYcNl00onZc_001onXcnko
ZM3]oj[Ak_nZdNkoZm;_ojcCkon]d^d00_n^dnh01?n_e>oo/=G`ok;Gl_nbeo83ok7Fl@Co]=Ob00Co
]]WdokKJl_nff_;o]][b0ongfo<00onhg?Co^MgeokOKl`02okOKl`?o^]cc00?o^mgdokcNmOnlg_D0
1?nlg_D00onng_?o_modol3Pm@05okoOm0So`N7f0_o0h?D3ol7QmPSo`^3f00?oa>;hol;Pm_o5h?L0
1?o5hOL00oo4hOOo`n7gol?Qm`03ol?Qm`;oaN7g0oo4h?H3olGQm`03ol?PmOo4h?KoaN3g00CoaN7g
02Goa>C_oloNlonTWH[oOfeFoh9gNOn6QGWoVXA_okB7Doo=P3koj8Djonf6:ooe[EKohY9=olE[<ooX
R4KolhllolmoAonWFR?oag0`omn2??o9O3ooQULZom>NJoo=S57o^Gi9oh]P>_n@MUooEU57oeAHEOm:
@SgoLfU]ohZ?XOnkf?Co]mGbokSGloneeo;o]=Ka00;o/mCa00Go/]C`ok;Cl?nbdo3o/MC`ok3Ck`03
ojoBkP?o[M3^0_n[c^`00onZc^koZLg`ojS<kP03ojW=k`;oYl_]0_nVb^`00onTb>[oXlW]oj;8k003
oj36jP?oWlGZ00001On>_NOoSKcUoi6niOnF`n[oV/G[00CoVlGY00?oW<KZoig7jonNbN/00_nNbN/0
0onOb^coX<_]oj?9j`02oj?9j`03ojG;kOnVc>koZ<c^00;oZ<c^0_nYcNl02?nXcnkoZ<o/ojW@kOnY
d>goZm;_oj_Ak_n/dNco[]?^0on`eO03ok7Fl@03ok;Gl_ncf??o]=Ob00;o]=Ob00?o/mKaokGHlone
fO400_nefO42okKJlP?o]m_c0onff_801?nifo;o^]ccokSJlOnjg?<3okcNm@?o^mgd0onng_<5okoO
m0go`>3e0_o1goD00oo2goKo`^3fol;PmP05ol;PmP03ol?PmOo5hOOoa>3f00;oa>3f00Ko`n3fol;P
m_o2h?Ko`]ofol?Qmoo1h?D2olGQm`Soa>3f00?oaN7golCPm_o3goD00_o4h?H0:?nohoCoc]OWojjI
Oon8LeSoRWekoijDPOnMRW;oW7]>ojM_@?o1MdKoeX=3om:6=OoaXE_o`6d^oo6NF_oVUDSoehiHokUe
@ooDRTkokieJol^5Boo3Qe?o]WY5ojM]>OnCHS[oRVI:ofmTC?mfOGCoCeYHoeEOEom3A3koN7R5okkG
mOnheO7o]MGaok?FlOnbeo7o]=Gbok;Dl?nad_02ok7Bk`?o[m;^0_n^dNd01_n]d>ko[]7_ojc?kOn/
cngoZ/g/ojW=k@?oZLg_00?oZ<c^ojO;kOnWbnd00_nWbnd00onVb^coYLW[oj;8k002oj36jP;oWlGY
0onNa>T00007ohjmion>_NKoTl3WoiG1j?nIa>[oV/CXoiW3i`02oi_5j@07oic6j_nMan_oW<OYoic7
jOnNbN_oWl[/oj3;k@03oj?9j`03ojC:k?nUbngoZ<c^00;oZ<c^0_nYcNl01onVcNcoYlk[ojS?k?nY
d>goZm;_oj_Ak_n/dN`01?n^dnh3ok7Fl@03ok;Gl_ncf??o]=Ob00;o]=Ob00?o/mKaokGHlonefO40
0_nefO42okKJlP?o]m_c0_nhg?@00onhg??o^=[aokWKlP05ok[Ll`?o^mgd0onng_<5okoOm0;o_]kc
00?o_modol3PmOo0h?D02?o0h?D2ol7Om@03ol;Om_o2h?Ko`^3f00?o`=kd0_o2h?H00oo3h?GoaN7g
olCPmP02olCPmP06ol?Pm_o2h?Ko`^3fol;Om_o3hOOo`N3e0_o5hOL=olCPmP0XokOTn_oAf^[oaJV7
oib1GonMQW_oY8a[oif7I_n[RUgoVG5Doi]dJ?nJLfCoaH5?om:>EOoBT57obh]<ol>2AOo6OdcoZF`o
okEfA_nnO4OoX6/oomJII_nVKdCoU6mCoheaG_mfF4GoS7iXoemLE_maKgGoG6ANofMSGommLh7o_mOf
okWElOneeO7o/mOaok7HlOndeO;o/]C`ok7Bl0;o/M;_0on_d^h2ojkAk@06ojg@k_n^dNoo[<o]ojc?
kOnZcNcoZLg]0onYcNl00onXc>koYl_]ojO;k@02ojO;k@03ojK:k?nUbN_oX/S/00;oX<KZ0_nOaNT3
oj36j`0000KoS[gWohbki?nB_nKoUL;YoiO2j?nI`nL2oi[4j0?oW<KZ0onMan/01?nNb>coWlW]oj;8
k?nSbNd2ojC:kP04ojK<l?nVc>koY/c^ojK<kP;oYlg_00OoZ<k`ojS?konXc_3oZ]7aoj[@l_n[dO3o
[=3^00;o[];`00?o[m?aok3Dl_n^eO000_n^eO000on_e_7o/=Obok;GlP02ok;GlP;o/mSc0onef?<0
1Ondeo;o]]WdokGHlonffOCo]m[e00;o^=_f00Oo^=ceokSJlonjg?Go^=[cokWKm?njg?Go^M_d00Co
^mgf1Onlg_D3okkNm@;o_mof00?o_moeokoOm?nogo@01Onogo@00onogoGo`>3eol3Pm@05ol3Pm@Go
`Moe00?o`]ofol;Pm_o2h?H02?o2h?H:ol7Om@03ol3Nm?o1goGo`^3f00;o`Moe02;o_mkkolWLn?oA
e=Gob;BJolFGI_o<U5SoYgmJoh9^HOn<S9_o]l;VoiJQbon?NiCo[Hj7ol2FL_neQe_o[H5KoiicB_n?
J47oS6U6oj:2HOnGO5koV81nog1/OomdQ:CoSYN[oi1kM?nFP6CoVXe^oi:1IOn0M6;oMW9aohjFYOne
e?;o]]Gb0_nce?400onbeO7o/]?`ok;Cl003ok;Cl004ok3ClOn_d_3o[]7_ojoBl0Co[M3^00Go[<o]
oj[=k?nYcNgoZ<c^ojO;k@06ojK:k0;oYLW[00?oX/S/oj36j_nPa^X00_nOaNT3oio5jP0000KoS;_U
oi;1j_nC`>OoUL;YoiO2j?nI`nL2oi[4j0?oW<KZ0onMan/01?nNb>coWlW]oj;8k?nSbNd2ojC:kP04
ojK<l?nVc>koY/c^ojK<kP;oYlg_0onXc_02oj[@lP06oj_Al?n/d>ko[];`ojkBl?n_do7o/=Cb0on^
eO000on_e_7o/=Obok;GlP02ok;GlP;o/mSc0once_401?ndeo;o]]WdokGHlonffO@4okOJm@06okSJ
lonjg?Go^=[cokWKm?njg?Go^M_d1?nkgOH5okcNm@?o_]ke0_nogoH00onogoGo_modokoOm005okoO
m003okoOmOo0h?Go`>3e00Go`>3e2?o1goD5ol;PmPgo`Moe00?o`=kdol7OmOo2h?H00_o1goD08onn
gO?o_n3eolCNl_o7dM[oc<2lojZCSOnMTico`L_Pol?Mnonkg__o]][hojWBoonV`>_oXK7EojBceonA
X/coUYJgogeoX?miOJ7oTIS0ojJ`f_nZ]mKo]Lg`ok7Eo?nkfoSo^LGBoiZ<RonJNgKo[X^6ojN6R_nm
YkWoc<_UokKGm?ndeO;o]=Cb00;o/mCa0_nbdo001onad_3o/M;_ok7Bkon`do7o[m;`ojkAkon_d_00
1?n]d>h01?n/cngoZ/g/ojW=kOnXc>h4ojO;k@?oY/[/0_nUbN/00onRb>coX<KZoj36jP02oio5j@?o
WlGZ00001_nA`>[oTL3YoiO4jonE`^WoUl;XoiW3i`;oV/CX0onLa^X3oig7j`04oik8k?nObNgoX/S/
oj?9k@;oY<[^00CoY/c`ojK<k_nVc>koY/c^0_nWcNl3ojS>l0;oZ]3b00KoZm7`ojc@k_n^d_3o[];`
ojoClOn`e?83ojkEl003ojoFlOn`eo;o/]Ob00;o/]Ob0_ncf?<3okGHl`05okCGl_nffOCo]MScokKI
m?ngf_D00onffO@01_nhf_?o^]ceokSJlonifoCo^]ceokWKm0Co^mgf1Onlg_D3okkNm@;o_mof00?o
_moeokoOm?nogo@01Onogo@00onogoGo`>3eol3Pm@05ol3Pm@Go`Moe0oo0g_@5ol;PmP?o`=kd2_o1
goD00oo0g_Co`Moeol;PmP02ol7Om@0SolGPmOo1g_Go_]omokcMoOo2gO[obMolol?Mo_nlgOko^N3m
okSPm?nkh>co^^;SokcKjOo0f?7o_]WbokgMlOnlhNco^Mo/okOOk_ndgnko/]o_okGMnOnffoSo]M_f
okGLm_nbfo?o_=_^ok74d?nW^<?o^LcJokWDionee^ko]MKcok;ClOnde?400_nce?42ok;Cl007ok7B
kon`dNko/=7^ok3ClOn_d_3o[]7_ojoBl004ojg@kP05ojc?kOnZcNcoZLg]ojS<k_nWbnd00onXc>h3
ojK:k0;oYLW[00?oX/S/oj36j_nPa^X00_nOaNT3oio5jP0000GoT;oYoi;1j_nF`n[oUL;YoiO2j002
oiW3i`05oi[4j?nKaNWoVlGYoi_5jOnLa^X00_nMan/00onNb>coWlW]oj?9k@03oj?9k@09ojG;konU
bngoY/c^ojO=konVc>koZ<k`ojO=konXc_3oZLoa00;oZ]3b00?oZm7`ojgAkon]dNl00on^d_02ojgD
k`03ojkEl?n]e>oo[mKa00Go/]Ob0ondeo82okKIm0;o]MSc0_nffO@01?ngf_Go^=_fokSJlonhf_<4
okWKm004ok_Mm_njg?Go^]ceok[Lm@Go^mgd1Onng_D00onogoGo`>3dokkNl`03okkNl`[o_mod0oo0
g_@Bol7Om@03ol7PmOo0g_Co`]of00Go`Moe02Co`=kdokoNm?o7f_Sob=[jol?LnOnng_Go_=oaokcP
konmgnoo_MkbokkMmOo1g?Go`]_gol3Jmoo1fOco`MSnol3JmonmgO3o_m[jokkInonmf?[o_=WjokcI
nonifoCo^m_`okgKkOnjf^go]]_cokCKmOnef_Co]M[bok?KlonafoCo/=WdokGFlonde?43ok?Dl@?o
/]?`00Go/M;`ok3Ak_n_d^oo/=?aojkAl005ojkAk`03ojc?kOnZcNcoZLg/00;oZ<c^00?oYl_]ojK:
k?nWbnd00onVb^`2ojG9j`07oj;8k?nPa^[oXLO[oj36j_nOaNWoW/CYoio5jP01oj36j`0000GoT/7[
oi;1j_nD`NSoUL;YoiO2j003oiW3i`?oVlGY00GoW<KZoig7jonMan_oW/S/oio9k@04oj?9k@09ojG;
konUbngoY/c^ojO=konVc>koZ<k`ojO=konXc_3oZLoa00;oZ]3b00?oZm7`ojgAkon]dNl00on^d_02
ojgDk`03ojkEl?n]e>oo[mKa00Go/]Ob1_ndeo801Onef??o]]WdokKIm?ngf_Go^=_f00;o^=[c1?ni
fo@01?nkgOKo^]ceok[LmOnjg?D5ok_Mm0Go_]ke00?o_]kdokoOm?nogo@00oo0h?D:okoOm0?o`=kd
4_o1goD00oo1h?Go`=kdol;OmP05ol7Om@0Tol3Nm?nog_Co`Mkeol?MmOo2g_?o`MgaokoNlOnng_7o
_mgaokoMl_o0gO?o_mgfokkMnOnigoCo]n3_okSQk_nhh?3o^=oeokcMlOnkg?7o^]__okcKkonlfnko
_=[`ok[Km?nifoKo^=Weok_HlOnmf?7o_=OcokcFmOnkeoOo^]KfokSEmOnee_?o]=Ca0once?43ok;C
l005ok7Bl?n`dNko[m;_ok3ClOn^dO000_n^dNl02on/d>go[<o]ojc?kOn/cngoZ/g/ojS<jonWbnko
ZLg_ojS<k_nWbngoZ<c^00;oY/[/0onUbN/01onRb>coX<KZoj77jonPa^[oWlGYoj36jonOaNX00OnN
a>T00003oiC2jOnD`^OoUL;W00;oU/?X00goV<?XoiW5j?nIa>OoV/GYoi[5j?nKan[oVlKYoic8j_nO
b>_oX<W/oj;9kOnRb>coXlW]00?oY<[^1?nVc>h02?nXc_3oYlk^ojS?kOnYd?3oZ]7_oj[Al?n[dNoo
[M7_1?n^d_02ojkDk`;o[mG`00Co/=G`ok7FlOnae_7o/MKa0_nbeo85ok?Hl`03okCHlonef??o]MSc
00;o]]Wd00?o]m[dokOIl_ngfO801Onifo@6ok[Lm@;o^mge1Onmg_D00onng_Go_]kdokoOm@03okoO
mPSo_moe00?o_]kdol3Pmoo0goD00_o1goD00oo2h?Ko`=kdol7Om@0?ol7Om@03ol;Pm_o1goGo`^3f
00Go`Moe0_o0g_@07OnogoCo_]odol3Nm?o0g_Ko`=ghol3MnOnogOWo_mkhokkNmOnmg_Go_MkgokgL
m_nmg??o_MceokkKnOnof_co^=kfokSLmonhgOGo^=ceokSLm?nif_Go^=[gokKJn_ngfOSo^MSdokSH
lOnef_7o]MWc00;o]=Sc00Go]=ObokCEl_ndeO;o/mCaok;Dl002ok;Cl0Co/M;_017o[m;^ojoBkon_
d^oo[M3]ojg@k?n]d>ko[<k/oj_?kOn/cngoZ/g/oj[=jonYc>coZ<c[ojW;k?nXc>_oZLc]ojO;k@03
ojK:k003ojC8j_nRb>coX<KZ00;oX<KZ00?oW/CXoio5j_nOaNX00OnOaNX000?oUL;W0_nF`nP00onG
a>SoVLGXoiW5j002oiW5j008oic8jonJa^SoW<SZoj38jonQbNcoXlW]oj;8k?nSbNd3ojC:kPCoY/c^
00CoZ<k`ojO>kOnXcncoZM3]0_nZdNh00on[dNko[=3^ojkBl003ojkBl0;o[mC_0on`eO03ok7Fl@;o
/]Ob1Oncf?<3okGHl`?o]]Wd0_ngfO85okWKm0Ko^]ce0_nkgOH5okcNm@03okkOm_nmgOCo_]ke00_o
_mof00?o_]keol3Pn?o1goD07?o1goD2ol3Nm0Ko`=kf1Onng_D5okgLmP?o^]ce0_nifo@4okSJm@04
okKHm?nff??o]]ScokKHl`?o]MOb0_ndeO801Onde?7o/]C`ok7Bkonbdo3o/=7^00?o/M;_0on_d^h0
1on]d>co[Lo[ojkAkon/c^coZlo]ojc?kOnZcN`01_nYc>X01_nWbngoY/[/ojG9jonVb^coY<SZoj;8
k0;oX<KZ0_nOaNT3oio5jP000onE`^L2oiK3j003oiO4j?nIaNSoVLGX00;oVLGX00SoW<S[oi[6j?nL
b>[oX<S[oj79k?nSbNgoX/S/oj?9k@?oY<[^0onTb^`01OnVc>koZ<k`ojO>kOnXcncoZM3]00;oZ]7^
00?oZm7^ojc@k_n^d_000on^d_02ojoDk`?o/=G`0onae_42ok;GlPGo/mSc0onef?<3okKIm0;o]mWb
1Onifo@6ok[Lm@;o^mgf1Onlg_D00onngoKo_MgdokkNm@0;okoOmP03okkNmOo0h?So`Moe00;o`Moe
00?o`=kdol;Om_o1h?D03oo1goD3ol3Nm0Go`Moe0_o0g_@5ol3NmP03okoNmOnmgOCo_Mgd00?o_]ke
1Onmg?H3ok[Lm@;o^M_d1?nhf_D01?nff?Co]]ScokKHlonff?<3okGGlP;o]=Gb00Go]=Caok;Dl?na
d^oo/]?`ok3AkP03ok7Bk`?o[m;^00Oo[M3/ojg?jon^dNoo[<k/oj_?kOn/cngoZ/g/00KoZLcZ00Oo
Yl_]ojK:k?nUbN_oY/[/ojC8j_nRb>coX<KZ00;oWlGY00?oX<KZoio5j_nOaNX00OnOaNX000?oU/?X
00?oUlCYoiK3j?nHaNT00_nIaNP3oi[6j@;oW<SZ00?oX<S[oj79k?nSbNd00onSbNd2ojC:kP?oY/c^
0_nWcNl01_nWc^goZ<o/ojW@kOnYd>goZ]7^oj_Bk`;o[=3^00?o[M7_ojkBl?n_do400_n`eO03ok7F
l@Go/]Ob0oncf?<00onbeo;o]=WdokKIm005okKIm0;o^=[c0onifo@2ok[Lm@03okWKm?njg?Go^mgf
00?o^]ce0_nkgOH00onkgOCo_=keokgOmP02okcNm@?o_Mgd3OnogoH5ol3Nm003ol3OmOo1goGo`Moe
00Go`Moe0oo0g_@2ol;PmP03ol7PmOo1goGo`Moe00?o`=kd1_o1goD00oo0gO?o_mgeokoMm@04okoM
m@Go_]ke0_nngOL3okgLmP?o^mgf0_nifo@4okSJm@04okOIm?nef?;o]MObokGGlP?o]]Sc00?o]MKc
okCDlOnce?400_nce?400onad^oo/m?aok;Cl002ok7Bk`08ojoBk_n^dNgo[M3/ojg@k?n_d^ko[M3^
ojc@kOn[c^`6oj[=j`05ojW<j_nXbnWoY<SZojG9jonVb^`00_nUbN/2oj;8k005oj77jonPa^[oW/CX
oj36jonOaNX00OnNa>T000CoUlCY00CoU/?XoiS5jOnIaNSoVLGX0onKanX2oic8jP03oj38jonQbNco
XlW]00GoXlW]0onVc>h2ojO=k`06ojS?k_nYd>goZ]7^ojW@kOnZdNko[=;_0_n]dNl00on^d_3o[m?a
ok3DlP02ok3El0?o/MKa1Onbeo83ok?Hl`03ok;Gl_ndfOCo]]Wd00Go]]Wd0_nhf_<3okWKm0;o^]ce
00?o^M_dok[LmOnkgOH01OnkgOH00onkgOCo_=keokgOmP02okcNm@03okgNmOnng_Go_]ke00go_mof
0oo0g_@00oo2goKo`^3fol7Om@0:ol7Om@;o`^3f00?o`N3eol7OmOo1goD02Oo1goD00oo0gO?o_mkf
ol3NmP04ol3NmPGo_]ke0_nngOL3okgLmP?o^mgf0_nifo@3okSJm@03okWKm_nhf_Go]]Sd00Go]]Sc
00?o]MKcokCDlOnce?400_nce?42ok;Cl005ok7Bl?nad^oo/M;_ok3Ckon_d^h00on^dNd00on]d>ko
[=3]oj_>k002oj_>k006oj[=k?nZcN_oZ/g[oj_>k?nZc>[oZLcZ0onVb^`2ojG9j`?oX/S/0_nPa^X1
oj36j`7oWlGZ0OnNa>T000?nUlCY00?nU/?XoYG2iojGa>P00_jHa>L3oY_7jP;nVlOY00?nWlOZoZ38
jojRb>`00_jRb>`00ojSbNgnYL__oZG;k`03oZG;k@;nY/c^00KnZ<o^oZW@kOjZdNknZ<o/oZW@kOj[
dNh2oZgAk`03oZkBl?j_do7n/=Cb00;n[mC_0oj`eO05o[7Fl@?n/]Ob00?n/MKao[?Hlojef?<01Oje
f?<2o[OIlP?n^=[c0_jifo@00ojhf_?n^M_do[[Lm@03o[_MmP;n^]ce00?n^]cco[_Mm?jlg_D00_jk
gO@00ojmg_Gn_]keo[kNm@0=o[kNm@?n_mgc0_k1goD8o/3Nm0Gn`Moe00?n`=odo/3Nm?k0g_@00ok1
goD6o/3Nm003o[oLl_jog_Kn`=kf00?n`=kf00?n_mkeo[gMm?jmgO@00ojmgO@2o[gLmP?n_=_e0ojj
g?D2o[SJl`?n]mWd00?n^M_fo[OIm?jgf?<00_jff?<3o[GGlP03o[CEl_jcdo3n/]?`00?n/]?`00Kn
/=7_o[3Ak_j`dNkn/=7^o[3Ckoj_d^h2oZkAk@04oZc?joj/cngnZlo/oZ[=j`;nZlk/00OnZ/g[oZW<
j_jYc>[nZ<_YoZO:j?jVbNOnYl_]00;nYLW[0_jTb>X4oZ77j`03oYo5jOjOaN[nW/CY007nWL?X0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{196.625, 140},
  ImageMargins->{{39, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(RDDensityPlots[actinhib, {u, v}, {u0, v0}, {d1, d2}, dt, 30, 
      PlotEvery \[Rule] 30, PlotRange \[Rule] {{0, 3}, {0, 3}}, 
      ImageSize \[Rule] 500]\)], "Input"],

Cell["\<\
Here\[CloseCurlyQuote]s a variation on the activator-inhibitor \
system, along with a different choice of diffusion coefficients:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(actinhib := {u\^2\/\(\((1 +  .2  u\^2)\) \((v +  .1)\)\) - u, 
        3 \((u\^2 - v)\)}; d1 =  .0003; d2 =  .01;\)], "Input"],

Cell["\<\
We\[CloseCurlyQuote]ll use a wider domain and periodic boundary \
conditions.\
\>", "MathCaption"],

Cell[BoxData[{
    \(h = 1/40; dt =  .1;\), "\n", 
    \(\(u0 = 
        Table[2  Random[] \((1 - 2  y)\)\^2, {y, 0, 1, h}, {x, 0, 2, 
            h}];\)\), "\n", 
    \(\(v0 = 
        Table[4  Random[] y\ \((1 - y)\), {y, 0, 1, h}, {x, 0, 2, 
            h}];\)\), "\n", 
    \(RDDensityPlots[actinhib, {u, v}, {u0, v0}, {d1, d2}, dt, 50, 
      PlotEvery \[Rule] 50, BoundaryConditions \[Rule] Periodic, 
      PlotRange \[Rule] {{0, 1.5}, {0, 1.5}}, 
      ImageSize \[Rule] 400]\)}], "Input"],

Cell["\<\
Here\[CloseCurlyQuote]s an interesting type of initial state:\
\>", \
"MathCaption"],

Cell[BoxData[{
    \(h = 1/40; dt =  .1;\), "\n", 
    \(\(u0 = 
        Table[If[ .475 < y <  .525, 2  Random[]\^2, 0], {y, 0, 1, h}, {x, 0, 
            3, h}];\)\), "\n", 
    \(\(v0 = Table[\  .5 + Random[], {y, 0, 1, h}, {x, 0, 3, h}];\)\), "\n", 
    \(RDDensityPlots[actinhib, {u, v}, {u0, v0}, {d1, d2}, dt, 100, 
      PlotEvery \[Rule] 50, BoundaryConditions \[Rule] Periodic, 
      PlotRange \[Rule] {{0, 1.5}, {0, 1.5}}, 
      ImageSize \[Rule] 400]\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Three-component Systems", "SubsectionIcon"],

Cell["\<\
For the three-component case, just include a third entry wherever \
appropriate:\
\>", "Text"],

Cell[BoxData[GridBox[{
        {
          RowBox[{"RDDensityPlots", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["f",
                          FontSlant->"Italic"], "1"],
                      FontFamily->"Times"], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["2",
                        FontFamily->"Times"]], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["3",
                        FontFamily->"Times"]], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}]}], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                StyleBox[\(u, \ v, \ w\),
                  FontFamily->"Times",
                  FontSlant->"Italic"], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                StyleBox[
                  RowBox[{
                    SubscriptBox[
                      StyleBox["u",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["v",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["w",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"]}],
                  FontFamily->"Times"], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "1"],
                    FontFamily->"Times"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "2"],
                    FontFamily->"Times"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  SubscriptBox[
                    StyleBox["d",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["3",
                      FontFamily->"Times"]]}], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["\[CapitalDelta]",
                  FontFamily->"Times",
                  FontSlant->"Plain"], 
                StyleBox["\[VeryThinSpace]",
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox["t",
                  FontFamily->"Times",
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["nframes",
                FontFamily->"Times",
                FontSlant->"Italic"]}], "]"}]},
        {
          RowBox[{"RDSurfacePlots", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["1",
                        FontFamily->"Times"]], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["2",
                        FontFamily->"Times"]], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["3",
                        FontFamily->"Times"]], "[", 
                    StyleBox[\(u, \ v, \ w\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], "]"}]}], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                StyleBox[\(u, \ v, \ w\),
                  FontFamily->"Times",
                  FontSlant->"Italic"], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                StyleBox[
                  RowBox[{
                    SubscriptBox[
                      StyleBox["u",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["v",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"], ",", " ", 
                    SubscriptBox[
                      StyleBox["w",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "0"]}],
                  FontFamily->"Times"], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{"{", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "1"],
                    FontFamily->"Times"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["d",
                        FontFamily->"Times",
                        FontSlant->"Italic"], "2"],
                    FontFamily->"Times"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  SubscriptBox[
                    StyleBox["d",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["3",
                      FontFamily->"Times"]]}], "}"}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["\[CapitalDelta]",
                  FontFamily->"Times",
                  FontSlant->"Plain"], 
                StyleBox["\[VeryThinSpace]",
                  FontFamily->"Times",
                  FontSlant->"Italic"], 
                StyleBox["t",
                  FontFamily->"Times",
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["nframes",
                FontFamily->"Times",
                FontSlant->"Italic"]}], "]"}]}
        }]], "FramedBox"],

Cell[CellGroupData[{

Cell["Example 3: The Oregonator", "SubsubsectionIcon"],

Cell[TextData[{
  "This is the vector field for an ",
  StyleBox["Oregonator",
    FontSlant->"Italic"],
  " system, which is a model of the Belousov-Zhabotinskii reaction:"
}], "MathCaption"],

Cell[BoxData[
    \(oregonator = {\(a\^\(-1\)\) \((q\ v - u\ v + 
                u \((1 - u)\))\), \(b\^\(-1\)\) \((\(-q\)\ v - u\ v + w)\), \ 
          u - w} /. {a \[Rule]  .01, b \[Rule] 1/3, 
          q \[Rule]  .005}\)], "Input"],

Cell["Here is a choice of diffusion coefficients:", "MathCaption"],

Cell[BoxData[
    \(d1 =  .01; d2 =  .001; d3 =  .0001;\)], "Input"],

Cell["Next we define initial values for each component:", "MathCaption"],

Cell[BoxData[{
    \(\(h = 1/30;\)\), "\n", 
    \(\(u0 = 
        Table[y \((1 - y)\) Random[], {y, 0, 1, h}, {x, 0, 2, 
            h}];\)\), "\n", 
    \(\(v0 = 
        Table[\ 1.  +  .25  Random[], {y, 0, 1, h}, {x, 0, 2, 
            h}];\)\), "\n", 
    \(\(w0 = 
        Table[y \((1 - y)\) Random[], {y, 0, 1, h}, {x, 0, 2, 
            h}];\)\), "\[IndentingNewLine]", 
    \(\(With[{opts = {DisplayFunction \[Rule] Identity, Frame \[Rule] False, 
              AspectRatio \[Rule] Automatic, FrameTicks \[Rule] None, 
              Mesh \[Rule] False}}, \[IndentingNewLine]Show[
          GraphicsArray[{ListDensityPlot[u0, opts], 
              ListDensityPlot[v0, opts], \[IndentingNewLine]ListDensityPlot[
                w0, opts]}], 
          DisplayFunction \[Rule] $DisplayFunction]];\)\)}], "Input"],

Cell[TextData[{
  "This is a ",
  StyleBox["likely",
    FontSlant->"Italic"],
  " safe time-step:"
}], "MathCaption"],

Cell[BoxData[
    \(dt =  .5*h\^2/Max[{d1, d2, d3}]\)], "Input"],

Cell[TextData[{
  "This uses the Dirichlet boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y) = y\ \((1 - y)\)\)]],
  " and Neumann boundary conditions for ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  "."
}], "MathCaption"],

Cell[BoxData[
    \(RDDensityPlots[oregonator, {u, v, w}, {u0, v0, w0}, {d1, d2, d3}, dt, 
      100, PlotEvery \[Rule] 10, 
      PlotRange \[Rule] {{0,  .3}, { .7, 1.4}, {0,  .3}}, 
      ColorFunction \[Rule] \((Hue[ArcTan[1 - #]] &)\), 
      BoundaryConditions \[Rule] {Dirichlet, Neumann, Neumann}, 
      BoundaryFunctions \[Rule] {#2 \((1 - #2)\) &, {}, {}}, 
      ImageSize \[Rule] 500]\)], "Input"],

Cell["The same thing in 3D:", "MathCaption"],

Cell[BoxData[
    \(RDSurfacePlots[oregonator, {u, v, w}, {u0, v0, w0}, {d1, d2, d3}, dt, 
      100, PlotEvery \[Rule] 10, 
      PlotRange \[Rule] {{0,  .3}, { .7, 1.4}, {0,  .3}}, 
      ColorFunction \[Rule] \((Hue[ArcTan[1 - #]] &)\), 
      BoundaryConditions \[Rule] {Dirichlet, Neumann, Neumann}, 
      BoundaryFunctions \[Rule] {#2 \((1 - #2)\) &, {}, {}}, 
      ImageSize \[Rule] 500]\)], "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1636}, {0, 1028}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{724, 812},
WindowMargins->{{367, Automatic}, {Automatic, 83}},
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 178, 3, 81, "Subtitle"],
Cell[1957, 58, 38, 0, 21, "Text"],
Cell[1998, 60, 405, 13, 63, "Text"],

Cell[CellGroupData[{
Cell[2428, 77, 37, 0, 35, "SubsectionIcon"],
Cell[2468, 79, 364, 12, 34, "Text"],
Cell[2835, 93, 788, 23, 35, "Text"],
Cell[3626, 118, 36, 0, 21, "Text"],
Cell[3665, 120, 978, 26, 51, "Text"],
Cell[4646, 148, 157, 4, 34, "Text"],
Cell[4806, 154, 752, 18, 47, "Text"],
Cell[5561, 174, 37, 0, 21, "Text"],
Cell[5601, 176, 166, 6, 26, "Text"],
Cell[5770, 184, 231, 9, 21, "Text"],
Cell[6004, 195, 233, 4, 34, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6274, 204, 47, 0, 25, "SubsectionIcon"],
Cell[6324, 206, 211, 8, 21, "Text"],
Cell[6538, 216, 7674, 208, 57, "FramedBox"],
Cell[14215, 426, 295, 11, 21, "Notes"],
Cell[14513, 439, 597, 19, 34, "Notes"],
Cell[15113, 460, 385, 13, 34, "Text"],
Cell[15501, 475, 3908, 109, 198, "DefinitionBox3Col"],
Cell[19412, 586, 97, 3, 21, "Notes"],
Cell[19512, 591, 332, 7, 34, "Notes"],
Cell[19847, 600, 1493, 42, 73, "Notes"],
Cell[21343, 644, 46, 0, 37, "MathCaption"],
Cell[21392, 646, 89, 2, 25, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[21506, 652, 80, 1, 21, "SubsubsectionIcon"],
Cell[21589, 655, 68, 0, 21, "Text"],
Cell[21660, 657, 469, 12, 41, "Text"],
Cell[22132, 671, 152, 5, 21, "Text"],
Cell[22287, 678, 446, 15, 46, "Text"],
Cell[22736, 695, 313, 11, 21, "Text"],
Cell[23052, 708, 145, 5, 37, "MathCaption"],
Cell[23200, 715, 80, 1, 26, "Input"],
Cell[23283, 718, 68, 0, 37, "MathCaption"],
Cell[23354, 720, 57, 1, 25, "Input"],
Cell[23414, 723, 187, 5, 37, "MathCaption"],
Cell[23604, 730, 200, 3, 55, "Input"],
Cell[23807, 735, 110, 5, 37, "MathCaption"],
Cell[23920, 742, 60, 1, 26, "Input"],
Cell[23983, 745, 85, 1, 37, "MathCaption"],
Cell[24071, 748, 223, 3, 40, "Input"],
Cell[24297, 753, 166, 5, 37, "MathCaption"],
Cell[24466, 760, 183, 3, 40, "Input"],
Cell[24652, 765, 250, 8, 37, "MathCaption"],
Cell[24905, 775, 422, 8, 100, "Input"],
Cell[25330, 785, 241, 6, 50, "MathCaption"],
Cell[25574, 793, 202, 3, 40, "Input"],
Cell[25779, 798, 112, 3, 37, "MathCaption"],
Cell[25894, 803, 223, 3, 40, "Input"],
Cell[26120, 808, 244, 6, 50, "MathCaption"],
Cell[26367, 816, 476, 9, 117, "Input"],
Cell[26846, 827, 140, 3, 37, "MathCaption"],
Cell[26989, 832, 774, 16, 164, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27800, 853, 80, 1, 17, "SubsubsectionIcon"],
Cell[27883, 856, 68, 0, 21, "Text"],
Cell[27954, 858, 440, 11, 41, "Text"],
Cell[28397, 871, 138, 5, 21, "Text"],
Cell[28538, 878, 452, 12, 84, "Text"],
Cell[28993, 892, 409, 15, 21, "Text"],
Cell[29405, 909, 216, 8, 37, "MathCaption"],
Cell[29624, 919, 68, 1, 42, "Input"],
Cell[29695, 922, 83, 1, 37, "MathCaption"],
Cell[29781, 925, 207, 4, 55, "Input"],
Cell[29991, 931, 100, 3, 37, "MathCaption"],
Cell[30094, 936, 84, 1, 26, "Input"],
Cell[30181, 939, 86, 3, 37, "MathCaption"],
Cell[30270, 944, 162, 3, 36, "Input"],
Cell[30435, 949, 209, 4, 50, "MathCaption"],
Cell[30647, 955, 140216, 1735, 148, 140097, 1731, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[170866, 2692, 188, 3, 40, "Input"],
Cell[171057, 2697, 162, 4, 37, "MathCaption"],
Cell[171222, 2703, 146, 2, 44, "Input"],
Cell[171371, 2707, 108, 3, 37, "MathCaption"],
Cell[171482, 2712, 497, 11, 87, "Input"],
Cell[171982, 2725, 94, 3, 37, "MathCaption"],
Cell[172079, 2730, 477, 9, 87, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[172605, 2745, 49, 0, 25, "SubsectionIcon"],
Cell[172657, 2747, 104, 3, 21, "Text"],
Cell[172764, 2752, 9498, 248, 59, "FramedBox"],

Cell[CellGroupData[{
Cell[182287, 3004, 54, 0, 21, "SubsubsectionIcon"],
Cell[182344, 3006, 192, 5, 37, "MathCaption"],
Cell[182539, 3013, 237, 4, 41, "Input"],
Cell[182779, 3019, 66, 0, 37, "MathCaption"],
Cell[182848, 3021, 68, 1, 25, "Input"],
Cell[182919, 3024, 72, 0, 37, "MathCaption"],
Cell[182994, 3026, 819, 17, 130, "Input"],
Cell[183816, 3045, 118, 5, 37, "MathCaption"],
Cell[183937, 3052, 64, 1, 26, "Input"],
Cell[184004, 3055, 310, 11, 37, "MathCaption"],
Cell[184317, 3068, 409, 7, 85, "Input"],
Cell[184729, 3077, 44, 0, 37, "MathCaption"],
Cell[184776, 3079, 409, 7, 70, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

